/*** Autogenerated by WIDL 11.7 from ../wine/include/radialcontrollerinterop.idl - Do not edit ***/

#ifdef _WIN32
#ifndef __REQUIRED_RPCNDR_H_VERSION__
#define __REQUIRED_RPCNDR_H_VERSION__ 475
#endif
#include <rpc.h>
#include <rpcndr.h>
#endif

#ifndef COM_NO_WINDOWS_H
#include <windows.h>
#include <ole2.h>
#endif

#ifndef __radialcontrollerinterop_h__
#define __radialcontrollerinterop_h__

/* Forward declarations */

#ifndef __IRadialControllerInterop_FWD_DEFINED__
#define __IRadialControllerInterop_FWD_DEFINED__
typedef interface IRadialControllerInterop IRadialControllerInterop;
#ifdef __cplusplus
interface IRadialControllerInterop;
#endif /* __cplusplus */
#endif

#ifndef __IRadialControllerConfigurationInterop_FWD_DEFINED__
#define __IRadialControllerConfigurationInterop_FWD_DEFINED__
typedef interface IRadialControllerConfigurationInterop IRadialControllerConfigurationInterop;
#ifdef __cplusplus
interface IRadialControllerConfigurationInterop;
#endif /* __cplusplus */
#endif

/* Headers for imported files */

#include <inspectable.h>

#ifdef __cplusplus
extern "C" {
#endif

/*****************************************************************************
 * IRadialControllerInterop interface
 */
#ifndef __IRadialControllerInterop_INTERFACE_DEFINED__
#define __IRadialControllerInterop_INTERFACE_DEFINED__

DEFINE_GUID(IID_IRadialControllerInterop, 0x1b0535c9, 0x57ad, 0x45c1, 0x9d,0x79, 0xad,0x5c,0x34,0x36,0x05,0x13);
#if defined(__cplusplus) && !defined(CINTERFACE)
MIDL_INTERFACE("1b0535c9-57ad-45c1-9d79-ad5c34360513")
IRadialControllerInterop : public IInspectable
{
    virtual HRESULT STDMETHODCALLTYPE CreateForWindow(
        HWND window,
        REFIID riid,
        void **radialcontroller) = 0;

};
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(IRadialControllerInterop, 0x1b0535c9, 0x57ad, 0x45c1, 0x9d,0x79, 0xad,0x5c,0x34,0x36,0x05,0x13)
#endif
#else
typedef struct IRadialControllerInteropVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IRadialControllerInterop *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IRadialControllerInterop *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IRadialControllerInterop *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        IRadialControllerInterop *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        IRadialControllerInterop *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        IRadialControllerInterop *This,
        TrustLevel *trustLevel);

    /*** IRadialControllerInterop methods ***/
    HRESULT (STDMETHODCALLTYPE *CreateForWindow)(
        IRadialControllerInterop *This,
        HWND window,
        REFIID riid,
        void **radialcontroller);

    END_INTERFACE
} IRadialControllerInteropVtbl;

interface IRadialControllerInterop {
    CONST_VTBL IRadialControllerInteropVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define IRadialControllerInterop_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define IRadialControllerInterop_AddRef(This) (This)->lpVtbl->AddRef(This)
#define IRadialControllerInterop_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define IRadialControllerInterop_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define IRadialControllerInterop_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define IRadialControllerInterop_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IRadialControllerInterop methods ***/
#define IRadialControllerInterop_CreateForWindow(This,window,riid,radialcontroller) (This)->lpVtbl->CreateForWindow(This,window,riid,radialcontroller)
#else
/*** IUnknown methods ***/
static inline HRESULT IRadialControllerInterop_QueryInterface(IRadialControllerInterop* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG IRadialControllerInterop_AddRef(IRadialControllerInterop* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG IRadialControllerInterop_Release(IRadialControllerInterop* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT IRadialControllerInterop_GetIids(IRadialControllerInterop* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT IRadialControllerInterop_GetRuntimeClassName(IRadialControllerInterop* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT IRadialControllerInterop_GetTrustLevel(IRadialControllerInterop* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IRadialControllerInterop methods ***/
static inline HRESULT IRadialControllerInterop_CreateForWindow(IRadialControllerInterop* This,HWND window,REFIID riid,void **radialcontroller) {
    return This->lpVtbl->CreateForWindow(This,window,riid,radialcontroller);
}
#endif
#endif

#endif


#endif  /* __IRadialControllerInterop_INTERFACE_DEFINED__ */

/*****************************************************************************
 * IRadialControllerConfigurationInterop interface
 */
#ifndef __IRadialControllerConfigurationInterop_INTERFACE_DEFINED__
#define __IRadialControllerConfigurationInterop_INTERFACE_DEFINED__

DEFINE_GUID(IID_IRadialControllerConfigurationInterop, 0x787cdaac, 0x3186, 0x476d, 0x87,0xe4, 0xb9,0x37,0x4a,0x7b,0x99,0x70);
#if defined(__cplusplus) && !defined(CINTERFACE)
MIDL_INTERFACE("787cdaac-3186-476d-87e4-b9374a7b9970")
IRadialControllerConfigurationInterop : public IInspectable
{
    virtual HRESULT STDMETHODCALLTYPE GetForWindow(
        HWND window,
        REFIID riid,
        void **radialcontrollerconfiguration) = 0;

};
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(IRadialControllerConfigurationInterop, 0x787cdaac, 0x3186, 0x476d, 0x87,0xe4, 0xb9,0x37,0x4a,0x7b,0x99,0x70)
#endif
#else
typedef struct IRadialControllerConfigurationInteropVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IRadialControllerConfigurationInterop *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IRadialControllerConfigurationInterop *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IRadialControllerConfigurationInterop *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        IRadialControllerConfigurationInterop *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        IRadialControllerConfigurationInterop *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        IRadialControllerConfigurationInterop *This,
        TrustLevel *trustLevel);

    /*** IRadialControllerConfigurationInterop methods ***/
    HRESULT (STDMETHODCALLTYPE *GetForWindow)(
        IRadialControllerConfigurationInterop *This,
        HWND window,
        REFIID riid,
        void **radialcontrollerconfiguration);

    END_INTERFACE
} IRadialControllerConfigurationInteropVtbl;

interface IRadialControllerConfigurationInterop {
    CONST_VTBL IRadialControllerConfigurationInteropVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define IRadialControllerConfigurationInterop_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define IRadialControllerConfigurationInterop_AddRef(This) (This)->lpVtbl->AddRef(This)
#define IRadialControllerConfigurationInterop_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define IRadialControllerConfigurationInterop_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define IRadialControllerConfigurationInterop_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define IRadialControllerConfigurationInterop_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IRadialControllerConfigurationInterop methods ***/
#define IRadialControllerConfigurationInterop_GetForWindow(This,window,riid,radialcontrollerconfiguration) (This)->lpVtbl->GetForWindow(This,window,riid,radialcontrollerconfiguration)
#else
/*** IUnknown methods ***/
static inline HRESULT IRadialControllerConfigurationInterop_QueryInterface(IRadialControllerConfigurationInterop* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG IRadialControllerConfigurationInterop_AddRef(IRadialControllerConfigurationInterop* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG IRadialControllerConfigurationInterop_Release(IRadialControllerConfigurationInterop* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT IRadialControllerConfigurationInterop_GetIids(IRadialControllerConfigurationInterop* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT IRadialControllerConfigurationInterop_GetRuntimeClassName(IRadialControllerConfigurationInterop* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT IRadialControllerConfigurationInterop_GetTrustLevel(IRadialControllerConfigurationInterop* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IRadialControllerConfigurationInterop methods ***/
static inline HRESULT IRadialControllerConfigurationInterop_GetForWindow(IRadialControllerConfigurationInterop* This,HWND window,REFIID riid,void **radialcontrollerconfiguration) {
    return This->lpVtbl->GetForWindow(This,window,riid,radialcontrollerconfiguration);
}
#endif
#endif

#endif


#endif  /* __IRadialControllerConfigurationInterop_INTERFACE_DEFINED__ */

/* Begin additional prototypes for all interfaces */


/* End additional prototypes */

#ifdef __cplusplus
}
#endif

#endif /* __radialcontrollerinterop_h__ */
