/*
 * Copyright (C) 2009 Huw Davies
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

#if 0
#pragma makedep install
#endif

[
    object,
    uuid(0c733a69-2a1c-11ce-ade5-00aa0044773d),
    pointer_default(unique)
]
interface IOpenRowset : IUnknown
{
    [local]
    HRESULT OpenRowset([in] IUnknown *pUnkOuter,
                       [in, unique] DBID *pTableID,
                       [in, unique] DBID *pIndexID,
                       [in] REFIID riid,
                       [in] ULONG cPropertySets,
                       [in, out, size_is(cPropertySets)] DBPROPSET rgPropertySets[],
                       [out, iid_is(riid)] IUnknown **ppRowset);

    [call_as(OpenRowset)]
    HRESULT RemoteOpenRowset([in] IUnknown *pUnkOuter,
                             [in, unique] DBID *pTableID,
                             [in, unique] DBID *pIndexID,
                             [in] REFIID riid,
                             [in] ULONG cPropertySets,
                             [in, unique, size_is(cPropertySets)] DBPROPSET *rgPropertySets,
                             [in, out, unique, iid_is(riid)] IUnknown **ppRowset,
                             [in] ULONG cTotalProps,
                             [out, size_is(cTotalProps)] DBPROPSTATUS *rgPropStatus,
                             [out] IErrorInfo **ppErrorInfoRem);

}
