/*** Autogenerated by WIDL 11.7 from ../wine/include/windows.ui.input.idl - Do not edit ***/

#ifdef _WIN32
#ifndef __REQUIRED_RPCNDR_H_VERSION__
#define __REQUIRED_RPCNDR_H_VERSION__ 475
#endif
#include <rpc.h>
#include <rpcndr.h>
#endif

#ifndef COM_NO_WINDOWS_H
#include <windows.h>
#include <ole2.h>
#endif

#ifndef __windows_ui_input_h__
#define __windows_ui_input_h__

/* Forward declarations */

#ifndef ____x_ABI_CWindows_CUI_CInput_CIPointerPoint_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIPointerPoint_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIPointerPoint __x_ABI_CWindows_CUI_CInput_CIPointerPoint;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIPointerPoint ABI::Windows::UI::Input::IPointerPoint
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IPointerPoint;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties ABI::Windows::UI::Input::IPointerPointProperties
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IPointerPointProperties;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2 __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2 ABI::Windows::UI::Input::IPointerPointProperties2
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IPointerPointProperties2;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics ABI::Windows::UI::Input::IPointerPointStatics
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IPointerPointStatics;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform ABI::Windows::UI::Input::IPointerPointTransform
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IPointerPointTransform;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialController_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialController_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialController __x_ABI_CWindows_CUI_CInput_CIRadialController;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialController ABI::Windows::UI::Input::IRadialController
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialController;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialController2_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialController2_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialController2 __x_ABI_CWindows_CUI_CInput_CIRadialController2;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialController2 ABI::Windows::UI::Input::IRadialController2
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialController2;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs ABI::Windows::UI::Input::IRadialControllerButtonClickedEventArgs
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerButtonClickedEventArgs;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2 __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2 ABI::Windows::UI::Input::IRadialControllerButtonClickedEventArgs2
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerButtonClickedEventArgs2;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs ABI::Windows::UI::Input::IRadialControllerButtonHoldingEventArgs
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerButtonHoldingEventArgs;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs ABI::Windows::UI::Input::IRadialControllerButtonPressedEventArgs
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerButtonPressedEventArgs;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs ABI::Windows::UI::Input::IRadialControllerButtonReleasedEventArgs
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerButtonReleasedEventArgs;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration ABI::Windows::UI::Input::IRadialControllerConfiguration
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerConfiguration;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2 __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2 ABI::Windows::UI::Input::IRadialControllerConfiguration2
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerConfiguration2;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics ABI::Windows::UI::Input::IRadialControllerConfigurationStatics
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerConfigurationStatics;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs ABI::Windows::UI::Input::IRadialControllerControlAcquiredEventArgs
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerControlAcquiredEventArgs;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2 __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2 ABI::Windows::UI::Input::IRadialControllerControlAcquiredEventArgs2
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerControlAcquiredEventArgs2;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu ABI::Windows::UI::Input::IRadialControllerMenu
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerMenu;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem ABI::Windows::UI::Input::IRadialControllerMenuItem
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerMenuItem;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics ABI::Windows::UI::Input::IRadialControllerMenuItemStatics
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerMenuItemStatics;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2 __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2 ABI::Windows::UI::Input::IRadialControllerMenuItemStatics2
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerMenuItemStatics2;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs ABI::Windows::UI::Input::IRadialControllerRotationChangedEventArgs
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerRotationChangedEventArgs;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact ABI::Windows::UI::Input::IRadialControllerScreenContact
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerScreenContact;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs ABI::Windows::UI::Input::IRadialControllerScreenContactContinuedEventArgs
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerScreenContactContinuedEventArgs;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs ABI::Windows::UI::Input::IRadialControllerScreenContactStartedEventArgs
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerScreenContactStartedEventArgs;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2 __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2 ABI::Windows::UI::Input::IRadialControllerScreenContactStartedEventArgs2
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerScreenContactStartedEventArgs2;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics ABI::Windows::UI::Input::IRadialControllerStatics
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerStatics;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CPointerPoint_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CPointerPoint_FWD_DEFINED__
#ifdef __cplusplus
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                class PointerPoint;
            }
        }
    }
}
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CPointerPoint __x_ABI_CWindows_CUI_CInput_CPointerPoint;
#endif /* defined __cplusplus */
#endif /* defined ____x_ABI_CWindows_CUI_CInput_CPointerPoint_FWD_DEFINED__ */

#ifndef ____x_ABI_CWindows_CUI_CInput_CPointerPointProperties_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CPointerPointProperties_FWD_DEFINED__
#ifdef __cplusplus
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                class PointerPointProperties;
            }
        }
    }
}
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CPointerPointProperties __x_ABI_CWindows_CUI_CInput_CPointerPointProperties;
#endif /* defined __cplusplus */
#endif /* defined ____x_ABI_CWindows_CUI_CInput_CPointerPointProperties_FWD_DEFINED__ */

#ifndef ____x_ABI_CWindows_CUI_CInput_CRadialController_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CRadialController_FWD_DEFINED__
#ifdef __cplusplus
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                class RadialController;
            }
        }
    }
}
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CRadialController __x_ABI_CWindows_CUI_CInput_CRadialController;
#endif /* defined __cplusplus */
#endif /* defined ____x_ABI_CWindows_CUI_CInput_CRadialController_FWD_DEFINED__ */

#ifndef ____x_ABI_CWindows_CUI_CInput_CRadialControllerButtonClickedEventArgs_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CRadialControllerButtonClickedEventArgs_FWD_DEFINED__
#ifdef __cplusplus
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                class RadialControllerButtonClickedEventArgs;
            }
        }
    }
}
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CRadialControllerButtonClickedEventArgs __x_ABI_CWindows_CUI_CInput_CRadialControllerButtonClickedEventArgs;
#endif /* defined __cplusplus */
#endif /* defined ____x_ABI_CWindows_CUI_CInput_CRadialControllerButtonClickedEventArgs_FWD_DEFINED__ */

#ifndef ____x_ABI_CWindows_CUI_CInput_CRadialControllerButtonHoldingEventArgs_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CRadialControllerButtonHoldingEventArgs_FWD_DEFINED__
#ifdef __cplusplus
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                class RadialControllerButtonHoldingEventArgs;
            }
        }
    }
}
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CRadialControllerButtonHoldingEventArgs __x_ABI_CWindows_CUI_CInput_CRadialControllerButtonHoldingEventArgs;
#endif /* defined __cplusplus */
#endif /* defined ____x_ABI_CWindows_CUI_CInput_CRadialControllerButtonHoldingEventArgs_FWD_DEFINED__ */

#ifndef ____x_ABI_CWindows_CUI_CInput_CRadialControllerButtonPressedEventArgs_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CRadialControllerButtonPressedEventArgs_FWD_DEFINED__
#ifdef __cplusplus
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                class RadialControllerButtonPressedEventArgs;
            }
        }
    }
}
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CRadialControllerButtonPressedEventArgs __x_ABI_CWindows_CUI_CInput_CRadialControllerButtonPressedEventArgs;
#endif /* defined __cplusplus */
#endif /* defined ____x_ABI_CWindows_CUI_CInput_CRadialControllerButtonPressedEventArgs_FWD_DEFINED__ */

#ifndef ____x_ABI_CWindows_CUI_CInput_CRadialControllerButtonReleasedEventArgs_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CRadialControllerButtonReleasedEventArgs_FWD_DEFINED__
#ifdef __cplusplus
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                class RadialControllerButtonReleasedEventArgs;
            }
        }
    }
}
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CRadialControllerButtonReleasedEventArgs __x_ABI_CWindows_CUI_CInput_CRadialControllerButtonReleasedEventArgs;
#endif /* defined __cplusplus */
#endif /* defined ____x_ABI_CWindows_CUI_CInput_CRadialControllerButtonReleasedEventArgs_FWD_DEFINED__ */

#ifndef ____x_ABI_CWindows_CUI_CInput_CRadialControllerConfiguration_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CRadialControllerConfiguration_FWD_DEFINED__
#ifdef __cplusplus
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                class RadialControllerConfiguration;
            }
        }
    }
}
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CRadialControllerConfiguration __x_ABI_CWindows_CUI_CInput_CRadialControllerConfiguration;
#endif /* defined __cplusplus */
#endif /* defined ____x_ABI_CWindows_CUI_CInput_CRadialControllerConfiguration_FWD_DEFINED__ */

#ifndef ____x_ABI_CWindows_CUI_CInput_CRadialControllerControlAcquiredEventArgs_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CRadialControllerControlAcquiredEventArgs_FWD_DEFINED__
#ifdef __cplusplus
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                class RadialControllerControlAcquiredEventArgs;
            }
        }
    }
}
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CRadialControllerControlAcquiredEventArgs __x_ABI_CWindows_CUI_CInput_CRadialControllerControlAcquiredEventArgs;
#endif /* defined __cplusplus */
#endif /* defined ____x_ABI_CWindows_CUI_CInput_CRadialControllerControlAcquiredEventArgs_FWD_DEFINED__ */

#ifndef ____x_ABI_CWindows_CUI_CInput_CRadialControllerMenu_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CRadialControllerMenu_FWD_DEFINED__
#ifdef __cplusplus
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                class RadialControllerMenu;
            }
        }
    }
}
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CRadialControllerMenu __x_ABI_CWindows_CUI_CInput_CRadialControllerMenu;
#endif /* defined __cplusplus */
#endif /* defined ____x_ABI_CWindows_CUI_CInput_CRadialControllerMenu_FWD_DEFINED__ */

#ifndef ____x_ABI_CWindows_CUI_CInput_CRadialControllerMenuItem_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CRadialControllerMenuItem_FWD_DEFINED__
#ifdef __cplusplus
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                class RadialControllerMenuItem;
            }
        }
    }
}
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CRadialControllerMenuItem __x_ABI_CWindows_CUI_CInput_CRadialControllerMenuItem;
#endif /* defined __cplusplus */
#endif /* defined ____x_ABI_CWindows_CUI_CInput_CRadialControllerMenuItem_FWD_DEFINED__ */

#ifndef ____x_ABI_CWindows_CUI_CInput_CRadialControllerRotationChangedEventArgs_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CRadialControllerRotationChangedEventArgs_FWD_DEFINED__
#ifdef __cplusplus
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                class RadialControllerRotationChangedEventArgs;
            }
        }
    }
}
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CRadialControllerRotationChangedEventArgs __x_ABI_CWindows_CUI_CInput_CRadialControllerRotationChangedEventArgs;
#endif /* defined __cplusplus */
#endif /* defined ____x_ABI_CWindows_CUI_CInput_CRadialControllerRotationChangedEventArgs_FWD_DEFINED__ */

#ifndef ____x_ABI_CWindows_CUI_CInput_CRadialControllerScreenContact_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CRadialControllerScreenContact_FWD_DEFINED__
#ifdef __cplusplus
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                class RadialControllerScreenContact;
            }
        }
    }
}
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CRadialControllerScreenContact __x_ABI_CWindows_CUI_CInput_CRadialControllerScreenContact;
#endif /* defined __cplusplus */
#endif /* defined ____x_ABI_CWindows_CUI_CInput_CRadialControllerScreenContact_FWD_DEFINED__ */

#ifndef ____x_ABI_CWindows_CUI_CInput_CRadialControllerScreenContactContinuedEventArgs_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CRadialControllerScreenContactContinuedEventArgs_FWD_DEFINED__
#ifdef __cplusplus
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                class RadialControllerScreenContactContinuedEventArgs;
            }
        }
    }
}
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CRadialControllerScreenContactContinuedEventArgs __x_ABI_CWindows_CUI_CInput_CRadialControllerScreenContactContinuedEventArgs;
#endif /* defined __cplusplus */
#endif /* defined ____x_ABI_CWindows_CUI_CInput_CRadialControllerScreenContactContinuedEventArgs_FWD_DEFINED__ */

#ifndef ____x_ABI_CWindows_CUI_CInput_CRadialControllerScreenContactStartedEventArgs_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CRadialControllerScreenContactStartedEventArgs_FWD_DEFINED__
#ifdef __cplusplus
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                class RadialControllerScreenContactStartedEventArgs;
            }
        }
    }
}
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CRadialControllerScreenContactStartedEventArgs __x_ABI_CWindows_CUI_CInput_CRadialControllerScreenContactStartedEventArgs;
#endif /* defined __cplusplus */
#endif /* defined ____x_ABI_CWindows_CUI_CInput_CRadialControllerScreenContactStartedEventArgs_FWD_DEFINED__ */

#ifndef ____FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_FWD_DEFINED__
#define ____FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_FWD_DEFINED__
typedef interface __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem;
#ifdef __cplusplus
#define __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem ABI::Windows::Foundation::Collections::IIterable<ABI::Windows::UI::Input::RadialControllerMenuItem* >
#endif /* __cplusplus */
#endif

#ifndef ____FIIterable_1_RadialControllerSystemMenuItemKind_FWD_DEFINED__
#define ____FIIterable_1_RadialControllerSystemMenuItemKind_FWD_DEFINED__
typedef interface __FIIterable_1_RadialControllerSystemMenuItemKind __FIIterable_1_RadialControllerSystemMenuItemKind;
#ifdef __cplusplus
#define __FIIterable_1_RadialControllerSystemMenuItemKind ABI::Windows::Foundation::Collections::IIterable<ABI::Windows::UI::Input::RadialControllerSystemMenuItemKind >
#endif /* __cplusplus */
#endif

#ifndef ____FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_FWD_DEFINED__
#define ____FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_FWD_DEFINED__
typedef interface __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem;
#ifdef __cplusplus
#define __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem ABI::Windows::Foundation::Collections::IIterator<ABI::Windows::UI::Input::RadialControllerMenuItem* >
#endif /* __cplusplus */
#endif

#ifndef ____FIIterator_1_RadialControllerSystemMenuItemKind_FWD_DEFINED__
#define ____FIIterator_1_RadialControllerSystemMenuItemKind_FWD_DEFINED__
typedef interface __FIIterator_1_RadialControllerSystemMenuItemKind __FIIterator_1_RadialControllerSystemMenuItemKind;
#ifdef __cplusplus
#define __FIIterator_1_RadialControllerSystemMenuItemKind ABI::Windows::Foundation::Collections::IIterator<ABI::Windows::UI::Input::RadialControllerSystemMenuItemKind >
#endif /* __cplusplus */
#endif

#ifndef ____FIVectorView_1_Windows__CUI__CInput__CPointerPoint_FWD_DEFINED__
#define ____FIVectorView_1_Windows__CUI__CInput__CPointerPoint_FWD_DEFINED__
typedef interface __FIVectorView_1_Windows__CUI__CInput__CPointerPoint __FIVectorView_1_Windows__CUI__CInput__CPointerPoint;
#ifdef __cplusplus
#define __FIVectorView_1_Windows__CUI__CInput__CPointerPoint ABI::Windows::Foundation::Collections::IVectorView<ABI::Windows::UI::Input::PointerPoint* >
#endif /* __cplusplus */
#endif

#ifndef ____FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_FWD_DEFINED__
#define ____FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_FWD_DEFINED__
typedef interface __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem;
#ifdef __cplusplus
#define __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem ABI::Windows::Foundation::Collections::IVectorView<ABI::Windows::UI::Input::RadialControllerMenuItem* >
#endif /* __cplusplus */
#endif

#ifndef ____FIVector_1_Windows__CUI__CInput__CPointerPoint_FWD_DEFINED__
#define ____FIVector_1_Windows__CUI__CInput__CPointerPoint_FWD_DEFINED__
typedef interface __FIVector_1_Windows__CUI__CInput__CPointerPoint __FIVector_1_Windows__CUI__CInput__CPointerPoint;
#ifdef __cplusplus
#define __FIVector_1_Windows__CUI__CInput__CPointerPoint ABI::Windows::Foundation::Collections::IVector<ABI::Windows::UI::Input::PointerPoint* >
#endif /* __cplusplus */
#endif

#ifndef ____FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_FWD_DEFINED__
#define ____FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_FWD_DEFINED__
typedef interface __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem;
#ifdef __cplusplus
#define __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem ABI::Windows::Foundation::Collections::IVector<ABI::Windows::UI::Input::RadialControllerMenuItem* >
#endif /* __cplusplus */
#endif

#ifndef ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable_FWD_DEFINED__
#define ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable_FWD_DEFINED__
typedef interface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable;
#ifdef __cplusplus
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable ABI::Windows::Foundation::ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,IInspectable* >
#endif /* __cplusplus */
#endif

#ifndef ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs_FWD_DEFINED__
#define ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs_FWD_DEFINED__
typedef interface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs;
#ifdef __cplusplus
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs ABI::Windows::Foundation::ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonClickedEventArgs* >
#endif /* __cplusplus */
#endif

#ifndef ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs_FWD_DEFINED__
#define ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs_FWD_DEFINED__
typedef interface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs;
#ifdef __cplusplus
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs ABI::Windows::Foundation::ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonHoldingEventArgs* >
#endif /* __cplusplus */
#endif

#ifndef ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs_FWD_DEFINED__
#define ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs_FWD_DEFINED__
typedef interface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs;
#ifdef __cplusplus
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs ABI::Windows::Foundation::ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonPressedEventArgs* >
#endif /* __cplusplus */
#endif

#ifndef ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs_FWD_DEFINED__
#define ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs_FWD_DEFINED__
typedef interface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs;
#ifdef __cplusplus
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs ABI::Windows::Foundation::ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonReleasedEventArgs* >
#endif /* __cplusplus */
#endif

#ifndef ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs_FWD_DEFINED__
#define ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs_FWD_DEFINED__
typedef interface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs;
#ifdef __cplusplus
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs ABI::Windows::Foundation::ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerControlAcquiredEventArgs* >
#endif /* __cplusplus */
#endif

#ifndef ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs_FWD_DEFINED__
#define ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs_FWD_DEFINED__
typedef interface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs;
#ifdef __cplusplus
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs ABI::Windows::Foundation::ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerRotationChangedEventArgs* >
#endif /* __cplusplus */
#endif

#ifndef ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs_FWD_DEFINED__
#define ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs_FWD_DEFINED__
typedef interface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs;
#ifdef __cplusplus
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs ABI::Windows::Foundation::ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerScreenContactContinuedEventArgs* >
#endif /* __cplusplus */
#endif

#ifndef ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs_FWD_DEFINED__
#define ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs_FWD_DEFINED__
typedef interface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs;
#ifdef __cplusplus
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs ABI::Windows::Foundation::ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerScreenContactStartedEventArgs* >
#endif /* __cplusplus */
#endif

#ifndef ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable_FWD_DEFINED__
#define ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable_FWD_DEFINED__
typedef interface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable __FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable;
#ifdef __cplusplus
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable ABI::Windows::Foundation::ITypedEventHandler<ABI::Windows::UI::Input::RadialControllerMenuItem*,IInspectable* >
#endif /* __cplusplus */
#endif

/* Headers for imported files */

#include <inspectable.h>
#include <asyncinfo.h>
#include <eventtoken.h>
#include <windowscontracts.h>
#include <windows.foundation.h>
#include <windows.devices.input.h>
#include <windows.system.h>
#include <windows.devices.haptics.h>

#ifdef __cplusplus
extern "C" {
#endif

#if !defined(WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION)
#define WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION 0xe0000
#endif // defined(WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION)

#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x10000
#ifndef ____x_ABI_CWindows_CUI_CInput_CPointerUpdateKind_ENUM_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CPointerUpdateKind_ENUM_DEFINED__
#ifdef __cplusplus
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                enum PointerUpdateKind {
                    PointerUpdateKind_Other = 0,
                    PointerUpdateKind_LeftButtonPressed = 1,
                    PointerUpdateKind_LeftButtonReleased = 2,
                    PointerUpdateKind_RightButtonPressed = 3,
                    PointerUpdateKind_RightButtonReleased = 4,
                    PointerUpdateKind_MiddleButtonPressed = 5,
                    PointerUpdateKind_MiddleButtonReleased = 6,
                    PointerUpdateKind_XButton1Pressed = 7,
                    PointerUpdateKind_XButton1Released = 8,
                    PointerUpdateKind_XButton2Pressed = 9,
                    PointerUpdateKind_XButton2Released = 10
                };
            }
        }
    }
}
extern "C" {
#else
enum __x_ABI_CWindows_CUI_CInput_CPointerUpdateKind {
    PointerUpdateKind_Other = 0,
    PointerUpdateKind_LeftButtonPressed = 1,
    PointerUpdateKind_LeftButtonReleased = 2,
    PointerUpdateKind_RightButtonPressed = 3,
    PointerUpdateKind_RightButtonReleased = 4,
    PointerUpdateKind_MiddleButtonPressed = 5,
    PointerUpdateKind_MiddleButtonReleased = 6,
    PointerUpdateKind_XButton1Pressed = 7,
    PointerUpdateKind_XButton1Released = 8,
    PointerUpdateKind_XButton2Pressed = 9,
    PointerUpdateKind_XButton2Released = 10
};
#ifdef WIDL_using_Windows_UI_Input
#define PointerUpdateKind __x_ABI_CWindows_CUI_CInput_CPointerUpdateKind
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif /* ____x_ABI_CWindows_CUI_CInput_CPointerUpdateKind_ENUM_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x10000 */
#ifndef __cplusplus
typedef enum __x_ABI_CWindows_CUI_CInput_CPointerUpdateKind __x_ABI_CWindows_CUI_CInput_CPointerUpdateKind;
#endif /* __cplusplus */

#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000
#ifndef ____x_ABI_CWindows_CUI_CInput_CRadialControllerMenuKnownIcon_ENUM_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CRadialControllerMenuKnownIcon_ENUM_DEFINED__
#ifdef __cplusplus
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                enum RadialControllerMenuKnownIcon {
                    RadialControllerMenuKnownIcon_Scroll = 0,
                    RadialControllerMenuKnownIcon_Zoom = 1,
                    RadialControllerMenuKnownIcon_UndoRedo = 2,
                    RadialControllerMenuKnownIcon_Volume = 3,
                    RadialControllerMenuKnownIcon_NextPreviousTrack = 4,
                    RadialControllerMenuKnownIcon_Ruler = 5,
                    RadialControllerMenuKnownIcon_InkColor = 6,
                    RadialControllerMenuKnownIcon_InkThickness = 7,
                    RadialControllerMenuKnownIcon_PenType = 8
                };
            }
        }
    }
}
extern "C" {
#else
enum __x_ABI_CWindows_CUI_CInput_CRadialControllerMenuKnownIcon {
    RadialControllerMenuKnownIcon_Scroll = 0,
    RadialControllerMenuKnownIcon_Zoom = 1,
    RadialControllerMenuKnownIcon_UndoRedo = 2,
    RadialControllerMenuKnownIcon_Volume = 3,
    RadialControllerMenuKnownIcon_NextPreviousTrack = 4,
    RadialControllerMenuKnownIcon_Ruler = 5,
    RadialControllerMenuKnownIcon_InkColor = 6,
    RadialControllerMenuKnownIcon_InkThickness = 7,
    RadialControllerMenuKnownIcon_PenType = 8
};
#ifdef WIDL_using_Windows_UI_Input
#define RadialControllerMenuKnownIcon __x_ABI_CWindows_CUI_CInput_CRadialControllerMenuKnownIcon
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif /* ____x_ABI_CWindows_CUI_CInput_CRadialControllerMenuKnownIcon_ENUM_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000 */
#ifndef __cplusplus
typedef enum __x_ABI_CWindows_CUI_CInput_CRadialControllerMenuKnownIcon __x_ABI_CWindows_CUI_CInput_CRadialControllerMenuKnownIcon;
#endif /* __cplusplus */

#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000
#ifndef ____x_ABI_CWindows_CUI_CInput_CRadialControllerSystemMenuItemKind_ENUM_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CRadialControllerSystemMenuItemKind_ENUM_DEFINED__
#ifdef __cplusplus
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                enum RadialControllerSystemMenuItemKind {
                    RadialControllerSystemMenuItemKind_Scroll = 0,
                    RadialControllerSystemMenuItemKind_Zoom = 1,
                    RadialControllerSystemMenuItemKind_UndoRedo = 2,
                    RadialControllerSystemMenuItemKind_Volume = 3,
                    RadialControllerSystemMenuItemKind_NextPreviousTrack = 4
                };
            }
        }
    }
}
extern "C" {
#else
enum __x_ABI_CWindows_CUI_CInput_CRadialControllerSystemMenuItemKind {
    RadialControllerSystemMenuItemKind_Scroll = 0,
    RadialControllerSystemMenuItemKind_Zoom = 1,
    RadialControllerSystemMenuItemKind_UndoRedo = 2,
    RadialControllerSystemMenuItemKind_Volume = 3,
    RadialControllerSystemMenuItemKind_NextPreviousTrack = 4
};
#ifdef WIDL_using_Windows_UI_Input
#define RadialControllerSystemMenuItemKind __x_ABI_CWindows_CUI_CInput_CRadialControllerSystemMenuItemKind
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif /* ____x_ABI_CWindows_CUI_CInput_CRadialControllerSystemMenuItemKind_ENUM_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000 */
#ifndef __cplusplus
typedef enum __x_ABI_CWindows_CUI_CInput_CRadialControllerSystemMenuItemKind __x_ABI_CWindows_CUI_CInput_CRadialControllerSystemMenuItemKind;
#endif /* __cplusplus */

#ifndef ____x_ABI_CWindows_CUI_CInput_CIPointerPoint_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIPointerPoint_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIPointerPoint __x_ABI_CWindows_CUI_CInput_CIPointerPoint;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIPointerPoint ABI::Windows::UI::Input::IPointerPoint
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IPointerPoint;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties ABI::Windows::UI::Input::IPointerPointProperties
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IPointerPointProperties;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2 __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2 ABI::Windows::UI::Input::IPointerPointProperties2
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IPointerPointProperties2;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics ABI::Windows::UI::Input::IPointerPointStatics
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IPointerPointStatics;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform ABI::Windows::UI::Input::IPointerPointTransform
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IPointerPointTransform;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialController_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialController_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialController __x_ABI_CWindows_CUI_CInput_CIRadialController;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialController ABI::Windows::UI::Input::IRadialController
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialController;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialController2_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialController2_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialController2 __x_ABI_CWindows_CUI_CInput_CIRadialController2;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialController2 ABI::Windows::UI::Input::IRadialController2
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialController2;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs ABI::Windows::UI::Input::IRadialControllerButtonClickedEventArgs
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerButtonClickedEventArgs;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2 __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2 ABI::Windows::UI::Input::IRadialControllerButtonClickedEventArgs2
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerButtonClickedEventArgs2;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs ABI::Windows::UI::Input::IRadialControllerButtonHoldingEventArgs
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerButtonHoldingEventArgs;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs ABI::Windows::UI::Input::IRadialControllerButtonPressedEventArgs
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerButtonPressedEventArgs;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs ABI::Windows::UI::Input::IRadialControllerButtonReleasedEventArgs
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerButtonReleasedEventArgs;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration ABI::Windows::UI::Input::IRadialControllerConfiguration
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerConfiguration;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2 __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2 ABI::Windows::UI::Input::IRadialControllerConfiguration2
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerConfiguration2;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics ABI::Windows::UI::Input::IRadialControllerConfigurationStatics
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerConfigurationStatics;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs ABI::Windows::UI::Input::IRadialControllerControlAcquiredEventArgs
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerControlAcquiredEventArgs;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2 __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2 ABI::Windows::UI::Input::IRadialControllerControlAcquiredEventArgs2
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerControlAcquiredEventArgs2;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu ABI::Windows::UI::Input::IRadialControllerMenu
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerMenu;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem ABI::Windows::UI::Input::IRadialControllerMenuItem
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerMenuItem;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics ABI::Windows::UI::Input::IRadialControllerMenuItemStatics
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerMenuItemStatics;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2 __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2 ABI::Windows::UI::Input::IRadialControllerMenuItemStatics2
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerMenuItemStatics2;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs ABI::Windows::UI::Input::IRadialControllerRotationChangedEventArgs
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerRotationChangedEventArgs;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact ABI::Windows::UI::Input::IRadialControllerScreenContact
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerScreenContact;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs ABI::Windows::UI::Input::IRadialControllerScreenContactContinuedEventArgs
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerScreenContactContinuedEventArgs;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs ABI::Windows::UI::Input::IRadialControllerScreenContactStartedEventArgs
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerScreenContactStartedEventArgs;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2 __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2 ABI::Windows::UI::Input::IRadialControllerScreenContactStartedEventArgs2
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerScreenContactStartedEventArgs2;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_FWD_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_FWD_DEFINED__
typedef interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics;
#ifdef __cplusplus
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics ABI::Windows::UI::Input::IRadialControllerStatics
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                interface IRadialControllerStatics;
            }
        }
    }
}
#endif /* __cplusplus */
#endif

#ifndef ____FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_FWD_DEFINED__
#define ____FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_FWD_DEFINED__
typedef interface __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem;
#ifdef __cplusplus
#define __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem ABI::Windows::Foundation::Collections::IIterable<ABI::Windows::UI::Input::RadialControllerMenuItem* >
#endif /* __cplusplus */
#endif

#ifndef ____FIIterable_1_RadialControllerSystemMenuItemKind_FWD_DEFINED__
#define ____FIIterable_1_RadialControllerSystemMenuItemKind_FWD_DEFINED__
typedef interface __FIIterable_1_RadialControllerSystemMenuItemKind __FIIterable_1_RadialControllerSystemMenuItemKind;
#ifdef __cplusplus
#define __FIIterable_1_RadialControllerSystemMenuItemKind ABI::Windows::Foundation::Collections::IIterable<ABI::Windows::UI::Input::RadialControllerSystemMenuItemKind >
#endif /* __cplusplus */
#endif

#ifndef ____FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_FWD_DEFINED__
#define ____FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_FWD_DEFINED__
typedef interface __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem;
#ifdef __cplusplus
#define __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem ABI::Windows::Foundation::Collections::IIterator<ABI::Windows::UI::Input::RadialControllerMenuItem* >
#endif /* __cplusplus */
#endif

#ifndef ____FIIterator_1_RadialControllerSystemMenuItemKind_FWD_DEFINED__
#define ____FIIterator_1_RadialControllerSystemMenuItemKind_FWD_DEFINED__
typedef interface __FIIterator_1_RadialControllerSystemMenuItemKind __FIIterator_1_RadialControllerSystemMenuItemKind;
#ifdef __cplusplus
#define __FIIterator_1_RadialControllerSystemMenuItemKind ABI::Windows::Foundation::Collections::IIterator<ABI::Windows::UI::Input::RadialControllerSystemMenuItemKind >
#endif /* __cplusplus */
#endif

#ifndef ____FIVectorView_1_Windows__CUI__CInput__CPointerPoint_FWD_DEFINED__
#define ____FIVectorView_1_Windows__CUI__CInput__CPointerPoint_FWD_DEFINED__
typedef interface __FIVectorView_1_Windows__CUI__CInput__CPointerPoint __FIVectorView_1_Windows__CUI__CInput__CPointerPoint;
#ifdef __cplusplus
#define __FIVectorView_1_Windows__CUI__CInput__CPointerPoint ABI::Windows::Foundation::Collections::IVectorView<ABI::Windows::UI::Input::PointerPoint* >
#endif /* __cplusplus */
#endif

#ifndef ____FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_FWD_DEFINED__
#define ____FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_FWD_DEFINED__
typedef interface __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem;
#ifdef __cplusplus
#define __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem ABI::Windows::Foundation::Collections::IVectorView<ABI::Windows::UI::Input::RadialControllerMenuItem* >
#endif /* __cplusplus */
#endif

#ifndef ____FIVector_1_Windows__CUI__CInput__CPointerPoint_FWD_DEFINED__
#define ____FIVector_1_Windows__CUI__CInput__CPointerPoint_FWD_DEFINED__
typedef interface __FIVector_1_Windows__CUI__CInput__CPointerPoint __FIVector_1_Windows__CUI__CInput__CPointerPoint;
#ifdef __cplusplus
#define __FIVector_1_Windows__CUI__CInput__CPointerPoint ABI::Windows::Foundation::Collections::IVector<ABI::Windows::UI::Input::PointerPoint* >
#endif /* __cplusplus */
#endif

#ifndef ____FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_FWD_DEFINED__
#define ____FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_FWD_DEFINED__
typedef interface __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem;
#ifdef __cplusplus
#define __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem ABI::Windows::Foundation::Collections::IVector<ABI::Windows::UI::Input::RadialControllerMenuItem* >
#endif /* __cplusplus */
#endif

/*****************************************************************************
 * IPointerPoint interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x10000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIPointerPoint_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIPointerPoint_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIPointerPoint, 0xe995317d, 0x7296, 0x42d9, 0x82,0x33, 0xc5,0xbe,0x73,0xb7,0x4a,0x4a);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("e995317d-7296-42d9-8233-c5be73b74a4a")
                IPointerPoint : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE get_PointerDevice(
                        ABI::Windows::Devices::Input::IPointerDevice **value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_Position(
                        ABI::Windows::Foundation::Point *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_RawPosition(
                        ABI::Windows::Foundation::Point *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_pointer_id(
                        UINT32 *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_FrameId(
                        UINT32 *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_Timestamp(
                        UINT64 *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_IsInContact(
                        boolean *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_Properties(
                        ABI::Windows::UI::Input::IPointerPointProperties **value) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIPointerPoint, 0xe995317d, 0x7296, 0x42d9, 0x82,0x33, 0xc5,0xbe,0x73,0xb7,0x4a,0x4a)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIPointerPointVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPoint *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPoint *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPoint *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPoint *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPoint *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPoint *This,
        TrustLevel *trustLevel);

    /*** IPointerPoint methods ***/
    HRESULT (STDMETHODCALLTYPE *get_PointerDevice)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPoint *This,
        __x_ABI_CWindows_CDevices_CInput_CIPointerDevice **value);

    HRESULT (STDMETHODCALLTYPE *get_Position)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPoint *This,
        __x_ABI_CWindows_CFoundation_CPoint *value);

    HRESULT (STDMETHODCALLTYPE *get_RawPosition)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPoint *This,
        __x_ABI_CWindows_CFoundation_CPoint *value);

    HRESULT (STDMETHODCALLTYPE *get_pointer_id)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPoint *This,
        UINT32 *value);

    HRESULT (STDMETHODCALLTYPE *get_FrameId)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPoint *This,
        UINT32 *value);

    HRESULT (STDMETHODCALLTYPE *get_Timestamp)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPoint *This,
        UINT64 *value);

    HRESULT (STDMETHODCALLTYPE *get_IsInContact)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPoint *This,
        boolean *value);

    HRESULT (STDMETHODCALLTYPE *get_Properties)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPoint *This,
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties **value);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIPointerPointVtbl;

interface __x_ABI_CWindows_CUI_CInput_CIPointerPoint {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIPointerPointVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIPointerPoint_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPoint_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPoint_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIPointerPoint_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPoint_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPoint_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IPointerPoint methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIPointerPoint_get_PointerDevice(This,value) (This)->lpVtbl->get_PointerDevice(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPoint_get_Position(This,value) (This)->lpVtbl->get_Position(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPoint_get_RawPosition(This,value) (This)->lpVtbl->get_RawPosition(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPoint_get_pointer_id(This,value) (This)->lpVtbl->get_pointer_id(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPoint_get_FrameId(This,value) (This)->lpVtbl->get_FrameId(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPoint_get_Timestamp(This,value) (This)->lpVtbl->get_Timestamp(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPoint_get_IsInContact(This,value) (This)->lpVtbl->get_IsInContact(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPoint_get_Properties(This,value) (This)->lpVtbl->get_Properties(This,value)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPoint_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIPointerPoint* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIPointerPoint_AddRef(__x_ABI_CWindows_CUI_CInput_CIPointerPoint* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIPointerPoint_Release(__x_ABI_CWindows_CUI_CInput_CIPointerPoint* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPoint_GetIids(__x_ABI_CWindows_CUI_CInput_CIPointerPoint* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPoint_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIPointerPoint* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPoint_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIPointerPoint* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IPointerPoint methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPoint_get_PointerDevice(__x_ABI_CWindows_CUI_CInput_CIPointerPoint* This,__x_ABI_CWindows_CDevices_CInput_CIPointerDevice **value) {
    return This->lpVtbl->get_PointerDevice(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPoint_get_Position(__x_ABI_CWindows_CUI_CInput_CIPointerPoint* This,__x_ABI_CWindows_CFoundation_CPoint *value) {
    return This->lpVtbl->get_Position(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPoint_get_RawPosition(__x_ABI_CWindows_CUI_CInput_CIPointerPoint* This,__x_ABI_CWindows_CFoundation_CPoint *value) {
    return This->lpVtbl->get_RawPosition(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPoint_get_pointer_id(__x_ABI_CWindows_CUI_CInput_CIPointerPoint* This,UINT32 *value) {
    return This->lpVtbl->get_pointer_id(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPoint_get_FrameId(__x_ABI_CWindows_CUI_CInput_CIPointerPoint* This,UINT32 *value) {
    return This->lpVtbl->get_FrameId(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPoint_get_Timestamp(__x_ABI_CWindows_CUI_CInput_CIPointerPoint* This,UINT64 *value) {
    return This->lpVtbl->get_Timestamp(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPoint_get_IsInContact(__x_ABI_CWindows_CUI_CInput_CIPointerPoint* This,boolean *value) {
    return This->lpVtbl->get_IsInContact(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPoint_get_Properties(__x_ABI_CWindows_CUI_CInput_CIPointerPoint* This,__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties **value) {
    return This->lpVtbl->get_Properties(This,value);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IPointerPoint IID___x_ABI_CWindows_CUI_CInput_CIPointerPoint
#define IPointerPointVtbl __x_ABI_CWindows_CUI_CInput_CIPointerPointVtbl
#define IPointerPoint __x_ABI_CWindows_CUI_CInput_CIPointerPoint
#define IPointerPoint_QueryInterface __x_ABI_CWindows_CUI_CInput_CIPointerPoint_QueryInterface
#define IPointerPoint_AddRef __x_ABI_CWindows_CUI_CInput_CIPointerPoint_AddRef
#define IPointerPoint_Release __x_ABI_CWindows_CUI_CInput_CIPointerPoint_Release
#define IPointerPoint_GetIids __x_ABI_CWindows_CUI_CInput_CIPointerPoint_GetIids
#define IPointerPoint_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIPointerPoint_GetRuntimeClassName
#define IPointerPoint_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIPointerPoint_GetTrustLevel
#define IPointerPoint_get_PointerDevice __x_ABI_CWindows_CUI_CInput_CIPointerPoint_get_PointerDevice
#define IPointerPoint_get_Position __x_ABI_CWindows_CUI_CInput_CIPointerPoint_get_Position
#define IPointerPoint_get_RawPosition __x_ABI_CWindows_CUI_CInput_CIPointerPoint_get_RawPosition
#define IPointerPoint_get_pointer_id __x_ABI_CWindows_CUI_CInput_CIPointerPoint_get_pointer_id
#define IPointerPoint_get_FrameId __x_ABI_CWindows_CUI_CInput_CIPointerPoint_get_FrameId
#define IPointerPoint_get_Timestamp __x_ABI_CWindows_CUI_CInput_CIPointerPoint_get_Timestamp
#define IPointerPoint_get_IsInContact __x_ABI_CWindows_CUI_CInput_CIPointerPoint_get_IsInContact
#define IPointerPoint_get_Properties __x_ABI_CWindows_CUI_CInput_CIPointerPoint_get_Properties
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIPointerPoint_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x10000 */

/*****************************************************************************
 * IPointerPointProperties interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x10000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIPointerPointProperties, 0xc79d8a4b, 0xc163, 0x4ee7, 0x80,0x3f, 0x67,0xce,0x79,0xf9,0x97,0x2d);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("c79d8a4b-c163-4ee7-803f-67ce79f9972d")
                IPointerPointProperties : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE get_Pressure(
                        FLOAT *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_IsInverted(
                        boolean *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_IsEraser(
                        boolean *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_Orientation(
                        FLOAT *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_XTilt(
                        FLOAT *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_YTilt(
                        FLOAT *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_Twist(
                        FLOAT *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_ContactRect(
                        ABI::Windows::Foundation::Rect *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_ContactRectRaw(
                        ABI::Windows::Foundation::Rect *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_TouchConfidence(
                        boolean *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_IsLeftButtonPressed(
                        boolean *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_IsRightButtonPressed(
                        boolean *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_IsMiddleButtonPressed(
                        boolean *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_MouseWheelDelta(
                        INT32 *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_IsHorizontalMouseWheel(
                        boolean *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_IsPrimary(
                        boolean *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_IsInRange(
                        boolean *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_IsCanceled(
                        boolean *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_IsBarrelButtonPressed(
                        boolean *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_IsXButton1Pressed(
                        boolean *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_IsXButton2Pressed(
                        boolean *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_PointerUpdateKind(
                        ABI::Windows::UI::Input::PointerUpdateKind *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE HasUsage(
                        UINT32 usage_page,
                        UINT32 usage_id,
                        boolean *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE GetUsageValue(
                        UINT32 usage_page,
                        UINT32 usage_id,
                        INT32 *value) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties, 0xc79d8a4b, 0xc163, 0x4ee7, 0x80,0x3f, 0x67,0xce,0x79,0xf9,0x97,0x2d)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIPointerPointPropertiesVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        TrustLevel *trustLevel);

    /*** IPointerPointProperties methods ***/
    HRESULT (STDMETHODCALLTYPE *get_Pressure)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        FLOAT *value);

    HRESULT (STDMETHODCALLTYPE *get_IsInverted)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        boolean *value);

    HRESULT (STDMETHODCALLTYPE *get_IsEraser)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        boolean *value);

    HRESULT (STDMETHODCALLTYPE *get_Orientation)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        FLOAT *value);

    HRESULT (STDMETHODCALLTYPE *get_XTilt)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        FLOAT *value);

    HRESULT (STDMETHODCALLTYPE *get_YTilt)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        FLOAT *value);

    HRESULT (STDMETHODCALLTYPE *get_Twist)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        FLOAT *value);

    HRESULT (STDMETHODCALLTYPE *get_ContactRect)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        __x_ABI_CWindows_CFoundation_CRect *value);

    HRESULT (STDMETHODCALLTYPE *get_ContactRectRaw)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        __x_ABI_CWindows_CFoundation_CRect *value);

    HRESULT (STDMETHODCALLTYPE *get_TouchConfidence)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        boolean *value);

    HRESULT (STDMETHODCALLTYPE *get_IsLeftButtonPressed)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        boolean *value);

    HRESULT (STDMETHODCALLTYPE *get_IsRightButtonPressed)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        boolean *value);

    HRESULT (STDMETHODCALLTYPE *get_IsMiddleButtonPressed)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        boolean *value);

    HRESULT (STDMETHODCALLTYPE *get_MouseWheelDelta)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        INT32 *value);

    HRESULT (STDMETHODCALLTYPE *get_IsHorizontalMouseWheel)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        boolean *value);

    HRESULT (STDMETHODCALLTYPE *get_IsPrimary)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        boolean *value);

    HRESULT (STDMETHODCALLTYPE *get_IsInRange)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        boolean *value);

    HRESULT (STDMETHODCALLTYPE *get_IsCanceled)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        boolean *value);

    HRESULT (STDMETHODCALLTYPE *get_IsBarrelButtonPressed)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        boolean *value);

    HRESULT (STDMETHODCALLTYPE *get_IsXButton1Pressed)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        boolean *value);

    HRESULT (STDMETHODCALLTYPE *get_IsXButton2Pressed)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        boolean *value);

    HRESULT (STDMETHODCALLTYPE *get_PointerUpdateKind)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        __x_ABI_CWindows_CUI_CInput_CPointerUpdateKind *value);

    HRESULT (STDMETHODCALLTYPE *HasUsage)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        UINT32 usage_page,
        UINT32 usage_id,
        boolean *value);

    HRESULT (STDMETHODCALLTYPE *GetUsageValue)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties *This,
        UINT32 usage_page,
        UINT32 usage_id,
        INT32 *value);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIPointerPointPropertiesVtbl;

interface __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIPointerPointPropertiesVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IPointerPointProperties methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_Pressure(This,value) (This)->lpVtbl->get_Pressure(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsInverted(This,value) (This)->lpVtbl->get_IsInverted(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsEraser(This,value) (This)->lpVtbl->get_IsEraser(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_Orientation(This,value) (This)->lpVtbl->get_Orientation(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_XTilt(This,value) (This)->lpVtbl->get_XTilt(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_YTilt(This,value) (This)->lpVtbl->get_YTilt(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_Twist(This,value) (This)->lpVtbl->get_Twist(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_ContactRect(This,value) (This)->lpVtbl->get_ContactRect(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_ContactRectRaw(This,value) (This)->lpVtbl->get_ContactRectRaw(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_TouchConfidence(This,value) (This)->lpVtbl->get_TouchConfidence(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsLeftButtonPressed(This,value) (This)->lpVtbl->get_IsLeftButtonPressed(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsRightButtonPressed(This,value) (This)->lpVtbl->get_IsRightButtonPressed(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsMiddleButtonPressed(This,value) (This)->lpVtbl->get_IsMiddleButtonPressed(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_MouseWheelDelta(This,value) (This)->lpVtbl->get_MouseWheelDelta(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsHorizontalMouseWheel(This,value) (This)->lpVtbl->get_IsHorizontalMouseWheel(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsPrimary(This,value) (This)->lpVtbl->get_IsPrimary(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsInRange(This,value) (This)->lpVtbl->get_IsInRange(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsCanceled(This,value) (This)->lpVtbl->get_IsCanceled(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsBarrelButtonPressed(This,value) (This)->lpVtbl->get_IsBarrelButtonPressed(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsXButton1Pressed(This,value) (This)->lpVtbl->get_IsXButton1Pressed(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsXButton2Pressed(This,value) (This)->lpVtbl->get_IsXButton2Pressed(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_PointerUpdateKind(This,value) (This)->lpVtbl->get_PointerUpdateKind(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_HasUsage(This,usage_page,usage_id,value) (This)->lpVtbl->HasUsage(This,usage_page,usage_id,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_GetUsageValue(This,usage_page,usage_id,value) (This)->lpVtbl->GetUsageValue(This,usage_page,usage_id,value)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_AddRef(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_Release(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_GetIids(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IPointerPointProperties methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_Pressure(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,FLOAT *value) {
    return This->lpVtbl->get_Pressure(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsInverted(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,boolean *value) {
    return This->lpVtbl->get_IsInverted(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsEraser(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,boolean *value) {
    return This->lpVtbl->get_IsEraser(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_Orientation(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,FLOAT *value) {
    return This->lpVtbl->get_Orientation(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_XTilt(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,FLOAT *value) {
    return This->lpVtbl->get_XTilt(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_YTilt(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,FLOAT *value) {
    return This->lpVtbl->get_YTilt(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_Twist(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,FLOAT *value) {
    return This->lpVtbl->get_Twist(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_ContactRect(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,__x_ABI_CWindows_CFoundation_CRect *value) {
    return This->lpVtbl->get_ContactRect(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_ContactRectRaw(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,__x_ABI_CWindows_CFoundation_CRect *value) {
    return This->lpVtbl->get_ContactRectRaw(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_TouchConfidence(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,boolean *value) {
    return This->lpVtbl->get_TouchConfidence(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsLeftButtonPressed(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,boolean *value) {
    return This->lpVtbl->get_IsLeftButtonPressed(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsRightButtonPressed(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,boolean *value) {
    return This->lpVtbl->get_IsRightButtonPressed(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsMiddleButtonPressed(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,boolean *value) {
    return This->lpVtbl->get_IsMiddleButtonPressed(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_MouseWheelDelta(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,INT32 *value) {
    return This->lpVtbl->get_MouseWheelDelta(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsHorizontalMouseWheel(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,boolean *value) {
    return This->lpVtbl->get_IsHorizontalMouseWheel(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsPrimary(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,boolean *value) {
    return This->lpVtbl->get_IsPrimary(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsInRange(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,boolean *value) {
    return This->lpVtbl->get_IsInRange(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsCanceled(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,boolean *value) {
    return This->lpVtbl->get_IsCanceled(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsBarrelButtonPressed(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,boolean *value) {
    return This->lpVtbl->get_IsBarrelButtonPressed(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsXButton1Pressed(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,boolean *value) {
    return This->lpVtbl->get_IsXButton1Pressed(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsXButton2Pressed(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,boolean *value) {
    return This->lpVtbl->get_IsXButton2Pressed(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_PointerUpdateKind(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,__x_ABI_CWindows_CUI_CInput_CPointerUpdateKind *value) {
    return This->lpVtbl->get_PointerUpdateKind(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_HasUsage(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,UINT32 usage_page,UINT32 usage_id,boolean *value) {
    return This->lpVtbl->HasUsage(This,usage_page,usage_id,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_GetUsageValue(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties* This,UINT32 usage_page,UINT32 usage_id,INT32 *value) {
    return This->lpVtbl->GetUsageValue(This,usage_page,usage_id,value);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IPointerPointProperties IID___x_ABI_CWindows_CUI_CInput_CIPointerPointProperties
#define IPointerPointPropertiesVtbl __x_ABI_CWindows_CUI_CInput_CIPointerPointPropertiesVtbl
#define IPointerPointProperties __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties
#define IPointerPointProperties_QueryInterface __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_QueryInterface
#define IPointerPointProperties_AddRef __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_AddRef
#define IPointerPointProperties_Release __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_Release
#define IPointerPointProperties_GetIids __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_GetIids
#define IPointerPointProperties_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_GetRuntimeClassName
#define IPointerPointProperties_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_GetTrustLevel
#define IPointerPointProperties_get_Pressure __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_Pressure
#define IPointerPointProperties_get_IsInverted __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsInverted
#define IPointerPointProperties_get_IsEraser __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsEraser
#define IPointerPointProperties_get_Orientation __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_Orientation
#define IPointerPointProperties_get_XTilt __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_XTilt
#define IPointerPointProperties_get_YTilt __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_YTilt
#define IPointerPointProperties_get_Twist __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_Twist
#define IPointerPointProperties_get_ContactRect __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_ContactRect
#define IPointerPointProperties_get_ContactRectRaw __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_ContactRectRaw
#define IPointerPointProperties_get_TouchConfidence __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_TouchConfidence
#define IPointerPointProperties_get_IsLeftButtonPressed __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsLeftButtonPressed
#define IPointerPointProperties_get_IsRightButtonPressed __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsRightButtonPressed
#define IPointerPointProperties_get_IsMiddleButtonPressed __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsMiddleButtonPressed
#define IPointerPointProperties_get_MouseWheelDelta __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_MouseWheelDelta
#define IPointerPointProperties_get_IsHorizontalMouseWheel __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsHorizontalMouseWheel
#define IPointerPointProperties_get_IsPrimary __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsPrimary
#define IPointerPointProperties_get_IsInRange __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsInRange
#define IPointerPointProperties_get_IsCanceled __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsCanceled
#define IPointerPointProperties_get_IsBarrelButtonPressed __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsBarrelButtonPressed
#define IPointerPointProperties_get_IsXButton1Pressed __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsXButton1Pressed
#define IPointerPointProperties_get_IsXButton2Pressed __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_IsXButton2Pressed
#define IPointerPointProperties_get_PointerUpdateKind __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_get_PointerUpdateKind
#define IPointerPointProperties_HasUsage __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_HasUsage
#define IPointerPointProperties_GetUsageValue __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_GetUsageValue
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIPointerPointProperties_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x10000 */

/*****************************************************************************
 * IPointerPointProperties2 interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x10000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2, 0x22c3433a, 0xc83b, 0x41c0, 0xa2,0x96, 0x5e,0x23,0x2d,0x64,0xd6,0xaf);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("22c3433a-c83b-41c0-a296-5e232d64d6af")
                IPointerPointProperties2 : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE get_ZDistance(
                        ABI::Windows::Foundation::IReference<FLOAT > **value) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2, 0x22c3433a, 0xc83b, 0x41c0, 0xa2,0x96, 0x5e,0x23,0x2d,0x64,0xd6,0xaf)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2Vtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2 *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2 *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2 *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2 *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2 *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2 *This,
        TrustLevel *trustLevel);

    /*** IPointerPointProperties2 methods ***/
    HRESULT (STDMETHODCALLTYPE *get_ZDistance)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2 *This,
        __FIReference_1_FLOAT **value);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2Vtbl;

interface __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2 {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2Vtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IPointerPointProperties2 methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_get_ZDistance(This,value) (This)->lpVtbl->get_ZDistance(This,value)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_AddRef(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_Release(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_GetIids(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IPointerPointProperties2 methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_get_ZDistance(__x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2* This,__FIReference_1_FLOAT **value) {
    return This->lpVtbl->get_ZDistance(This,value);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IPointerPointProperties2 IID___x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2
#define IPointerPointProperties2Vtbl __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2Vtbl
#define IPointerPointProperties2 __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2
#define IPointerPointProperties2_QueryInterface __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_QueryInterface
#define IPointerPointProperties2_AddRef __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_AddRef
#define IPointerPointProperties2_Release __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_Release
#define IPointerPointProperties2_GetIids __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_GetIids
#define IPointerPointProperties2_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_GetRuntimeClassName
#define IPointerPointProperties2_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_GetTrustLevel
#define IPointerPointProperties2_get_ZDistance __x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_get_ZDistance
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIPointerPointProperties2_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x10000 */

/*****************************************************************************
 * IPointerPointStatics interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x10000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIPointerPointStatics, 0xa506638d, 0x2a1a, 0x413e, 0xbc,0x75, 0x9f,0x38,0x38,0x1c,0xc0,0x69);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("a506638d-2a1a-413e-bc75-9f38381cc069")
                IPointerPointStatics : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE GetCurrentPoint(
                        UINT32 pointer_id,
                        ABI::Windows::UI::Input::IPointerPoint **point) = 0;

                    virtual HRESULT STDMETHODCALLTYPE GetIntermediatePoints(
                        UINT32 pointer_id,
                        ABI::Windows::Foundation::Collections::IVector<ABI::Windows::UI::Input::PointerPoint* > **points) = 0;

                    virtual HRESULT STDMETHODCALLTYPE GetCurrentPointTransformed(
                        UINT32 pointer_id,
                        ABI::Windows::UI::Input::IPointerPointTransform *transform,
                        ABI::Windows::UI::Input::IPointerPoint **point) = 0;

                    virtual HRESULT STDMETHODCALLTYPE GetIntermediatePointsTransformed(
                        UINT32 pointer_id,
                        ABI::Windows::UI::Input::IPointerPointTransform *transform,
                        ABI::Windows::Foundation::Collections::IVector<ABI::Windows::UI::Input::PointerPoint* > **points) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIPointerPointStatics, 0xa506638d, 0x2a1a, 0x413e, 0xbc,0x75, 0x9f,0x38,0x38,0x1c,0xc0,0x69)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIPointerPointStaticsVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics *This,
        TrustLevel *trustLevel);

    /*** IPointerPointStatics methods ***/
    HRESULT (STDMETHODCALLTYPE *GetCurrentPoint)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics *This,
        UINT32 pointer_id,
        __x_ABI_CWindows_CUI_CInput_CIPointerPoint **point);

    HRESULT (STDMETHODCALLTYPE *GetIntermediatePoints)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics *This,
        UINT32 pointer_id,
        __FIVector_1_Windows__CUI__CInput__CPointerPoint **points);

    HRESULT (STDMETHODCALLTYPE *GetCurrentPointTransformed)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics *This,
        UINT32 pointer_id,
        __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform *transform,
        __x_ABI_CWindows_CUI_CInput_CIPointerPoint **point);

    HRESULT (STDMETHODCALLTYPE *GetIntermediatePointsTransformed)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics *This,
        UINT32 pointer_id,
        __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform *transform,
        __FIVector_1_Windows__CUI__CInput__CPointerPoint **points);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIPointerPointStaticsVtbl;

interface __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIPointerPointStaticsVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IPointerPointStatics methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_GetCurrentPoint(This,pointer_id,point) (This)->lpVtbl->GetCurrentPoint(This,pointer_id,point)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_GetIntermediatePoints(This,pointer_id,points) (This)->lpVtbl->GetIntermediatePoints(This,pointer_id,points)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_GetCurrentPointTransformed(This,pointer_id,transform,point) (This)->lpVtbl->GetCurrentPointTransformed(This,pointer_id,transform,point)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_GetIntermediatePointsTransformed(This,pointer_id,transform,points) (This)->lpVtbl->GetIntermediatePointsTransformed(This,pointer_id,transform,points)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIPointerPointStatics* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_AddRef(__x_ABI_CWindows_CUI_CInput_CIPointerPointStatics* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_Release(__x_ABI_CWindows_CUI_CInput_CIPointerPointStatics* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_GetIids(__x_ABI_CWindows_CUI_CInput_CIPointerPointStatics* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIPointerPointStatics* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIPointerPointStatics* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IPointerPointStatics methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_GetCurrentPoint(__x_ABI_CWindows_CUI_CInput_CIPointerPointStatics* This,UINT32 pointer_id,__x_ABI_CWindows_CUI_CInput_CIPointerPoint **point) {
    return This->lpVtbl->GetCurrentPoint(This,pointer_id,point);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_GetIntermediatePoints(__x_ABI_CWindows_CUI_CInput_CIPointerPointStatics* This,UINT32 pointer_id,__FIVector_1_Windows__CUI__CInput__CPointerPoint **points) {
    return This->lpVtbl->GetIntermediatePoints(This,pointer_id,points);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_GetCurrentPointTransformed(__x_ABI_CWindows_CUI_CInput_CIPointerPointStatics* This,UINT32 pointer_id,__x_ABI_CWindows_CUI_CInput_CIPointerPointTransform *transform,__x_ABI_CWindows_CUI_CInput_CIPointerPoint **point) {
    return This->lpVtbl->GetCurrentPointTransformed(This,pointer_id,transform,point);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_GetIntermediatePointsTransformed(__x_ABI_CWindows_CUI_CInput_CIPointerPointStatics* This,UINT32 pointer_id,__x_ABI_CWindows_CUI_CInput_CIPointerPointTransform *transform,__FIVector_1_Windows__CUI__CInput__CPointerPoint **points) {
    return This->lpVtbl->GetIntermediatePointsTransformed(This,pointer_id,transform,points);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IPointerPointStatics IID___x_ABI_CWindows_CUI_CInput_CIPointerPointStatics
#define IPointerPointStaticsVtbl __x_ABI_CWindows_CUI_CInput_CIPointerPointStaticsVtbl
#define IPointerPointStatics __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics
#define IPointerPointStatics_QueryInterface __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_QueryInterface
#define IPointerPointStatics_AddRef __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_AddRef
#define IPointerPointStatics_Release __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_Release
#define IPointerPointStatics_GetIids __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_GetIids
#define IPointerPointStatics_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_GetRuntimeClassName
#define IPointerPointStatics_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_GetTrustLevel
#define IPointerPointStatics_GetCurrentPoint __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_GetCurrentPoint
#define IPointerPointStatics_GetIntermediatePoints __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_GetIntermediatePoints
#define IPointerPointStatics_GetCurrentPointTransformed __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_GetCurrentPointTransformed
#define IPointerPointStatics_GetIntermediatePointsTransformed __x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_GetIntermediatePointsTransformed
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIPointerPointStatics_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x10000 */

/*****************************************************************************
 * IPointerPointTransform interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x10000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIPointerPointTransform, 0x4d5fe14f, 0xb87c, 0x4028, 0xbc,0x9c, 0x59,0xe9,0x94,0x7f,0xb0,0x56);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("4d5fe14f-b87c-4028-bc9c-59e9947fb056")
                IPointerPointTransform : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE get_Inverse(
                        ABI::Windows::UI::Input::IPointerPointTransform **value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE TryTransform(
                        ABI::Windows::Foundation::Point in_point,
                        ABI::Windows::Foundation::Point *out_point,
                        boolean *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE TransformBounds(
                        ABI::Windows::Foundation::Rect rect,
                        ABI::Windows::Foundation::Rect *value) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIPointerPointTransform, 0x4d5fe14f, 0xb87c, 0x4028, 0xbc,0x9c, 0x59,0xe9,0x94,0x7f,0xb0,0x56)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIPointerPointTransformVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform *This,
        TrustLevel *trustLevel);

    /*** IPointerPointTransform methods ***/
    HRESULT (STDMETHODCALLTYPE *get_Inverse)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform *This,
        __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform **value);

    HRESULT (STDMETHODCALLTYPE *TryTransform)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform *This,
        __x_ABI_CWindows_CFoundation_CPoint in_point,
        __x_ABI_CWindows_CFoundation_CPoint *out_point,
        boolean *value);

    HRESULT (STDMETHODCALLTYPE *TransformBounds)(
        __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform *This,
        __x_ABI_CWindows_CFoundation_CRect rect,
        __x_ABI_CWindows_CFoundation_CRect *value);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIPointerPointTransformVtbl;

interface __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIPointerPointTransformVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IPointerPointTransform methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_get_Inverse(This,value) (This)->lpVtbl->get_Inverse(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_TryTransform(This,in_point,out_point,value) (This)->lpVtbl->TryTransform(This,in_point,out_point,value)
#define __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_TransformBounds(This,rect,value) (This)->lpVtbl->TransformBounds(This,rect,value)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIPointerPointTransform* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_AddRef(__x_ABI_CWindows_CUI_CInput_CIPointerPointTransform* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_Release(__x_ABI_CWindows_CUI_CInput_CIPointerPointTransform* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_GetIids(__x_ABI_CWindows_CUI_CInput_CIPointerPointTransform* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIPointerPointTransform* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIPointerPointTransform* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IPointerPointTransform methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_get_Inverse(__x_ABI_CWindows_CUI_CInput_CIPointerPointTransform* This,__x_ABI_CWindows_CUI_CInput_CIPointerPointTransform **value) {
    return This->lpVtbl->get_Inverse(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_TryTransform(__x_ABI_CWindows_CUI_CInput_CIPointerPointTransform* This,__x_ABI_CWindows_CFoundation_CPoint in_point,__x_ABI_CWindows_CFoundation_CPoint *out_point,boolean *value) {
    return This->lpVtbl->TryTransform(This,in_point,out_point,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_TransformBounds(__x_ABI_CWindows_CUI_CInput_CIPointerPointTransform* This,__x_ABI_CWindows_CFoundation_CRect rect,__x_ABI_CWindows_CFoundation_CRect *value) {
    return This->lpVtbl->TransformBounds(This,rect,value);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IPointerPointTransform IID___x_ABI_CWindows_CUI_CInput_CIPointerPointTransform
#define IPointerPointTransformVtbl __x_ABI_CWindows_CUI_CInput_CIPointerPointTransformVtbl
#define IPointerPointTransform __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform
#define IPointerPointTransform_QueryInterface __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_QueryInterface
#define IPointerPointTransform_AddRef __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_AddRef
#define IPointerPointTransform_Release __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_Release
#define IPointerPointTransform_GetIids __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_GetIids
#define IPointerPointTransform_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_GetRuntimeClassName
#define IPointerPointTransform_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_GetTrustLevel
#define IPointerPointTransform_get_Inverse __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_get_Inverse
#define IPointerPointTransform_TryTransform __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_TryTransform
#define IPointerPointTransform_TransformBounds __x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_TransformBounds
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIPointerPointTransform_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x10000 */

/*****************************************************************************
 * IRadialController interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialController_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialController_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIRadialController, 0x3055d1c8, 0xdf51, 0x43d4, 0xb2,0x3b, 0x0e,0x10,0x37,0x46,0x7a,0x09);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("3055d1c8-df51-43d4-b23b-0e1037467a09")
                IRadialController : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE get_Menu(
                        ABI::Windows::UI::Input::IRadialControllerMenu **value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_RotationResolutionInDegrees(
                        DOUBLE *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE put_RotationResolutionInDegrees(
                        DOUBLE value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_UseAutomaticHapticFeedback(
                        boolean *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE put_UseAutomaticHapticFeedback(
                        boolean value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE add_ScreenContactStarted(
                        ABI::Windows::Foundation::ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerScreenContactStartedEventArgs* > *handler,
                        EventRegistrationToken *cookie) = 0;

                    virtual HRESULT STDMETHODCALLTYPE remove_ScreenContactStarted(
                        EventRegistrationToken cookie) = 0;

                    virtual HRESULT STDMETHODCALLTYPE add_ScreenContactEnded(
                        ABI::Windows::Foundation::ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,IInspectable* > *handler,
                        EventRegistrationToken *cookie) = 0;

                    virtual HRESULT STDMETHODCALLTYPE remove_ScreenContactEnded(
                        EventRegistrationToken cookie) = 0;

                    virtual HRESULT STDMETHODCALLTYPE add_ScreenContactContinued(
                        ABI::Windows::Foundation::ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerScreenContactContinuedEventArgs* > *handler,
                        EventRegistrationToken *cookie) = 0;

                    virtual HRESULT STDMETHODCALLTYPE remove_ScreenContactContinued(
                        EventRegistrationToken cookie) = 0;

                    virtual HRESULT STDMETHODCALLTYPE add_ControlLost(
                        ABI::Windows::Foundation::ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,IInspectable* > *handler,
                        EventRegistrationToken *cookie) = 0;

                    virtual HRESULT STDMETHODCALLTYPE remove_ControlLost(
                        EventRegistrationToken cookie) = 0;

                    virtual HRESULT STDMETHODCALLTYPE add_RotationChanged(
                        ABI::Windows::Foundation::ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerRotationChangedEventArgs* > *handler,
                        EventRegistrationToken *token) = 0;

                    virtual HRESULT STDMETHODCALLTYPE remove_RotationChanged(
                        EventRegistrationToken token) = 0;

                    virtual HRESULT STDMETHODCALLTYPE add_ButtonClicked(
                        ABI::Windows::Foundation::ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonClickedEventArgs* > *handler,
                        EventRegistrationToken *token) = 0;

                    virtual HRESULT STDMETHODCALLTYPE remove_ButtonClicked(
                        EventRegistrationToken token) = 0;

                    virtual HRESULT STDMETHODCALLTYPE add_ControlAcquired(
                        ABI::Windows::Foundation::ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerControlAcquiredEventArgs* > *handler,
                        EventRegistrationToken *cookie) = 0;

                    virtual HRESULT STDMETHODCALLTYPE remove_ControlAcquired(
                        EventRegistrationToken cookie) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIRadialController, 0x3055d1c8, 0xdf51, 0x43d4, 0xb2,0x3b, 0x0e,0x10,0x37,0x46,0x7a,0x09)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIRadialControllerVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController *This,
        TrustLevel *trustLevel);

    /*** IRadialController methods ***/
    HRESULT (STDMETHODCALLTYPE *get_Menu)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu **value);

    HRESULT (STDMETHODCALLTYPE *get_RotationResolutionInDegrees)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController *This,
        DOUBLE *value);

    HRESULT (STDMETHODCALLTYPE *put_RotationResolutionInDegrees)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController *This,
        DOUBLE value);

    HRESULT (STDMETHODCALLTYPE *get_UseAutomaticHapticFeedback)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController *This,
        boolean *value);

    HRESULT (STDMETHODCALLTYPE *put_UseAutomaticHapticFeedback)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController *This,
        boolean value);

    HRESULT (STDMETHODCALLTYPE *add_ScreenContactStarted)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController *This,
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs *handler,
        EventRegistrationToken *cookie);

    HRESULT (STDMETHODCALLTYPE *remove_ScreenContactStarted)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController *This,
        EventRegistrationToken cookie);

    HRESULT (STDMETHODCALLTYPE *add_ScreenContactEnded)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController *This,
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable *handler,
        EventRegistrationToken *cookie);

    HRESULT (STDMETHODCALLTYPE *remove_ScreenContactEnded)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController *This,
        EventRegistrationToken cookie);

    HRESULT (STDMETHODCALLTYPE *add_ScreenContactContinued)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController *This,
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs *handler,
        EventRegistrationToken *cookie);

    HRESULT (STDMETHODCALLTYPE *remove_ScreenContactContinued)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController *This,
        EventRegistrationToken cookie);

    HRESULT (STDMETHODCALLTYPE *add_ControlLost)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController *This,
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable *handler,
        EventRegistrationToken *cookie);

    HRESULT (STDMETHODCALLTYPE *remove_ControlLost)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController *This,
        EventRegistrationToken cookie);

    HRESULT (STDMETHODCALLTYPE *add_RotationChanged)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController *This,
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs *handler,
        EventRegistrationToken *token);

    HRESULT (STDMETHODCALLTYPE *remove_RotationChanged)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController *This,
        EventRegistrationToken token);

    HRESULT (STDMETHODCALLTYPE *add_ButtonClicked)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController *This,
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs *handler,
        EventRegistrationToken *token);

    HRESULT (STDMETHODCALLTYPE *remove_ButtonClicked)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController *This,
        EventRegistrationToken token);

    HRESULT (STDMETHODCALLTYPE *add_ControlAcquired)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController *This,
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs *handler,
        EventRegistrationToken *cookie);

    HRESULT (STDMETHODCALLTYPE *remove_ControlAcquired)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController *This,
        EventRegistrationToken cookie);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIRadialControllerVtbl;

interface __x_ABI_CWindows_CUI_CInput_CIRadialController {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIRadialControllerVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialController_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialController_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IRadialController methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialController_get_Menu(This,value) (This)->lpVtbl->get_Menu(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController_get_RotationResolutionInDegrees(This,value) (This)->lpVtbl->get_RotationResolutionInDegrees(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController_put_RotationResolutionInDegrees(This,value) (This)->lpVtbl->put_RotationResolutionInDegrees(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController_get_UseAutomaticHapticFeedback(This,value) (This)->lpVtbl->get_UseAutomaticHapticFeedback(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController_put_UseAutomaticHapticFeedback(This,value) (This)->lpVtbl->put_UseAutomaticHapticFeedback(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController_add_ScreenContactStarted(This,handler,cookie) (This)->lpVtbl->add_ScreenContactStarted(This,handler,cookie)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController_remove_ScreenContactStarted(This,cookie) (This)->lpVtbl->remove_ScreenContactStarted(This,cookie)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController_add_ScreenContactEnded(This,handler,cookie) (This)->lpVtbl->add_ScreenContactEnded(This,handler,cookie)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController_remove_ScreenContactEnded(This,cookie) (This)->lpVtbl->remove_ScreenContactEnded(This,cookie)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController_add_ScreenContactContinued(This,handler,cookie) (This)->lpVtbl->add_ScreenContactContinued(This,handler,cookie)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController_remove_ScreenContactContinued(This,cookie) (This)->lpVtbl->remove_ScreenContactContinued(This,cookie)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController_add_ControlLost(This,handler,cookie) (This)->lpVtbl->add_ControlLost(This,handler,cookie)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController_remove_ControlLost(This,cookie) (This)->lpVtbl->remove_ControlLost(This,cookie)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController_add_RotationChanged(This,handler,token) (This)->lpVtbl->add_RotationChanged(This,handler,token)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController_remove_RotationChanged(This,token) (This)->lpVtbl->remove_RotationChanged(This,token)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController_add_ButtonClicked(This,handler,token) (This)->lpVtbl->add_ButtonClicked(This,handler,token)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController_remove_ButtonClicked(This,token) (This)->lpVtbl->remove_ButtonClicked(This,token)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController_add_ControlAcquired(This,handler,cookie) (This)->lpVtbl->add_ControlAcquired(This,handler,cookie)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController_remove_ControlAcquired(This,cookie) (This)->lpVtbl->remove_ControlAcquired(This,cookie)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIRadialController* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialController_AddRef(__x_ABI_CWindows_CUI_CInput_CIRadialController* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialController_Release(__x_ABI_CWindows_CUI_CInput_CIRadialController* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController_GetIids(__x_ABI_CWindows_CUI_CInput_CIRadialController* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIRadialController* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIRadialController* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IRadialController methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController_get_Menu(__x_ABI_CWindows_CUI_CInput_CIRadialController* This,__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu **value) {
    return This->lpVtbl->get_Menu(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController_get_RotationResolutionInDegrees(__x_ABI_CWindows_CUI_CInput_CIRadialController* This,DOUBLE *value) {
    return This->lpVtbl->get_RotationResolutionInDegrees(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController_put_RotationResolutionInDegrees(__x_ABI_CWindows_CUI_CInput_CIRadialController* This,DOUBLE value) {
    return This->lpVtbl->put_RotationResolutionInDegrees(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController_get_UseAutomaticHapticFeedback(__x_ABI_CWindows_CUI_CInput_CIRadialController* This,boolean *value) {
    return This->lpVtbl->get_UseAutomaticHapticFeedback(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController_put_UseAutomaticHapticFeedback(__x_ABI_CWindows_CUI_CInput_CIRadialController* This,boolean value) {
    return This->lpVtbl->put_UseAutomaticHapticFeedback(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController_add_ScreenContactStarted(__x_ABI_CWindows_CUI_CInput_CIRadialController* This,__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs *handler,EventRegistrationToken *cookie) {
    return This->lpVtbl->add_ScreenContactStarted(This,handler,cookie);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController_remove_ScreenContactStarted(__x_ABI_CWindows_CUI_CInput_CIRadialController* This,EventRegistrationToken cookie) {
    return This->lpVtbl->remove_ScreenContactStarted(This,cookie);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController_add_ScreenContactEnded(__x_ABI_CWindows_CUI_CInput_CIRadialController* This,__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable *handler,EventRegistrationToken *cookie) {
    return This->lpVtbl->add_ScreenContactEnded(This,handler,cookie);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController_remove_ScreenContactEnded(__x_ABI_CWindows_CUI_CInput_CIRadialController* This,EventRegistrationToken cookie) {
    return This->lpVtbl->remove_ScreenContactEnded(This,cookie);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController_add_ScreenContactContinued(__x_ABI_CWindows_CUI_CInput_CIRadialController* This,__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs *handler,EventRegistrationToken *cookie) {
    return This->lpVtbl->add_ScreenContactContinued(This,handler,cookie);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController_remove_ScreenContactContinued(__x_ABI_CWindows_CUI_CInput_CIRadialController* This,EventRegistrationToken cookie) {
    return This->lpVtbl->remove_ScreenContactContinued(This,cookie);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController_add_ControlLost(__x_ABI_CWindows_CUI_CInput_CIRadialController* This,__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable *handler,EventRegistrationToken *cookie) {
    return This->lpVtbl->add_ControlLost(This,handler,cookie);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController_remove_ControlLost(__x_ABI_CWindows_CUI_CInput_CIRadialController* This,EventRegistrationToken cookie) {
    return This->lpVtbl->remove_ControlLost(This,cookie);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController_add_RotationChanged(__x_ABI_CWindows_CUI_CInput_CIRadialController* This,__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs *handler,EventRegistrationToken *token) {
    return This->lpVtbl->add_RotationChanged(This,handler,token);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController_remove_RotationChanged(__x_ABI_CWindows_CUI_CInput_CIRadialController* This,EventRegistrationToken token) {
    return This->lpVtbl->remove_RotationChanged(This,token);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController_add_ButtonClicked(__x_ABI_CWindows_CUI_CInput_CIRadialController* This,__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs *handler,EventRegistrationToken *token) {
    return This->lpVtbl->add_ButtonClicked(This,handler,token);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController_remove_ButtonClicked(__x_ABI_CWindows_CUI_CInput_CIRadialController* This,EventRegistrationToken token) {
    return This->lpVtbl->remove_ButtonClicked(This,token);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController_add_ControlAcquired(__x_ABI_CWindows_CUI_CInput_CIRadialController* This,__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs *handler,EventRegistrationToken *cookie) {
    return This->lpVtbl->add_ControlAcquired(This,handler,cookie);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController_remove_ControlAcquired(__x_ABI_CWindows_CUI_CInput_CIRadialController* This,EventRegistrationToken cookie) {
    return This->lpVtbl->remove_ControlAcquired(This,cookie);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IRadialController IID___x_ABI_CWindows_CUI_CInput_CIRadialController
#define IRadialControllerVtbl __x_ABI_CWindows_CUI_CInput_CIRadialControllerVtbl
#define IRadialController __x_ABI_CWindows_CUI_CInput_CIRadialController
#define IRadialController_QueryInterface __x_ABI_CWindows_CUI_CInput_CIRadialController_QueryInterface
#define IRadialController_AddRef __x_ABI_CWindows_CUI_CInput_CIRadialController_AddRef
#define IRadialController_Release __x_ABI_CWindows_CUI_CInput_CIRadialController_Release
#define IRadialController_GetIids __x_ABI_CWindows_CUI_CInput_CIRadialController_GetIids
#define IRadialController_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIRadialController_GetRuntimeClassName
#define IRadialController_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIRadialController_GetTrustLevel
#define IRadialController_get_Menu __x_ABI_CWindows_CUI_CInput_CIRadialController_get_Menu
#define IRadialController_get_RotationResolutionInDegrees __x_ABI_CWindows_CUI_CInput_CIRadialController_get_RotationResolutionInDegrees
#define IRadialController_put_RotationResolutionInDegrees __x_ABI_CWindows_CUI_CInput_CIRadialController_put_RotationResolutionInDegrees
#define IRadialController_get_UseAutomaticHapticFeedback __x_ABI_CWindows_CUI_CInput_CIRadialController_get_UseAutomaticHapticFeedback
#define IRadialController_put_UseAutomaticHapticFeedback __x_ABI_CWindows_CUI_CInput_CIRadialController_put_UseAutomaticHapticFeedback
#define IRadialController_add_ScreenContactStarted __x_ABI_CWindows_CUI_CInput_CIRadialController_add_ScreenContactStarted
#define IRadialController_remove_ScreenContactStarted __x_ABI_CWindows_CUI_CInput_CIRadialController_remove_ScreenContactStarted
#define IRadialController_add_ScreenContactEnded __x_ABI_CWindows_CUI_CInput_CIRadialController_add_ScreenContactEnded
#define IRadialController_remove_ScreenContactEnded __x_ABI_CWindows_CUI_CInput_CIRadialController_remove_ScreenContactEnded
#define IRadialController_add_ScreenContactContinued __x_ABI_CWindows_CUI_CInput_CIRadialController_add_ScreenContactContinued
#define IRadialController_remove_ScreenContactContinued __x_ABI_CWindows_CUI_CInput_CIRadialController_remove_ScreenContactContinued
#define IRadialController_add_ControlLost __x_ABI_CWindows_CUI_CInput_CIRadialController_add_ControlLost
#define IRadialController_remove_ControlLost __x_ABI_CWindows_CUI_CInput_CIRadialController_remove_ControlLost
#define IRadialController_add_RotationChanged __x_ABI_CWindows_CUI_CInput_CIRadialController_add_RotationChanged
#define IRadialController_remove_RotationChanged __x_ABI_CWindows_CUI_CInput_CIRadialController_remove_RotationChanged
#define IRadialController_add_ButtonClicked __x_ABI_CWindows_CUI_CInput_CIRadialController_add_ButtonClicked
#define IRadialController_remove_ButtonClicked __x_ABI_CWindows_CUI_CInput_CIRadialController_remove_ButtonClicked
#define IRadialController_add_ControlAcquired __x_ABI_CWindows_CUI_CInput_CIRadialController_add_ControlAcquired
#define IRadialController_remove_ControlAcquired __x_ABI_CWindows_CUI_CInput_CIRadialController_remove_ControlAcquired
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIRadialController_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000 */

/*****************************************************************************
 * IRadialController2 interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x40000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialController2_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialController2_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIRadialController2, 0x3d577eff, 0x4cee, 0x11e6, 0xb5,0x35, 0x00,0x1b,0xdc,0x06,0xab,0x3b);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("3d577eff-4cee-11e6-b535-001bdc06ab3b")
                IRadialController2 : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE add_ButtonPressed(
                        ABI::Windows::Foundation::ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonPressedEventArgs* > *handler,
                        EventRegistrationToken *token) = 0;

                    virtual HRESULT STDMETHODCALLTYPE remove_ButtonPressed(
                        EventRegistrationToken token) = 0;

                    virtual HRESULT STDMETHODCALLTYPE add_ButtonHolding(
                        ABI::Windows::Foundation::ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonHoldingEventArgs* > *handler,
                        EventRegistrationToken *token) = 0;

                    virtual HRESULT STDMETHODCALLTYPE remove_ButtonHolding(
                        EventRegistrationToken token) = 0;

                    virtual HRESULT STDMETHODCALLTYPE add_ButtonReleased(
                        ABI::Windows::Foundation::ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonReleasedEventArgs* > *handler,
                        EventRegistrationToken *token) = 0;

                    virtual HRESULT STDMETHODCALLTYPE remove_ButtonReleased(
                        EventRegistrationToken token) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIRadialController2, 0x3d577eff, 0x4cee, 0x11e6, 0xb5,0x35, 0x00,0x1b,0xdc,0x06,0xab,0x3b)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIRadialController2Vtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController2 *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController2 *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController2 *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController2 *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController2 *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController2 *This,
        TrustLevel *trustLevel);

    /*** IRadialController2 methods ***/
    HRESULT (STDMETHODCALLTYPE *add_ButtonPressed)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController2 *This,
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs *handler,
        EventRegistrationToken *token);

    HRESULT (STDMETHODCALLTYPE *remove_ButtonPressed)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController2 *This,
        EventRegistrationToken token);

    HRESULT (STDMETHODCALLTYPE *add_ButtonHolding)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController2 *This,
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs *handler,
        EventRegistrationToken *token);

    HRESULT (STDMETHODCALLTYPE *remove_ButtonHolding)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController2 *This,
        EventRegistrationToken token);

    HRESULT (STDMETHODCALLTYPE *add_ButtonReleased)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController2 *This,
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs *handler,
        EventRegistrationToken *token);

    HRESULT (STDMETHODCALLTYPE *remove_ButtonReleased)(
        __x_ABI_CWindows_CUI_CInput_CIRadialController2 *This,
        EventRegistrationToken token);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIRadialController2Vtbl;

interface __x_ABI_CWindows_CUI_CInput_CIRadialController2 {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIRadialController2Vtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialController2_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController2_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController2_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialController2_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController2_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController2_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IRadialController2 methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialController2_add_ButtonPressed(This,handler,token) (This)->lpVtbl->add_ButtonPressed(This,handler,token)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController2_remove_ButtonPressed(This,token) (This)->lpVtbl->remove_ButtonPressed(This,token)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController2_add_ButtonHolding(This,handler,token) (This)->lpVtbl->add_ButtonHolding(This,handler,token)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController2_remove_ButtonHolding(This,token) (This)->lpVtbl->remove_ButtonHolding(This,token)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController2_add_ButtonReleased(This,handler,token) (This)->lpVtbl->add_ButtonReleased(This,handler,token)
#define __x_ABI_CWindows_CUI_CInput_CIRadialController2_remove_ButtonReleased(This,token) (This)->lpVtbl->remove_ButtonReleased(This,token)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController2_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIRadialController2* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialController2_AddRef(__x_ABI_CWindows_CUI_CInput_CIRadialController2* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialController2_Release(__x_ABI_CWindows_CUI_CInput_CIRadialController2* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController2_GetIids(__x_ABI_CWindows_CUI_CInput_CIRadialController2* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController2_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIRadialController2* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController2_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIRadialController2* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IRadialController2 methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController2_add_ButtonPressed(__x_ABI_CWindows_CUI_CInput_CIRadialController2* This,__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs *handler,EventRegistrationToken *token) {
    return This->lpVtbl->add_ButtonPressed(This,handler,token);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController2_remove_ButtonPressed(__x_ABI_CWindows_CUI_CInput_CIRadialController2* This,EventRegistrationToken token) {
    return This->lpVtbl->remove_ButtonPressed(This,token);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController2_add_ButtonHolding(__x_ABI_CWindows_CUI_CInput_CIRadialController2* This,__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs *handler,EventRegistrationToken *token) {
    return This->lpVtbl->add_ButtonHolding(This,handler,token);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController2_remove_ButtonHolding(__x_ABI_CWindows_CUI_CInput_CIRadialController2* This,EventRegistrationToken token) {
    return This->lpVtbl->remove_ButtonHolding(This,token);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController2_add_ButtonReleased(__x_ABI_CWindows_CUI_CInput_CIRadialController2* This,__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs *handler,EventRegistrationToken *token) {
    return This->lpVtbl->add_ButtonReleased(This,handler,token);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialController2_remove_ButtonReleased(__x_ABI_CWindows_CUI_CInput_CIRadialController2* This,EventRegistrationToken token) {
    return This->lpVtbl->remove_ButtonReleased(This,token);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IRadialController2 IID___x_ABI_CWindows_CUI_CInput_CIRadialController2
#define IRadialController2Vtbl __x_ABI_CWindows_CUI_CInput_CIRadialController2Vtbl
#define IRadialController2 __x_ABI_CWindows_CUI_CInput_CIRadialController2
#define IRadialController2_QueryInterface __x_ABI_CWindows_CUI_CInput_CIRadialController2_QueryInterface
#define IRadialController2_AddRef __x_ABI_CWindows_CUI_CInput_CIRadialController2_AddRef
#define IRadialController2_Release __x_ABI_CWindows_CUI_CInput_CIRadialController2_Release
#define IRadialController2_GetIids __x_ABI_CWindows_CUI_CInput_CIRadialController2_GetIids
#define IRadialController2_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIRadialController2_GetRuntimeClassName
#define IRadialController2_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIRadialController2_GetTrustLevel
#define IRadialController2_add_ButtonPressed __x_ABI_CWindows_CUI_CInput_CIRadialController2_add_ButtonPressed
#define IRadialController2_remove_ButtonPressed __x_ABI_CWindows_CUI_CInput_CIRadialController2_remove_ButtonPressed
#define IRadialController2_add_ButtonHolding __x_ABI_CWindows_CUI_CInput_CIRadialController2_add_ButtonHolding
#define IRadialController2_remove_ButtonHolding __x_ABI_CWindows_CUI_CInput_CIRadialController2_remove_ButtonHolding
#define IRadialController2_add_ButtonReleased __x_ABI_CWindows_CUI_CInput_CIRadialController2_add_ButtonReleased
#define IRadialController2_remove_ButtonReleased __x_ABI_CWindows_CUI_CInput_CIRadialController2_remove_ButtonReleased
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIRadialController2_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x40000 */

/*****************************************************************************
 * IRadialControllerButtonClickedEventArgs interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs, 0x206aa438, 0xe651, 0x11e5, 0xbf,0x62, 0x2c,0x27,0xd7,0x40,0x4e,0x85);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("206aa438-e651-11e5-bf62-2c27d7404e85")
                IRadialControllerButtonClickedEventArgs : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE get_Contact(
                        ABI::Windows::UI::Input::IRadialControllerScreenContact **value) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs, 0x206aa438, 0xe651, 0x11e5, 0xbf,0x62, 0x2c,0x27,0xd7,0x40,0x4e,0x85)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgsVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs *This,
        TrustLevel *trustLevel);

    /*** IRadialControllerButtonClickedEventArgs methods ***/
    HRESULT (STDMETHODCALLTYPE *get_Contact)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact **value);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgsVtbl;

interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgsVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IRadialControllerButtonClickedEventArgs methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_get_Contact(This,value) (This)->lpVtbl->get_Contact(This,value)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_AddRef(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_Release(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_GetIids(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IRadialControllerButtonClickedEventArgs methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_get_Contact(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs* This,__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact **value) {
    return This->lpVtbl->get_Contact(This,value);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IRadialControllerButtonClickedEventArgs IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs
#define IRadialControllerButtonClickedEventArgsVtbl __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgsVtbl
#define IRadialControllerButtonClickedEventArgs __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs
#define IRadialControllerButtonClickedEventArgs_QueryInterface __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_QueryInterface
#define IRadialControllerButtonClickedEventArgs_AddRef __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_AddRef
#define IRadialControllerButtonClickedEventArgs_Release __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_Release
#define IRadialControllerButtonClickedEventArgs_GetIids __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_GetIids
#define IRadialControllerButtonClickedEventArgs_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_GetRuntimeClassName
#define IRadialControllerButtonClickedEventArgs_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_GetTrustLevel
#define IRadialControllerButtonClickedEventArgs_get_Contact __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_get_Contact
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000 */

/*****************************************************************************
 * IRadialControllerButtonClickedEventArgs2 interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x40000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2, 0x3d577ef3, 0x3cee, 0x11e6, 0xb5,0x35, 0x00,0x1b,0xdc,0x06,0xab,0x3b);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("3d577ef3-3cee-11e6-b535-001bdc06ab3b")
                IRadialControllerButtonClickedEventArgs2 : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE get_SimpleHapticsController(
                        ABI::Windows::Devices::Haptics::ISimpleHapticsController **value) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2, 0x3d577ef3, 0x3cee, 0x11e6, 0xb5,0x35, 0x00,0x1b,0xdc,0x06,0xab,0x3b)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2Vtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2 *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2 *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2 *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2 *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2 *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2 *This,
        TrustLevel *trustLevel);

    /*** IRadialControllerButtonClickedEventArgs2 methods ***/
    HRESULT (STDMETHODCALLTYPE *get_SimpleHapticsController)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2 *This,
        __x_ABI_CWindows_CDevices_CHaptics_CISimpleHapticsController **value);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2Vtbl;

interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2 {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2Vtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IRadialControllerButtonClickedEventArgs2 methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_get_SimpleHapticsController(This,value) (This)->lpVtbl->get_SimpleHapticsController(This,value)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_AddRef(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_Release(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_GetIids(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IRadialControllerButtonClickedEventArgs2 methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_get_SimpleHapticsController(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2* This,__x_ABI_CWindows_CDevices_CHaptics_CISimpleHapticsController **value) {
    return This->lpVtbl->get_SimpleHapticsController(This,value);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IRadialControllerButtonClickedEventArgs2 IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2
#define IRadialControllerButtonClickedEventArgs2Vtbl __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2Vtbl
#define IRadialControllerButtonClickedEventArgs2 __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2
#define IRadialControllerButtonClickedEventArgs2_QueryInterface __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_QueryInterface
#define IRadialControllerButtonClickedEventArgs2_AddRef __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_AddRef
#define IRadialControllerButtonClickedEventArgs2_Release __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_Release
#define IRadialControllerButtonClickedEventArgs2_GetIids __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_GetIids
#define IRadialControllerButtonClickedEventArgs2_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_GetRuntimeClassName
#define IRadialControllerButtonClickedEventArgs2_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_GetTrustLevel
#define IRadialControllerButtonClickedEventArgs2_get_SimpleHapticsController __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_get_SimpleHapticsController
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs2_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x40000 */

/*****************************************************************************
 * IRadialControllerButtonHoldingEventArgs interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x40000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs, 0x3d577eee, 0x3cee, 0x11e6, 0xb5,0x35, 0x00,0x1b,0xdc,0x06,0xab,0x3b);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("3d577eee-3cee-11e6-b535-001bdc06ab3b")
                IRadialControllerButtonHoldingEventArgs : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE get_Contact(
                        ABI::Windows::UI::Input::IRadialControllerScreenContact **value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_SimpleHapticsController(
                        ABI::Windows::Devices::Haptics::ISimpleHapticsController **value) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs, 0x3d577eee, 0x3cee, 0x11e6, 0xb5,0x35, 0x00,0x1b,0xdc,0x06,0xab,0x3b)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgsVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs *This,
        TrustLevel *trustLevel);

    /*** IRadialControllerButtonHoldingEventArgs methods ***/
    HRESULT (STDMETHODCALLTYPE *get_Contact)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact **value);

    HRESULT (STDMETHODCALLTYPE *get_SimpleHapticsController)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs *This,
        __x_ABI_CWindows_CDevices_CHaptics_CISimpleHapticsController **value);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgsVtbl;

interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgsVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IRadialControllerButtonHoldingEventArgs methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_get_Contact(This,value) (This)->lpVtbl->get_Contact(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_get_SimpleHapticsController(This,value) (This)->lpVtbl->get_SimpleHapticsController(This,value)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_AddRef(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_Release(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_GetIids(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IRadialControllerButtonHoldingEventArgs methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_get_Contact(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs* This,__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact **value) {
    return This->lpVtbl->get_Contact(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_get_SimpleHapticsController(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs* This,__x_ABI_CWindows_CDevices_CHaptics_CISimpleHapticsController **value) {
    return This->lpVtbl->get_SimpleHapticsController(This,value);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IRadialControllerButtonHoldingEventArgs IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs
#define IRadialControllerButtonHoldingEventArgsVtbl __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgsVtbl
#define IRadialControllerButtonHoldingEventArgs __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs
#define IRadialControllerButtonHoldingEventArgs_QueryInterface __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_QueryInterface
#define IRadialControllerButtonHoldingEventArgs_AddRef __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_AddRef
#define IRadialControllerButtonHoldingEventArgs_Release __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_Release
#define IRadialControllerButtonHoldingEventArgs_GetIids __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_GetIids
#define IRadialControllerButtonHoldingEventArgs_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_GetRuntimeClassName
#define IRadialControllerButtonHoldingEventArgs_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_GetTrustLevel
#define IRadialControllerButtonHoldingEventArgs_get_Contact __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_get_Contact
#define IRadialControllerButtonHoldingEventArgs_get_SimpleHapticsController __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_get_SimpleHapticsController
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x40000 */

/*****************************************************************************
 * IRadialControllerButtonPressedEventArgs interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x40000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs, 0x3d577eed, 0x4cee, 0x11e6, 0xb5,0x35, 0x00,0x1b,0xdc,0x06,0xab,0x3b);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("3d577eed-4cee-11e6-b535-001bdc06ab3b")
                IRadialControllerButtonPressedEventArgs : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE get_Contact(
                        ABI::Windows::UI::Input::IRadialControllerScreenContact **value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_SimpleHapticsController(
                        ABI::Windows::Devices::Haptics::ISimpleHapticsController **value) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs, 0x3d577eed, 0x4cee, 0x11e6, 0xb5,0x35, 0x00,0x1b,0xdc,0x06,0xab,0x3b)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgsVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs *This,
        TrustLevel *trustLevel);

    /*** IRadialControllerButtonPressedEventArgs methods ***/
    HRESULT (STDMETHODCALLTYPE *get_Contact)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact **value);

    HRESULT (STDMETHODCALLTYPE *get_SimpleHapticsController)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs *This,
        __x_ABI_CWindows_CDevices_CHaptics_CISimpleHapticsController **value);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgsVtbl;

interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgsVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IRadialControllerButtonPressedEventArgs methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_get_Contact(This,value) (This)->lpVtbl->get_Contact(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_get_SimpleHapticsController(This,value) (This)->lpVtbl->get_SimpleHapticsController(This,value)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_AddRef(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_Release(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_GetIids(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IRadialControllerButtonPressedEventArgs methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_get_Contact(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs* This,__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact **value) {
    return This->lpVtbl->get_Contact(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_get_SimpleHapticsController(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs* This,__x_ABI_CWindows_CDevices_CHaptics_CISimpleHapticsController **value) {
    return This->lpVtbl->get_SimpleHapticsController(This,value);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IRadialControllerButtonPressedEventArgs IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs
#define IRadialControllerButtonPressedEventArgsVtbl __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgsVtbl
#define IRadialControllerButtonPressedEventArgs __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs
#define IRadialControllerButtonPressedEventArgs_QueryInterface __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_QueryInterface
#define IRadialControllerButtonPressedEventArgs_AddRef __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_AddRef
#define IRadialControllerButtonPressedEventArgs_Release __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_Release
#define IRadialControllerButtonPressedEventArgs_GetIids __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_GetIids
#define IRadialControllerButtonPressedEventArgs_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_GetRuntimeClassName
#define IRadialControllerButtonPressedEventArgs_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_GetTrustLevel
#define IRadialControllerButtonPressedEventArgs_get_Contact __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_get_Contact
#define IRadialControllerButtonPressedEventArgs_get_SimpleHapticsController __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_get_SimpleHapticsController
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x40000 */

/*****************************************************************************
 * IRadialControllerButtonReleasedEventArgs interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x40000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs, 0x3d577eef, 0x3cee, 0x11e6, 0xb5,0x35, 0x00,0x1b,0xdc,0x06,0xab,0x3b);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("3d577eef-3cee-11e6-b535-001bdc06ab3b")
                IRadialControllerButtonReleasedEventArgs : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE get_Contact(
                        ABI::Windows::UI::Input::IRadialControllerScreenContact **value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_SimpleHapticsController(
                        ABI::Windows::Devices::Haptics::ISimpleHapticsController **value) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs, 0x3d577eef, 0x3cee, 0x11e6, 0xb5,0x35, 0x00,0x1b,0xdc,0x06,0xab,0x3b)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgsVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs *This,
        TrustLevel *trustLevel);

    /*** IRadialControllerButtonReleasedEventArgs methods ***/
    HRESULT (STDMETHODCALLTYPE *get_Contact)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact **value);

    HRESULT (STDMETHODCALLTYPE *get_SimpleHapticsController)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs *This,
        __x_ABI_CWindows_CDevices_CHaptics_CISimpleHapticsController **value);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgsVtbl;

interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgsVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IRadialControllerButtonReleasedEventArgs methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_get_Contact(This,value) (This)->lpVtbl->get_Contact(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_get_SimpleHapticsController(This,value) (This)->lpVtbl->get_SimpleHapticsController(This,value)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_AddRef(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_Release(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_GetIids(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IRadialControllerButtonReleasedEventArgs methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_get_Contact(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs* This,__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact **value) {
    return This->lpVtbl->get_Contact(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_get_SimpleHapticsController(__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs* This,__x_ABI_CWindows_CDevices_CHaptics_CISimpleHapticsController **value) {
    return This->lpVtbl->get_SimpleHapticsController(This,value);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IRadialControllerButtonReleasedEventArgs IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs
#define IRadialControllerButtonReleasedEventArgsVtbl __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgsVtbl
#define IRadialControllerButtonReleasedEventArgs __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs
#define IRadialControllerButtonReleasedEventArgs_QueryInterface __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_QueryInterface
#define IRadialControllerButtonReleasedEventArgs_AddRef __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_AddRef
#define IRadialControllerButtonReleasedEventArgs_Release __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_Release
#define IRadialControllerButtonReleasedEventArgs_GetIids __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_GetIids
#define IRadialControllerButtonReleasedEventArgs_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_GetRuntimeClassName
#define IRadialControllerButtonReleasedEventArgs_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_GetTrustLevel
#define IRadialControllerButtonReleasedEventArgs_get_Contact __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_get_Contact
#define IRadialControllerButtonReleasedEventArgs_get_SimpleHapticsController __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_get_SimpleHapticsController
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x40000 */

/*****************************************************************************
 * IRadialControllerConfiguration interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration, 0xa6b79ecb, 0x6a52, 0x4430, 0x91,0x0c, 0x56,0x37,0x0a,0x9d,0x6b,0x42);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("a6b79ecb-6a52-4430-910c-56370a9d6b42")
                IRadialControllerConfiguration : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE SetDefaultMenuItems(
                        ABI::Windows::Foundation::Collections::IIterable<ABI::Windows::UI::Input::RadialControllerSystemMenuItemKind > *buttons) = 0;

                    virtual HRESULT STDMETHODCALLTYPE ResetToDefaultMenuItems(
                        ) = 0;

                    virtual HRESULT STDMETHODCALLTYPE TrySelectDefaultMenuItem(
                        ABI::Windows::UI::Input::RadialControllerSystemMenuItemKind type,
                        boolean *result) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration, 0xa6b79ecb, 0x6a52, 0x4430, 0x91,0x0c, 0x56,0x37,0x0a,0x9d,0x6b,0x42)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration *This,
        TrustLevel *trustLevel);

    /*** IRadialControllerConfiguration methods ***/
    HRESULT (STDMETHODCALLTYPE *SetDefaultMenuItems)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration *This,
        __FIIterable_1_RadialControllerSystemMenuItemKind *buttons);

    HRESULT (STDMETHODCALLTYPE *ResetToDefaultMenuItems)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration *This);

    HRESULT (STDMETHODCALLTYPE *TrySelectDefaultMenuItem)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration *This,
        __x_ABI_CWindows_CUI_CInput_CRadialControllerSystemMenuItemKind type,
        boolean *result);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationVtbl;

interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IRadialControllerConfiguration methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_SetDefaultMenuItems(This,buttons) (This)->lpVtbl->SetDefaultMenuItems(This,buttons)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_ResetToDefaultMenuItems(This) (This)->lpVtbl->ResetToDefaultMenuItems(This)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_TrySelectDefaultMenuItem(This,type,result) (This)->lpVtbl->TrySelectDefaultMenuItem(This,type,result)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_AddRef(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_Release(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_GetIids(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IRadialControllerConfiguration methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_SetDefaultMenuItems(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration* This,__FIIterable_1_RadialControllerSystemMenuItemKind *buttons) {
    return This->lpVtbl->SetDefaultMenuItems(This,buttons);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_ResetToDefaultMenuItems(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration* This) {
    return This->lpVtbl->ResetToDefaultMenuItems(This);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_TrySelectDefaultMenuItem(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration* This,__x_ABI_CWindows_CUI_CInput_CRadialControllerSystemMenuItemKind type,boolean *result) {
    return This->lpVtbl->TrySelectDefaultMenuItem(This,type,result);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IRadialControllerConfiguration IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration
#define IRadialControllerConfigurationVtbl __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationVtbl
#define IRadialControllerConfiguration __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration
#define IRadialControllerConfiguration_QueryInterface __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_QueryInterface
#define IRadialControllerConfiguration_AddRef __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_AddRef
#define IRadialControllerConfiguration_Release __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_Release
#define IRadialControllerConfiguration_GetIids __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_GetIids
#define IRadialControllerConfiguration_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_GetRuntimeClassName
#define IRadialControllerConfiguration_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_GetTrustLevel
#define IRadialControllerConfiguration_SetDefaultMenuItems __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_SetDefaultMenuItems
#define IRadialControllerConfiguration_ResetToDefaultMenuItems __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_ResetToDefaultMenuItems
#define IRadialControllerConfiguration_TrySelectDefaultMenuItem __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_TrySelectDefaultMenuItem
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000 */

/*****************************************************************************
 * IRadialControllerConfiguration2 interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x40000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2, 0x3d577ef7, 0x3cee, 0x11e6, 0xb5,0x35, 0x00,0x1b,0xdc,0x06,0xab,0x3b);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("3d577ef7-3cee-11e6-b535-001bdc06ab3b")
                IRadialControllerConfiguration2 : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE put_ActiveControllerWhenMenuIsSuppressed(
                        ABI::Windows::UI::Input::IRadialController *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_ActiveControllerWhenMenuIsSuppressed(
                        ABI::Windows::UI::Input::IRadialController **value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE put_IsMenuSuppressed(
                        boolean value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_IsMenuSuppressed(
                        boolean *value) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2, 0x3d577ef7, 0x3cee, 0x11e6, 0xb5,0x35, 0x00,0x1b,0xdc,0x06,0xab,0x3b)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2Vtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2 *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2 *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2 *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2 *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2 *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2 *This,
        TrustLevel *trustLevel);

    /*** IRadialControllerConfiguration2 methods ***/
    HRESULT (STDMETHODCALLTYPE *put_ActiveControllerWhenMenuIsSuppressed)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2 *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialController *value);

    HRESULT (STDMETHODCALLTYPE *get_ActiveControllerWhenMenuIsSuppressed)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2 *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialController **value);

    HRESULT (STDMETHODCALLTYPE *put_IsMenuSuppressed)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2 *This,
        boolean value);

    HRESULT (STDMETHODCALLTYPE *get_IsMenuSuppressed)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2 *This,
        boolean *value);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2Vtbl;

interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2 {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2Vtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IRadialControllerConfiguration2 methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_put_ActiveControllerWhenMenuIsSuppressed(This,value) (This)->lpVtbl->put_ActiveControllerWhenMenuIsSuppressed(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_get_ActiveControllerWhenMenuIsSuppressed(This,value) (This)->lpVtbl->get_ActiveControllerWhenMenuIsSuppressed(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_put_IsMenuSuppressed(This,value) (This)->lpVtbl->put_IsMenuSuppressed(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_get_IsMenuSuppressed(This,value) (This)->lpVtbl->get_IsMenuSuppressed(This,value)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_AddRef(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_Release(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_GetIids(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IRadialControllerConfiguration2 methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_put_ActiveControllerWhenMenuIsSuppressed(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2* This,__x_ABI_CWindows_CUI_CInput_CIRadialController *value) {
    return This->lpVtbl->put_ActiveControllerWhenMenuIsSuppressed(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_get_ActiveControllerWhenMenuIsSuppressed(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2* This,__x_ABI_CWindows_CUI_CInput_CIRadialController **value) {
    return This->lpVtbl->get_ActiveControllerWhenMenuIsSuppressed(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_put_IsMenuSuppressed(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2* This,boolean value) {
    return This->lpVtbl->put_IsMenuSuppressed(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_get_IsMenuSuppressed(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2* This,boolean *value) {
    return This->lpVtbl->get_IsMenuSuppressed(This,value);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IRadialControllerConfiguration2 IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2
#define IRadialControllerConfiguration2Vtbl __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2Vtbl
#define IRadialControllerConfiguration2 __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2
#define IRadialControllerConfiguration2_QueryInterface __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_QueryInterface
#define IRadialControllerConfiguration2_AddRef __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_AddRef
#define IRadialControllerConfiguration2_Release __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_Release
#define IRadialControllerConfiguration2_GetIids __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_GetIids
#define IRadialControllerConfiguration2_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_GetRuntimeClassName
#define IRadialControllerConfiguration2_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_GetTrustLevel
#define IRadialControllerConfiguration2_put_ActiveControllerWhenMenuIsSuppressed __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_put_ActiveControllerWhenMenuIsSuppressed
#define IRadialControllerConfiguration2_get_ActiveControllerWhenMenuIsSuppressed __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_get_ActiveControllerWhenMenuIsSuppressed
#define IRadialControllerConfiguration2_put_IsMenuSuppressed __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_put_IsMenuSuppressed
#define IRadialControllerConfiguration2_get_IsMenuSuppressed __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_get_IsMenuSuppressed
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration2_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x40000 */

/*****************************************************************************
 * IRadialControllerConfigurationStatics interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics, 0x79b6b0e5, 0x069a, 0x4486, 0xa9,0x9d, 0x8d,0xb7,0x72,0xb9,0x64,0x2f);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("79b6b0e5-069a-4486-a99d-8db772b9642f")
                IRadialControllerConfigurationStatics : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE GetForCurrentView(
                        ABI::Windows::UI::Input::IRadialControllerConfiguration **configuration) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics, 0x79b6b0e5, 0x069a, 0x4486, 0xa9,0x9d, 0x8d,0xb7,0x72,0xb9,0x64,0x2f)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStaticsVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics *This,
        TrustLevel *trustLevel);

    /*** IRadialControllerConfigurationStatics methods ***/
    HRESULT (STDMETHODCALLTYPE *GetForCurrentView)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration **configuration);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStaticsVtbl;

interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStaticsVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IRadialControllerConfigurationStatics methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_GetForCurrentView(This,configuration) (This)->lpVtbl->GetForCurrentView(This,configuration)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_AddRef(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_Release(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_GetIids(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IRadialControllerConfigurationStatics methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_GetForCurrentView(__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics* This,__x_ABI_CWindows_CUI_CInput_CIRadialControllerConfiguration **configuration) {
    return This->lpVtbl->GetForCurrentView(This,configuration);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IRadialControllerConfigurationStatics IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics
#define IRadialControllerConfigurationStaticsVtbl __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStaticsVtbl
#define IRadialControllerConfigurationStatics __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics
#define IRadialControllerConfigurationStatics_QueryInterface __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_QueryInterface
#define IRadialControllerConfigurationStatics_AddRef __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_AddRef
#define IRadialControllerConfigurationStatics_Release __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_Release
#define IRadialControllerConfigurationStatics_GetIids __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_GetIids
#define IRadialControllerConfigurationStatics_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_GetRuntimeClassName
#define IRadialControllerConfigurationStatics_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_GetTrustLevel
#define IRadialControllerConfigurationStatics_GetForCurrentView __x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_GetForCurrentView
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIRadialControllerConfigurationStatics_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000 */

/*****************************************************************************
 * IRadialControllerControlAcquiredEventArgs interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs, 0x206aa439, 0xe651, 0x11e5, 0xbf,0x62, 0x2c,0x27,0xd7,0x40,0x4e,0x85);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("206aa439-e651-11e5-bf62-2c27d7404e85")
                IRadialControllerControlAcquiredEventArgs : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE get_Contact(
                        ABI::Windows::UI::Input::IRadialControllerScreenContact **value) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs, 0x206aa439, 0xe651, 0x11e5, 0xbf,0x62, 0x2c,0x27,0xd7,0x40,0x4e,0x85)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgsVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs *This,
        TrustLevel *trustLevel);

    /*** IRadialControllerControlAcquiredEventArgs methods ***/
    HRESULT (STDMETHODCALLTYPE *get_Contact)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact **value);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgsVtbl;

interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgsVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IRadialControllerControlAcquiredEventArgs methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_get_Contact(This,value) (This)->lpVtbl->get_Contact(This,value)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_AddRef(__x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_Release(__x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_GetIids(__x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IRadialControllerControlAcquiredEventArgs methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_get_Contact(__x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs* This,__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact **value) {
    return This->lpVtbl->get_Contact(This,value);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IRadialControllerControlAcquiredEventArgs IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs
#define IRadialControllerControlAcquiredEventArgsVtbl __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgsVtbl
#define IRadialControllerControlAcquiredEventArgs __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs
#define IRadialControllerControlAcquiredEventArgs_QueryInterface __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_QueryInterface
#define IRadialControllerControlAcquiredEventArgs_AddRef __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_AddRef
#define IRadialControllerControlAcquiredEventArgs_Release __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_Release
#define IRadialControllerControlAcquiredEventArgs_GetIids __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_GetIids
#define IRadialControllerControlAcquiredEventArgs_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_GetRuntimeClassName
#define IRadialControllerControlAcquiredEventArgs_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_GetTrustLevel
#define IRadialControllerControlAcquiredEventArgs_get_Contact __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_get_Contact
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000 */

/*****************************************************************************
 * IRadialControllerControlAcquiredEventArgs2 interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x40000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2, 0x3d577ef4, 0x3cee, 0x11e6, 0xb5,0x35, 0x00,0x1b,0xdc,0x06,0xab,0x3b);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("3d577ef4-3cee-11e6-b535-001bdc06ab3b")
                IRadialControllerControlAcquiredEventArgs2 : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE get_IsButtonPressed(
                        boolean *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_SimpleHapticsController(
                        ABI::Windows::Devices::Haptics::ISimpleHapticsController **value) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2, 0x3d577ef4, 0x3cee, 0x11e6, 0xb5,0x35, 0x00,0x1b,0xdc,0x06,0xab,0x3b)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2Vtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2 *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2 *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2 *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2 *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2 *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2 *This,
        TrustLevel *trustLevel);

    /*** IRadialControllerControlAcquiredEventArgs2 methods ***/
    HRESULT (STDMETHODCALLTYPE *get_IsButtonPressed)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2 *This,
        boolean *value);

    HRESULT (STDMETHODCALLTYPE *get_SimpleHapticsController)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2 *This,
        __x_ABI_CWindows_CDevices_CHaptics_CISimpleHapticsController **value);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2Vtbl;

interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2 {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2Vtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IRadialControllerControlAcquiredEventArgs2 methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_get_IsButtonPressed(This,value) (This)->lpVtbl->get_IsButtonPressed(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_get_SimpleHapticsController(This,value) (This)->lpVtbl->get_SimpleHapticsController(This,value)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_AddRef(__x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_Release(__x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_GetIids(__x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IRadialControllerControlAcquiredEventArgs2 methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_get_IsButtonPressed(__x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2* This,boolean *value) {
    return This->lpVtbl->get_IsButtonPressed(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_get_SimpleHapticsController(__x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2* This,__x_ABI_CWindows_CDevices_CHaptics_CISimpleHapticsController **value) {
    return This->lpVtbl->get_SimpleHapticsController(This,value);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IRadialControllerControlAcquiredEventArgs2 IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2
#define IRadialControllerControlAcquiredEventArgs2Vtbl __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2Vtbl
#define IRadialControllerControlAcquiredEventArgs2 __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2
#define IRadialControllerControlAcquiredEventArgs2_QueryInterface __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_QueryInterface
#define IRadialControllerControlAcquiredEventArgs2_AddRef __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_AddRef
#define IRadialControllerControlAcquiredEventArgs2_Release __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_Release
#define IRadialControllerControlAcquiredEventArgs2_GetIids __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_GetIids
#define IRadialControllerControlAcquiredEventArgs2_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_GetRuntimeClassName
#define IRadialControllerControlAcquiredEventArgs2_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_GetTrustLevel
#define IRadialControllerControlAcquiredEventArgs2_get_IsButtonPressed __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_get_IsButtonPressed
#define IRadialControllerControlAcquiredEventArgs2_get_SimpleHapticsController __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_get_SimpleHapticsController
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs2_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x40000 */

/*****************************************************************************
 * IRadialControllerMenu interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu, 0x8506b35d, 0xf640, 0x4412, 0xab,0xa0, 0xba,0xd0,0x77,0xe5,0xea,0x8a);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("8506b35d-f640-4412-aba0-bad077e5ea8a")
                IRadialControllerMenu : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE get_Items(
                        ABI::Windows::Foundation::Collections::IVector<ABI::Windows::UI::Input::RadialControllerMenuItem* > **value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_IsEnabled(
                        boolean *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE put_IsEnabled(
                        boolean value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE GetSelectedMenuItem(
                        ABI::Windows::UI::Input::IRadialControllerMenuItem **result) = 0;

                    virtual HRESULT STDMETHODCALLTYPE SelectMenuItem(
                        ABI::Windows::UI::Input::IRadialControllerMenuItem *menu_item) = 0;

                    virtual HRESULT STDMETHODCALLTYPE TrySelectPreviouslySelectedMenuItem(
                        boolean *result) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu, 0x8506b35d, 0xf640, 0x4412, 0xab,0xa0, 0xba,0xd0,0x77,0xe5,0xea,0x8a)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu *This,
        TrustLevel *trustLevel);

    /*** IRadialControllerMenu methods ***/
    HRESULT (STDMETHODCALLTYPE *get_Items)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu *This,
        __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem **value);

    HRESULT (STDMETHODCALLTYPE *get_IsEnabled)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu *This,
        boolean *value);

    HRESULT (STDMETHODCALLTYPE *put_IsEnabled)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu *This,
        boolean value);

    HRESULT (STDMETHODCALLTYPE *GetSelectedMenuItem)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem **result);

    HRESULT (STDMETHODCALLTYPE *SelectMenuItem)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem *menu_item);

    HRESULT (STDMETHODCALLTYPE *TrySelectPreviouslySelectedMenuItem)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu *This,
        boolean *result);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuVtbl;

interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IRadialControllerMenu methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_get_Items(This,value) (This)->lpVtbl->get_Items(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_get_IsEnabled(This,value) (This)->lpVtbl->get_IsEnabled(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_put_IsEnabled(This,value) (This)->lpVtbl->put_IsEnabled(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_GetSelectedMenuItem(This,result) (This)->lpVtbl->GetSelectedMenuItem(This,result)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_SelectMenuItem(This,menu_item) (This)->lpVtbl->SelectMenuItem(This,menu_item)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_TrySelectPreviouslySelectedMenuItem(This,result) (This)->lpVtbl->TrySelectPreviouslySelectedMenuItem(This,result)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_AddRef(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_Release(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_GetIids(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IRadialControllerMenu methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_get_Items(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu* This,__FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem **value) {
    return This->lpVtbl->get_Items(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_get_IsEnabled(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu* This,boolean *value) {
    return This->lpVtbl->get_IsEnabled(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_put_IsEnabled(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu* This,boolean value) {
    return This->lpVtbl->put_IsEnabled(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_GetSelectedMenuItem(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu* This,__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem **result) {
    return This->lpVtbl->GetSelectedMenuItem(This,result);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_SelectMenuItem(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu* This,__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem *menu_item) {
    return This->lpVtbl->SelectMenuItem(This,menu_item);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_TrySelectPreviouslySelectedMenuItem(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu* This,boolean *result) {
    return This->lpVtbl->TrySelectPreviouslySelectedMenuItem(This,result);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IRadialControllerMenu IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu
#define IRadialControllerMenuVtbl __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuVtbl
#define IRadialControllerMenu __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu
#define IRadialControllerMenu_QueryInterface __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_QueryInterface
#define IRadialControllerMenu_AddRef __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_AddRef
#define IRadialControllerMenu_Release __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_Release
#define IRadialControllerMenu_GetIids __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_GetIids
#define IRadialControllerMenu_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_GetRuntimeClassName
#define IRadialControllerMenu_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_GetTrustLevel
#define IRadialControllerMenu_get_Items __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_get_Items
#define IRadialControllerMenu_get_IsEnabled __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_get_IsEnabled
#define IRadialControllerMenu_put_IsEnabled __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_put_IsEnabled
#define IRadialControllerMenu_GetSelectedMenuItem __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_GetSelectedMenuItem
#define IRadialControllerMenu_SelectMenuItem __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_SelectMenuItem
#define IRadialControllerMenu_TrySelectPreviouslySelectedMenuItem __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_TrySelectPreviouslySelectedMenuItem
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenu_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000 */

/*****************************************************************************
 * IRadialControllerMenuItem interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem, 0xc80fc98d, 0xad0b, 0x4c9c, 0x8f,0x2f, 0x13,0x6a,0x23,0x73,0xa6,0xba);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("c80fc98d-ad0b-4c9c-8f2f-136a2373a6ba")
                IRadialControllerMenuItem : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE get_DisplayText(
                        HSTRING *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_Tag(
                        IInspectable **value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE put_Tag(
                        IInspectable *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE add_Invoked(
                        ABI::Windows::Foundation::ITypedEventHandler<ABI::Windows::UI::Input::RadialControllerMenuItem*,IInspectable* > *handler,
                        EventRegistrationToken *token) = 0;

                    virtual HRESULT STDMETHODCALLTYPE remove_Invoked(
                        EventRegistrationToken token) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem, 0xc80fc98d, 0xad0b, 0x4c9c, 0x8f,0x2f, 0x13,0x6a,0x23,0x73,0xa6,0xba)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem *This,
        TrustLevel *trustLevel);

    /*** IRadialControllerMenuItem methods ***/
    HRESULT (STDMETHODCALLTYPE *get_DisplayText)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem *This,
        HSTRING *value);

    HRESULT (STDMETHODCALLTYPE *get_Tag)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem *This,
        IInspectable **value);

    HRESULT (STDMETHODCALLTYPE *put_Tag)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem *This,
        IInspectable *value);

    HRESULT (STDMETHODCALLTYPE *add_Invoked)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem *This,
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable *handler,
        EventRegistrationToken *token);

    HRESULT (STDMETHODCALLTYPE *remove_Invoked)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem *This,
        EventRegistrationToken token);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemVtbl;

interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IRadialControllerMenuItem methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_get_DisplayText(This,value) (This)->lpVtbl->get_DisplayText(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_get_Tag(This,value) (This)->lpVtbl->get_Tag(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_put_Tag(This,value) (This)->lpVtbl->put_Tag(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_add_Invoked(This,handler,token) (This)->lpVtbl->add_Invoked(This,handler,token)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_remove_Invoked(This,token) (This)->lpVtbl->remove_Invoked(This,token)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_AddRef(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_Release(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_GetIids(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IRadialControllerMenuItem methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_get_DisplayText(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem* This,HSTRING *value) {
    return This->lpVtbl->get_DisplayText(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_get_Tag(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem* This,IInspectable **value) {
    return This->lpVtbl->get_Tag(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_put_Tag(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem* This,IInspectable *value) {
    return This->lpVtbl->put_Tag(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_add_Invoked(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem* This,__FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable *handler,EventRegistrationToken *token) {
    return This->lpVtbl->add_Invoked(This,handler,token);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_remove_Invoked(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem* This,EventRegistrationToken token) {
    return This->lpVtbl->remove_Invoked(This,token);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IRadialControllerMenuItem IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem
#define IRadialControllerMenuItemVtbl __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemVtbl
#define IRadialControllerMenuItem __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem
#define IRadialControllerMenuItem_QueryInterface __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_QueryInterface
#define IRadialControllerMenuItem_AddRef __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_AddRef
#define IRadialControllerMenuItem_Release __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_Release
#define IRadialControllerMenuItem_GetIids __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_GetIids
#define IRadialControllerMenuItem_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_GetRuntimeClassName
#define IRadialControllerMenuItem_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_GetTrustLevel
#define IRadialControllerMenuItem_get_DisplayText __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_get_DisplayText
#define IRadialControllerMenuItem_get_Tag __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_get_Tag
#define IRadialControllerMenuItem_put_Tag __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_put_Tag
#define IRadialControllerMenuItem_add_Invoked __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_add_Invoked
#define IRadialControllerMenuItem_remove_Invoked __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_remove_Invoked
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000 */

/*****************************************************************************
 * IRadialControllerMenuItemStatics interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics, 0x249e0887, 0xd842, 0x4524, 0x9d,0xf8, 0xe0,0xd6,0x47,0xed,0xc8,0x87);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("249e0887-d842-4524-9df8-e0d647edc887")
                IRadialControllerMenuItemStatics : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE CreateFromIcon(
                        HSTRING display_text,
                        ABI::Windows::Storage::Streams::IRandomAccessStreamReference *icon,
                        ABI::Windows::UI::Input::IRadialControllerMenuItem **result) = 0;

                    virtual HRESULT STDMETHODCALLTYPE CreateFromKnownIcon(
                        HSTRING display_text,
                        ABI::Windows::UI::Input::RadialControllerMenuKnownIcon value,
                        ABI::Windows::UI::Input::IRadialControllerMenuItem **result) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics, 0x249e0887, 0xd842, 0x4524, 0x9d,0xf8, 0xe0,0xd6,0x47,0xed,0xc8,0x87)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStaticsVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics *This,
        TrustLevel *trustLevel);

    /*** IRadialControllerMenuItemStatics methods ***/
    HRESULT (STDMETHODCALLTYPE *CreateFromIcon)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics *This,
        HSTRING display_text,
        __x_ABI_CWindows_CStorage_CStreams_CIRandomAccessStreamReference *icon,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem **result);

    HRESULT (STDMETHODCALLTYPE *CreateFromKnownIcon)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics *This,
        HSTRING display_text,
        __x_ABI_CWindows_CUI_CInput_CRadialControllerMenuKnownIcon value,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem **result);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStaticsVtbl;

interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStaticsVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IRadialControllerMenuItemStatics methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_CreateFromIcon(This,display_text,icon,result) (This)->lpVtbl->CreateFromIcon(This,display_text,icon,result)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_CreateFromKnownIcon(This,display_text,value,result) (This)->lpVtbl->CreateFromKnownIcon(This,display_text,value,result)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_AddRef(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_Release(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_GetIids(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IRadialControllerMenuItemStatics methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_CreateFromIcon(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics* This,HSTRING display_text,__x_ABI_CWindows_CStorage_CStreams_CIRandomAccessStreamReference *icon,__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem **result) {
    return This->lpVtbl->CreateFromIcon(This,display_text,icon,result);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_CreateFromKnownIcon(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics* This,HSTRING display_text,__x_ABI_CWindows_CUI_CInput_CRadialControllerMenuKnownIcon value,__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem **result) {
    return This->lpVtbl->CreateFromKnownIcon(This,display_text,value,result);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IRadialControllerMenuItemStatics IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics
#define IRadialControllerMenuItemStaticsVtbl __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStaticsVtbl
#define IRadialControllerMenuItemStatics __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics
#define IRadialControllerMenuItemStatics_QueryInterface __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_QueryInterface
#define IRadialControllerMenuItemStatics_AddRef __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_AddRef
#define IRadialControllerMenuItemStatics_Release __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_Release
#define IRadialControllerMenuItemStatics_GetIids __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_GetIids
#define IRadialControllerMenuItemStatics_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_GetRuntimeClassName
#define IRadialControllerMenuItemStatics_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_GetTrustLevel
#define IRadialControllerMenuItemStatics_CreateFromIcon __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_CreateFromIcon
#define IRadialControllerMenuItemStatics_CreateFromKnownIcon __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_CreateFromKnownIcon
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000 */

/*****************************************************************************
 * IRadialControllerMenuItemStatics2 interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x40000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2, 0x0cbb70be, 0x7e3e, 0x48bd, 0xbe,0x04, 0x2c,0x7f,0xca,0xa9,0xc1,0xff);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("0cbb70be-7e3e-48bd-be04-2c7fcaa9c1ff")
                IRadialControllerMenuItemStatics2 : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE CreateFromFontGlyph(
                        HSTRING display_text,
                        HSTRING glyph,
                        HSTRING font_family,
                        ABI::Windows::UI::Input::IRadialControllerMenuItem **result) = 0;

                    virtual HRESULT STDMETHODCALLTYPE CreateFromFontGlyphWithUri(
                        HSTRING display_text,
                        HSTRING glyph,
                        HSTRING font_family,
                        ABI::Windows::Foundation::IUriRuntimeClass *font_uri,
                        ABI::Windows::UI::Input::IRadialControllerMenuItem **result) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2, 0x0cbb70be, 0x7e3e, 0x48bd, 0xbe,0x04, 0x2c,0x7f,0xca,0xa9,0xc1,0xff)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2Vtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2 *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2 *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2 *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2 *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2 *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2 *This,
        TrustLevel *trustLevel);

    /*** IRadialControllerMenuItemStatics2 methods ***/
    HRESULT (STDMETHODCALLTYPE *CreateFromFontGlyph)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2 *This,
        HSTRING display_text,
        HSTRING glyph,
        HSTRING font_family,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem **result);

    HRESULT (STDMETHODCALLTYPE *CreateFromFontGlyphWithUri)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2 *This,
        HSTRING display_text,
        HSTRING glyph,
        HSTRING font_family,
        __x_ABI_CWindows_CFoundation_CIUriRuntimeClass *font_uri,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem **result);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2Vtbl;

interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2 {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2Vtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IRadialControllerMenuItemStatics2 methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_CreateFromFontGlyph(This,display_text,glyph,font_family,result) (This)->lpVtbl->CreateFromFontGlyph(This,display_text,glyph,font_family,result)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_CreateFromFontGlyphWithUri(This,display_text,glyph,font_family,font_uri,result) (This)->lpVtbl->CreateFromFontGlyphWithUri(This,display_text,glyph,font_family,font_uri,result)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_AddRef(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_Release(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_GetIids(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IRadialControllerMenuItemStatics2 methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_CreateFromFontGlyph(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2* This,HSTRING display_text,HSTRING glyph,HSTRING font_family,__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem **result) {
    return This->lpVtbl->CreateFromFontGlyph(This,display_text,glyph,font_family,result);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_CreateFromFontGlyphWithUri(__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2* This,HSTRING display_text,HSTRING glyph,HSTRING font_family,__x_ABI_CWindows_CFoundation_CIUriRuntimeClass *font_uri,__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem **result) {
    return This->lpVtbl->CreateFromFontGlyphWithUri(This,display_text,glyph,font_family,font_uri,result);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IRadialControllerMenuItemStatics2 IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2
#define IRadialControllerMenuItemStatics2Vtbl __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2Vtbl
#define IRadialControllerMenuItemStatics2 __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2
#define IRadialControllerMenuItemStatics2_QueryInterface __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_QueryInterface
#define IRadialControllerMenuItemStatics2_AddRef __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_AddRef
#define IRadialControllerMenuItemStatics2_Release __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_Release
#define IRadialControllerMenuItemStatics2_GetIids __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_GetIids
#define IRadialControllerMenuItemStatics2_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_GetRuntimeClassName
#define IRadialControllerMenuItemStatics2_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_GetTrustLevel
#define IRadialControllerMenuItemStatics2_CreateFromFontGlyph __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_CreateFromFontGlyph
#define IRadialControllerMenuItemStatics2_CreateFromFontGlyphWithUri __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_CreateFromFontGlyphWithUri
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItemStatics2_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x40000 */

/*****************************************************************************
 * IRadialControllerRotationChangedEventArgs interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs, 0x206aa435, 0xe651, 0x11e5, 0xbf,0x62, 0x2c,0x27,0xd7,0x40,0x4e,0x85);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("206aa435-e651-11e5-bf62-2c27d7404e85")
                IRadialControllerRotationChangedEventArgs : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE get_RotationDeltaInDegrees(
                        DOUBLE *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_Contact(
                        ABI::Windows::UI::Input::IRadialControllerScreenContact **value) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs, 0x206aa435, 0xe651, 0x11e5, 0xbf,0x62, 0x2c,0x27,0xd7,0x40,0x4e,0x85)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgsVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs *This,
        TrustLevel *trustLevel);

    /*** IRadialControllerRotationChangedEventArgs methods ***/
    HRESULT (STDMETHODCALLTYPE *get_RotationDeltaInDegrees)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs *This,
        DOUBLE *value);

    HRESULT (STDMETHODCALLTYPE *get_Contact)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact **value);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgsVtbl;

interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgsVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IRadialControllerRotationChangedEventArgs methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_get_RotationDeltaInDegrees(This,value) (This)->lpVtbl->get_RotationDeltaInDegrees(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_get_Contact(This,value) (This)->lpVtbl->get_Contact(This,value)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_AddRef(__x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_Release(__x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_GetIids(__x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IRadialControllerRotationChangedEventArgs methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_get_RotationDeltaInDegrees(__x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs* This,DOUBLE *value) {
    return This->lpVtbl->get_RotationDeltaInDegrees(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_get_Contact(__x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs* This,__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact **value) {
    return This->lpVtbl->get_Contact(This,value);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IRadialControllerRotationChangedEventArgs IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs
#define IRadialControllerRotationChangedEventArgsVtbl __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgsVtbl
#define IRadialControllerRotationChangedEventArgs __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs
#define IRadialControllerRotationChangedEventArgs_QueryInterface __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_QueryInterface
#define IRadialControllerRotationChangedEventArgs_AddRef __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_AddRef
#define IRadialControllerRotationChangedEventArgs_Release __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_Release
#define IRadialControllerRotationChangedEventArgs_GetIids __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_GetIids
#define IRadialControllerRotationChangedEventArgs_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_GetRuntimeClassName
#define IRadialControllerRotationChangedEventArgs_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_GetTrustLevel
#define IRadialControllerRotationChangedEventArgs_get_RotationDeltaInDegrees __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_get_RotationDeltaInDegrees
#define IRadialControllerRotationChangedEventArgs_get_Contact __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_get_Contact
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000 */

/*****************************************************************************
 * IRadialControllerScreenContact interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact, 0x206aa434, 0xe651, 0x11e5, 0xbf,0x62, 0x2c,0x27,0xd7,0x40,0x4e,0x85);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("206aa434-e651-11e5-bf62-2c27d7404e85")
                IRadialControllerScreenContact : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE get_Bounds(
                        ABI::Windows::Foundation::Rect *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_Position(
                        ABI::Windows::Foundation::Point *value) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact, 0x206aa434, 0xe651, 0x11e5, 0xbf,0x62, 0x2c,0x27,0xd7,0x40,0x4e,0x85)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact *This,
        TrustLevel *trustLevel);

    /*** IRadialControllerScreenContact methods ***/
    HRESULT (STDMETHODCALLTYPE *get_Bounds)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact *This,
        __x_ABI_CWindows_CFoundation_CRect *value);

    HRESULT (STDMETHODCALLTYPE *get_Position)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact *This,
        __x_ABI_CWindows_CFoundation_CPoint *value);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactVtbl;

interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IRadialControllerScreenContact methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_get_Bounds(This,value) (This)->lpVtbl->get_Bounds(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_get_Position(This,value) (This)->lpVtbl->get_Position(This,value)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_AddRef(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_Release(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_GetIids(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IRadialControllerScreenContact methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_get_Bounds(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact* This,__x_ABI_CWindows_CFoundation_CRect *value) {
    return This->lpVtbl->get_Bounds(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_get_Position(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact* This,__x_ABI_CWindows_CFoundation_CPoint *value) {
    return This->lpVtbl->get_Position(This,value);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IRadialControllerScreenContact IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact
#define IRadialControllerScreenContactVtbl __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactVtbl
#define IRadialControllerScreenContact __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact
#define IRadialControllerScreenContact_QueryInterface __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_QueryInterface
#define IRadialControllerScreenContact_AddRef __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_AddRef
#define IRadialControllerScreenContact_Release __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_Release
#define IRadialControllerScreenContact_GetIids __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_GetIids
#define IRadialControllerScreenContact_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_GetRuntimeClassName
#define IRadialControllerScreenContact_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_GetTrustLevel
#define IRadialControllerScreenContact_get_Bounds __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_get_Bounds
#define IRadialControllerScreenContact_get_Position __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_get_Position
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000 */

/*****************************************************************************
 * IRadialControllerScreenContactContinuedEventArgs interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs, 0x206aa437, 0xe651, 0x11e5, 0xbf,0x62, 0x2c,0x27,0xd7,0x40,0x4e,0x85);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("206aa437-e651-11e5-bf62-2c27d7404e85")
                IRadialControllerScreenContactContinuedEventArgs : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE get_Contact(
                        ABI::Windows::UI::Input::IRadialControllerScreenContact **value) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs, 0x206aa437, 0xe651, 0x11e5, 0xbf,0x62, 0x2c,0x27,0xd7,0x40,0x4e,0x85)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgsVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs *This,
        TrustLevel *trustLevel);

    /*** IRadialControllerScreenContactContinuedEventArgs methods ***/
    HRESULT (STDMETHODCALLTYPE *get_Contact)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact **value);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgsVtbl;

interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgsVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IRadialControllerScreenContactContinuedEventArgs methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_get_Contact(This,value) (This)->lpVtbl->get_Contact(This,value)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_AddRef(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_Release(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_GetIids(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IRadialControllerScreenContactContinuedEventArgs methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_get_Contact(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs* This,__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact **value) {
    return This->lpVtbl->get_Contact(This,value);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IRadialControllerScreenContactContinuedEventArgs IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs
#define IRadialControllerScreenContactContinuedEventArgsVtbl __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgsVtbl
#define IRadialControllerScreenContactContinuedEventArgs __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs
#define IRadialControllerScreenContactContinuedEventArgs_QueryInterface __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_QueryInterface
#define IRadialControllerScreenContactContinuedEventArgs_AddRef __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_AddRef
#define IRadialControllerScreenContactContinuedEventArgs_Release __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_Release
#define IRadialControllerScreenContactContinuedEventArgs_GetIids __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_GetIids
#define IRadialControllerScreenContactContinuedEventArgs_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_GetRuntimeClassName
#define IRadialControllerScreenContactContinuedEventArgs_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_GetTrustLevel
#define IRadialControllerScreenContactContinuedEventArgs_get_Contact __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_get_Contact
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000 */

/*****************************************************************************
 * IRadialControllerScreenContactStartedEventArgs interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs, 0x206aa436, 0xe651, 0x11e5, 0xbf,0x62, 0x2c,0x27,0xd7,0x40,0x4e,0x85);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("206aa436-e651-11e5-bf62-2c27d7404e85")
                IRadialControllerScreenContactStartedEventArgs : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE get_Contact(
                        ABI::Windows::UI::Input::IRadialControllerScreenContact **value) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs, 0x206aa436, 0xe651, 0x11e5, 0xbf,0x62, 0x2c,0x27,0xd7,0x40,0x4e,0x85)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgsVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs *This,
        TrustLevel *trustLevel);

    /*** IRadialControllerScreenContactStartedEventArgs methods ***/
    HRESULT (STDMETHODCALLTYPE *get_Contact)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact **value);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgsVtbl;

interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgsVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IRadialControllerScreenContactStartedEventArgs methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_get_Contact(This,value) (This)->lpVtbl->get_Contact(This,value)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_AddRef(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_Release(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_GetIids(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IRadialControllerScreenContactStartedEventArgs methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_get_Contact(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs* This,__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContact **value) {
    return This->lpVtbl->get_Contact(This,value);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IRadialControllerScreenContactStartedEventArgs IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs
#define IRadialControllerScreenContactStartedEventArgsVtbl __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgsVtbl
#define IRadialControllerScreenContactStartedEventArgs __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs
#define IRadialControllerScreenContactStartedEventArgs_QueryInterface __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_QueryInterface
#define IRadialControllerScreenContactStartedEventArgs_AddRef __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_AddRef
#define IRadialControllerScreenContactStartedEventArgs_Release __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_Release
#define IRadialControllerScreenContactStartedEventArgs_GetIids __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_GetIids
#define IRadialControllerScreenContactStartedEventArgs_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_GetRuntimeClassName
#define IRadialControllerScreenContactStartedEventArgs_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_GetTrustLevel
#define IRadialControllerScreenContactStartedEventArgs_get_Contact __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_get_Contact
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000 */

/*****************************************************************************
 * IRadialControllerScreenContactStartedEventArgs2 interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x40000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2, 0x3d577ef0, 0x3cee, 0x11e6, 0xb5,0x35, 0x00,0x1b,0xdc,0x06,0xab,0x3b);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("3d577ef0-3cee-11e6-b535-001bdc06ab3b")
                IRadialControllerScreenContactStartedEventArgs2 : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE get_IsButtonPressed(
                        boolean *value) = 0;

                    virtual HRESULT STDMETHODCALLTYPE get_SimpleHapticsController(
                        ABI::Windows::Devices::Haptics::ISimpleHapticsController **value) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2, 0x3d577ef0, 0x3cee, 0x11e6, 0xb5,0x35, 0x00,0x1b,0xdc,0x06,0xab,0x3b)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2Vtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2 *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2 *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2 *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2 *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2 *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2 *This,
        TrustLevel *trustLevel);

    /*** IRadialControllerScreenContactStartedEventArgs2 methods ***/
    HRESULT (STDMETHODCALLTYPE *get_IsButtonPressed)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2 *This,
        boolean *value);

    HRESULT (STDMETHODCALLTYPE *get_SimpleHapticsController)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2 *This,
        __x_ABI_CWindows_CDevices_CHaptics_CISimpleHapticsController **value);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2Vtbl;

interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2 {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2Vtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IRadialControllerScreenContactStartedEventArgs2 methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_get_IsButtonPressed(This,value) (This)->lpVtbl->get_IsButtonPressed(This,value)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_get_SimpleHapticsController(This,value) (This)->lpVtbl->get_SimpleHapticsController(This,value)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_AddRef(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_Release(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_GetIids(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IRadialControllerScreenContactStartedEventArgs2 methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_get_IsButtonPressed(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2* This,boolean *value) {
    return This->lpVtbl->get_IsButtonPressed(This,value);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_get_SimpleHapticsController(__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2* This,__x_ABI_CWindows_CDevices_CHaptics_CISimpleHapticsController **value) {
    return This->lpVtbl->get_SimpleHapticsController(This,value);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IRadialControllerScreenContactStartedEventArgs2 IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2
#define IRadialControllerScreenContactStartedEventArgs2Vtbl __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2Vtbl
#define IRadialControllerScreenContactStartedEventArgs2 __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2
#define IRadialControllerScreenContactStartedEventArgs2_QueryInterface __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_QueryInterface
#define IRadialControllerScreenContactStartedEventArgs2_AddRef __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_AddRef
#define IRadialControllerScreenContactStartedEventArgs2_Release __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_Release
#define IRadialControllerScreenContactStartedEventArgs2_GetIids __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_GetIids
#define IRadialControllerScreenContactStartedEventArgs2_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_GetRuntimeClassName
#define IRadialControllerScreenContactStartedEventArgs2_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_GetTrustLevel
#define IRadialControllerScreenContactStartedEventArgs2_get_IsButtonPressed __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_get_IsButtonPressed
#define IRadialControllerScreenContactStartedEventArgs2_get_SimpleHapticsController __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_get_SimpleHapticsController
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs2_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x40000 */

/*****************************************************************************
 * IRadialControllerStatics interface
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000
#ifndef ____x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_INTERFACE_DEFINED__
#define ____x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_INTERFACE_DEFINED__

DEFINE_GUID(IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics, 0xfaded0b7, 0xb84c, 0x4894, 0x87,0xaa, 0x8f,0x25,0xaa,0x5f,0x28,0x8b);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace UI {
            namespace Input {
                MIDL_INTERFACE("faded0b7-b84c-4894-87aa-8f25aa5f288b")
                IRadialControllerStatics : public IInspectable
                {
                    virtual HRESULT STDMETHODCALLTYPE IsSupported(
                        boolean *result) = 0;

                    virtual HRESULT STDMETHODCALLTYPE CreateForCurrentView(
                        ABI::Windows::UI::Input::IRadialController **result) = 0;

                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics, 0xfaded0b7, 0xb84c, 0x4894, 0x87,0xaa, 0x8f,0x25,0xaa,0x5f,0x28,0x8b)
#endif
#else
typedef struct __x_ABI_CWindows_CUI_CInput_CIRadialControllerStaticsVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics *This,
        TrustLevel *trustLevel);

    /*** IRadialControllerStatics methods ***/
    HRESULT (STDMETHODCALLTYPE *IsSupported)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics *This,
        boolean *result);

    HRESULT (STDMETHODCALLTYPE *CreateForCurrentView)(
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialController **result);

    END_INTERFACE
} __x_ABI_CWindows_CUI_CInput_CIRadialControllerStaticsVtbl;

interface __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics {
    CONST_VTBL __x_ABI_CWindows_CUI_CInput_CIRadialControllerStaticsVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IRadialControllerStatics methods ***/
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_IsSupported(This,result) (This)->lpVtbl->IsSupported(This,result)
#define __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_CreateForCurrentView(This,result) (This)->lpVtbl->CreateForCurrentView(This,result)
#else
/*** IUnknown methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_QueryInterface(__x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_AddRef(__x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_Release(__x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_GetIids(__x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_GetRuntimeClassName(__x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_GetTrustLevel(__x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IRadialControllerStatics methods ***/
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_IsSupported(__x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics* This,boolean *result) {
    return This->lpVtbl->IsSupported(This,result);
}
static inline HRESULT __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_CreateForCurrentView(__x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics* This,__x_ABI_CWindows_CUI_CInput_CIRadialController **result) {
    return This->lpVtbl->CreateForCurrentView(This,result);
}
#endif
#ifdef WIDL_using_Windows_UI_Input
#define IID_IRadialControllerStatics IID___x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics
#define IRadialControllerStaticsVtbl __x_ABI_CWindows_CUI_CInput_CIRadialControllerStaticsVtbl
#define IRadialControllerStatics __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics
#define IRadialControllerStatics_QueryInterface __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_QueryInterface
#define IRadialControllerStatics_AddRef __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_AddRef
#define IRadialControllerStatics_Release __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_Release
#define IRadialControllerStatics_GetIids __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_GetIids
#define IRadialControllerStatics_GetRuntimeClassName __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_GetRuntimeClassName
#define IRadialControllerStatics_GetTrustLevel __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_GetTrustLevel
#define IRadialControllerStatics_IsSupported __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_IsSupported
#define IRadialControllerStatics_CreateForCurrentView __x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_CreateForCurrentView
#endif /* WIDL_using_Windows_UI_Input */
#endif

#endif

#endif  /* ____x_ABI_CWindows_CUI_CInput_CIRadialControllerStatics_INTERFACE_DEFINED__ */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000 */

/*
 * Class Windows.UI.Input.PointerPoint
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x10000
#ifndef RUNTIMECLASS_Windows_UI_Input_PointerPoint_DEFINED
#define RUNTIMECLASS_Windows_UI_Input_PointerPoint_DEFINED
#if !defined(_MSC_VER) && !defined(__MINGW32__)
static const WCHAR RuntimeClass_Windows_UI_Input_PointerPoint[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','P','o','i','n','t','e','r','P','o','i','n','t',0};
#elif defined(__GNUC__) && !defined(__cplusplus)
const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_PointerPoint[] = L"Windows.UI.Input.PointerPoint";
#else
extern const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_PointerPoint[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','P','o','i','n','t','e','r','P','o','i','n','t',0};
#endif
#endif /* RUNTIMECLASS_Windows_UI_Input_PointerPoint_DEFINED */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x10000 */

/*
 * Class Windows.UI.Input.PointerPointProperties
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x10000
#ifndef RUNTIMECLASS_Windows_UI_Input_PointerPointProperties_DEFINED
#define RUNTIMECLASS_Windows_UI_Input_PointerPointProperties_DEFINED
#if !defined(_MSC_VER) && !defined(__MINGW32__)
static const WCHAR RuntimeClass_Windows_UI_Input_PointerPointProperties[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','P','o','i','n','t','e','r','P','o','i','n','t','P','r','o','p','e','r','t','i','e','s',0};
#elif defined(__GNUC__) && !defined(__cplusplus)
const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_PointerPointProperties[] = L"Windows.UI.Input.PointerPointProperties";
#else
extern const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_PointerPointProperties[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','P','o','i','n','t','e','r','P','o','i','n','t','P','r','o','p','e','r','t','i','e','s',0};
#endif
#endif /* RUNTIMECLASS_Windows_UI_Input_PointerPointProperties_DEFINED */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x10000 */

/*
 * Class Windows.UI.Input.RadialController
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000
#ifndef RUNTIMECLASS_Windows_UI_Input_RadialController_DEFINED
#define RUNTIMECLASS_Windows_UI_Input_RadialController_DEFINED
#if !defined(_MSC_VER) && !defined(__MINGW32__)
static const WCHAR RuntimeClass_Windows_UI_Input_RadialController[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','R','a','d','i','a','l','C','o','n','t','r','o','l','l','e','r',0};
#elif defined(__GNUC__) && !defined(__cplusplus)
const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_RadialController[] = L"Windows.UI.Input.RadialController";
#else
extern const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_RadialController[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','R','a','d','i','a','l','C','o','n','t','r','o','l','l','e','r',0};
#endif
#endif /* RUNTIMECLASS_Windows_UI_Input_RadialController_DEFINED */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000 */

/*
 * Class Windows.UI.Input.RadialControllerButtonClickedEventArgs
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000
#ifndef RUNTIMECLASS_Windows_UI_Input_RadialControllerButtonClickedEventArgs_DEFINED
#define RUNTIMECLASS_Windows_UI_Input_RadialControllerButtonClickedEventArgs_DEFINED
#if !defined(_MSC_VER) && !defined(__MINGW32__)
static const WCHAR RuntimeClass_Windows_UI_Input_RadialControllerButtonClickedEventArgs[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','R','a','d','i','a','l','C','o','n','t','r','o','l','l','e','r','B','u','t','t','o','n','C','l','i','c','k','e','d','E','v','e','n','t','A','r','g','s',0};
#elif defined(__GNUC__) && !defined(__cplusplus)
const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_RadialControllerButtonClickedEventArgs[] = L"Windows.UI.Input.RadialControllerButtonClickedEventArgs";
#else
extern const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_RadialControllerButtonClickedEventArgs[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','R','a','d','i','a','l','C','o','n','t','r','o','l','l','e','r','B','u','t','t','o','n','C','l','i','c','k','e','d','E','v','e','n','t','A','r','g','s',0};
#endif
#endif /* RUNTIMECLASS_Windows_UI_Input_RadialControllerButtonClickedEventArgs_DEFINED */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000 */

/*
 * Class Windows.UI.Input.RadialControllerButtonHoldingEventArgs
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x40000
#ifndef RUNTIMECLASS_Windows_UI_Input_RadialControllerButtonHoldingEventArgs_DEFINED
#define RUNTIMECLASS_Windows_UI_Input_RadialControllerButtonHoldingEventArgs_DEFINED
#if !defined(_MSC_VER) && !defined(__MINGW32__)
static const WCHAR RuntimeClass_Windows_UI_Input_RadialControllerButtonHoldingEventArgs[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','R','a','d','i','a','l','C','o','n','t','r','o','l','l','e','r','B','u','t','t','o','n','H','o','l','d','i','n','g','E','v','e','n','t','A','r','g','s',0};
#elif defined(__GNUC__) && !defined(__cplusplus)
const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_RadialControllerButtonHoldingEventArgs[] = L"Windows.UI.Input.RadialControllerButtonHoldingEventArgs";
#else
extern const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_RadialControllerButtonHoldingEventArgs[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','R','a','d','i','a','l','C','o','n','t','r','o','l','l','e','r','B','u','t','t','o','n','H','o','l','d','i','n','g','E','v','e','n','t','A','r','g','s',0};
#endif
#endif /* RUNTIMECLASS_Windows_UI_Input_RadialControllerButtonHoldingEventArgs_DEFINED */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x40000 */

/*
 * Class Windows.UI.Input.RadialControllerButtonPressedEventArgs
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x40000
#ifndef RUNTIMECLASS_Windows_UI_Input_RadialControllerButtonPressedEventArgs_DEFINED
#define RUNTIMECLASS_Windows_UI_Input_RadialControllerButtonPressedEventArgs_DEFINED
#if !defined(_MSC_VER) && !defined(__MINGW32__)
static const WCHAR RuntimeClass_Windows_UI_Input_RadialControllerButtonPressedEventArgs[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','R','a','d','i','a','l','C','o','n','t','r','o','l','l','e','r','B','u','t','t','o','n','P','r','e','s','s','e','d','E','v','e','n','t','A','r','g','s',0};
#elif defined(__GNUC__) && !defined(__cplusplus)
const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_RadialControllerButtonPressedEventArgs[] = L"Windows.UI.Input.RadialControllerButtonPressedEventArgs";
#else
extern const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_RadialControllerButtonPressedEventArgs[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','R','a','d','i','a','l','C','o','n','t','r','o','l','l','e','r','B','u','t','t','o','n','P','r','e','s','s','e','d','E','v','e','n','t','A','r','g','s',0};
#endif
#endif /* RUNTIMECLASS_Windows_UI_Input_RadialControllerButtonPressedEventArgs_DEFINED */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x40000 */

/*
 * Class Windows.UI.Input.RadialControllerButtonReleasedEventArgs
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x40000
#ifndef RUNTIMECLASS_Windows_UI_Input_RadialControllerButtonReleasedEventArgs_DEFINED
#define RUNTIMECLASS_Windows_UI_Input_RadialControllerButtonReleasedEventArgs_DEFINED
#if !defined(_MSC_VER) && !defined(__MINGW32__)
static const WCHAR RuntimeClass_Windows_UI_Input_RadialControllerButtonReleasedEventArgs[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','R','a','d','i','a','l','C','o','n','t','r','o','l','l','e','r','B','u','t','t','o','n','R','e','l','e','a','s','e','d','E','v','e','n','t','A','r','g','s',0};
#elif defined(__GNUC__) && !defined(__cplusplus)
const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_RadialControllerButtonReleasedEventArgs[] = L"Windows.UI.Input.RadialControllerButtonReleasedEventArgs";
#else
extern const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_RadialControllerButtonReleasedEventArgs[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','R','a','d','i','a','l','C','o','n','t','r','o','l','l','e','r','B','u','t','t','o','n','R','e','l','e','a','s','e','d','E','v','e','n','t','A','r','g','s',0};
#endif
#endif /* RUNTIMECLASS_Windows_UI_Input_RadialControllerButtonReleasedEventArgs_DEFINED */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x40000 */

/*
 * Class Windows.UI.Input.RadialControllerConfiguration
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000
#ifndef RUNTIMECLASS_Windows_UI_Input_RadialControllerConfiguration_DEFINED
#define RUNTIMECLASS_Windows_UI_Input_RadialControllerConfiguration_DEFINED
#if !defined(_MSC_VER) && !defined(__MINGW32__)
static const WCHAR RuntimeClass_Windows_UI_Input_RadialControllerConfiguration[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','R','a','d','i','a','l','C','o','n','t','r','o','l','l','e','r','C','o','n','f','i','g','u','r','a','t','i','o','n',0};
#elif defined(__GNUC__) && !defined(__cplusplus)
const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_RadialControllerConfiguration[] = L"Windows.UI.Input.RadialControllerConfiguration";
#else
extern const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_RadialControllerConfiguration[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','R','a','d','i','a','l','C','o','n','t','r','o','l','l','e','r','C','o','n','f','i','g','u','r','a','t','i','o','n',0};
#endif
#endif /* RUNTIMECLASS_Windows_UI_Input_RadialControllerConfiguration_DEFINED */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000 */

/*
 * Class Windows.UI.Input.RadialControllerControlAcquiredEventArgs
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000
#ifndef RUNTIMECLASS_Windows_UI_Input_RadialControllerControlAcquiredEventArgs_DEFINED
#define RUNTIMECLASS_Windows_UI_Input_RadialControllerControlAcquiredEventArgs_DEFINED
#if !defined(_MSC_VER) && !defined(__MINGW32__)
static const WCHAR RuntimeClass_Windows_UI_Input_RadialControllerControlAcquiredEventArgs[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','R','a','d','i','a','l','C','o','n','t','r','o','l','l','e','r','C','o','n','t','r','o','l','A','c','q','u','i','r','e','d','E','v','e','n','t','A','r','g','s',0};
#elif defined(__GNUC__) && !defined(__cplusplus)
const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_RadialControllerControlAcquiredEventArgs[] = L"Windows.UI.Input.RadialControllerControlAcquiredEventArgs";
#else
extern const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_RadialControllerControlAcquiredEventArgs[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','R','a','d','i','a','l','C','o','n','t','r','o','l','l','e','r','C','o','n','t','r','o','l','A','c','q','u','i','r','e','d','E','v','e','n','t','A','r','g','s',0};
#endif
#endif /* RUNTIMECLASS_Windows_UI_Input_RadialControllerControlAcquiredEventArgs_DEFINED */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000 */

/*
 * Class Windows.UI.Input.RadialControllerMenu
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000
#ifndef RUNTIMECLASS_Windows_UI_Input_RadialControllerMenu_DEFINED
#define RUNTIMECLASS_Windows_UI_Input_RadialControllerMenu_DEFINED
#if !defined(_MSC_VER) && !defined(__MINGW32__)
static const WCHAR RuntimeClass_Windows_UI_Input_RadialControllerMenu[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','R','a','d','i','a','l','C','o','n','t','r','o','l','l','e','r','M','e','n','u',0};
#elif defined(__GNUC__) && !defined(__cplusplus)
const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_RadialControllerMenu[] = L"Windows.UI.Input.RadialControllerMenu";
#else
extern const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_RadialControllerMenu[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','R','a','d','i','a','l','C','o','n','t','r','o','l','l','e','r','M','e','n','u',0};
#endif
#endif /* RUNTIMECLASS_Windows_UI_Input_RadialControllerMenu_DEFINED */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000 */

/*
 * Class Windows.UI.Input.RadialControllerMenuItem
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000
#ifndef RUNTIMECLASS_Windows_UI_Input_RadialControllerMenuItem_DEFINED
#define RUNTIMECLASS_Windows_UI_Input_RadialControllerMenuItem_DEFINED
#if !defined(_MSC_VER) && !defined(__MINGW32__)
static const WCHAR RuntimeClass_Windows_UI_Input_RadialControllerMenuItem[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','R','a','d','i','a','l','C','o','n','t','r','o','l','l','e','r','M','e','n','u','I','t','e','m',0};
#elif defined(__GNUC__) && !defined(__cplusplus)
const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_RadialControllerMenuItem[] = L"Windows.UI.Input.RadialControllerMenuItem";
#else
extern const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_RadialControllerMenuItem[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','R','a','d','i','a','l','C','o','n','t','r','o','l','l','e','r','M','e','n','u','I','t','e','m',0};
#endif
#endif /* RUNTIMECLASS_Windows_UI_Input_RadialControllerMenuItem_DEFINED */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000 */

/*
 * Class Windows.UI.Input.RadialControllerRotationChangedEventArgs
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000
#ifndef RUNTIMECLASS_Windows_UI_Input_RadialControllerRotationChangedEventArgs_DEFINED
#define RUNTIMECLASS_Windows_UI_Input_RadialControllerRotationChangedEventArgs_DEFINED
#if !defined(_MSC_VER) && !defined(__MINGW32__)
static const WCHAR RuntimeClass_Windows_UI_Input_RadialControllerRotationChangedEventArgs[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','R','a','d','i','a','l','C','o','n','t','r','o','l','l','e','r','R','o','t','a','t','i','o','n','C','h','a','n','g','e','d','E','v','e','n','t','A','r','g','s',0};
#elif defined(__GNUC__) && !defined(__cplusplus)
const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_RadialControllerRotationChangedEventArgs[] = L"Windows.UI.Input.RadialControllerRotationChangedEventArgs";
#else
extern const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_RadialControllerRotationChangedEventArgs[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','R','a','d','i','a','l','C','o','n','t','r','o','l','l','e','r','R','o','t','a','t','i','o','n','C','h','a','n','g','e','d','E','v','e','n','t','A','r','g','s',0};
#endif
#endif /* RUNTIMECLASS_Windows_UI_Input_RadialControllerRotationChangedEventArgs_DEFINED */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000 */

/*
 * Class Windows.UI.Input.RadialControllerScreenContact
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000
#ifndef RUNTIMECLASS_Windows_UI_Input_RadialControllerScreenContact_DEFINED
#define RUNTIMECLASS_Windows_UI_Input_RadialControllerScreenContact_DEFINED
#if !defined(_MSC_VER) && !defined(__MINGW32__)
static const WCHAR RuntimeClass_Windows_UI_Input_RadialControllerScreenContact[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','R','a','d','i','a','l','C','o','n','t','r','o','l','l','e','r','S','c','r','e','e','n','C','o','n','t','a','c','t',0};
#elif defined(__GNUC__) && !defined(__cplusplus)
const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_RadialControllerScreenContact[] = L"Windows.UI.Input.RadialControllerScreenContact";
#else
extern const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_RadialControllerScreenContact[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','R','a','d','i','a','l','C','o','n','t','r','o','l','l','e','r','S','c','r','e','e','n','C','o','n','t','a','c','t',0};
#endif
#endif /* RUNTIMECLASS_Windows_UI_Input_RadialControllerScreenContact_DEFINED */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000 */

/*
 * Class Windows.UI.Input.RadialControllerScreenContactContinuedEventArgs
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000
#ifndef RUNTIMECLASS_Windows_UI_Input_RadialControllerScreenContactContinuedEventArgs_DEFINED
#define RUNTIMECLASS_Windows_UI_Input_RadialControllerScreenContactContinuedEventArgs_DEFINED
#if !defined(_MSC_VER) && !defined(__MINGW32__)
static const WCHAR RuntimeClass_Windows_UI_Input_RadialControllerScreenContactContinuedEventArgs[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','R','a','d','i','a','l','C','o','n','t','r','o','l','l','e','r','S','c','r','e','e','n','C','o','n','t','a','c','t','C','o','n','t','i','n','u','e','d','E','v','e','n','t','A','r','g','s',0};
#elif defined(__GNUC__) && !defined(__cplusplus)
const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_RadialControllerScreenContactContinuedEventArgs[] = L"Windows.UI.Input.RadialControllerScreenContactContinuedEventArgs";
#else
extern const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_RadialControllerScreenContactContinuedEventArgs[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','R','a','d','i','a','l','C','o','n','t','r','o','l','l','e','r','S','c','r','e','e','n','C','o','n','t','a','c','t','C','o','n','t','i','n','u','e','d','E','v','e','n','t','A','r','g','s',0};
#endif
#endif /* RUNTIMECLASS_Windows_UI_Input_RadialControllerScreenContactContinuedEventArgs_DEFINED */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000 */

/*
 * Class Windows.UI.Input.RadialControllerScreenContactStartedEventArgs
 */
#if WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000
#ifndef RUNTIMECLASS_Windows_UI_Input_RadialControllerScreenContactStartedEventArgs_DEFINED
#define RUNTIMECLASS_Windows_UI_Input_RadialControllerScreenContactStartedEventArgs_DEFINED
#if !defined(_MSC_VER) && !defined(__MINGW32__)
static const WCHAR RuntimeClass_Windows_UI_Input_RadialControllerScreenContactStartedEventArgs[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','R','a','d','i','a','l','C','o','n','t','r','o','l','l','e','r','S','c','r','e','e','n','C','o','n','t','a','c','t','S','t','a','r','t','e','d','E','v','e','n','t','A','r','g','s',0};
#elif defined(__GNUC__) && !defined(__cplusplus)
const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_RadialControllerScreenContactStartedEventArgs[] = L"Windows.UI.Input.RadialControllerScreenContactStartedEventArgs";
#else
extern const DECLSPEC_SELECTANY WCHAR RuntimeClass_Windows_UI_Input_RadialControllerScreenContactStartedEventArgs[] = {'W','i','n','d','o','w','s','.','U','I','.','I','n','p','u','t','.','R','a','d','i','a','l','C','o','n','t','r','o','l','l','e','r','S','c','r','e','e','n','C','o','n','t','a','c','t','S','t','a','r','t','e','d','E','v','e','n','t','A','r','g','s',0};
#endif
#endif /* RUNTIMECLASS_Windows_UI_Input_RadialControllerScreenContactStartedEventArgs_DEFINED */
#endif /* WINDOWS_FOUNDATION_UNIVERSALAPICONTRACT_VERSION >= 0x30000 */

/*****************************************************************************
 * IIterable<ABI::Windows::UI::Input::RadialControllerMenuItem* > interface
 */
#ifndef ____FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_INTERFACE_DEFINED__
#define ____FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_INTERFACE_DEFINED__

DEFINE_GUID(IID___FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem, 0x1aa752b3, 0xdc11, 0x5bce, 0xb2,0xb9, 0xcd,0x1b,0xf8,0xf2,0x35,0xbe);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace Foundation {
            namespace Collections {
                template<>
                MIDL_INTERFACE("1aa752b3-dc11-5bce-b2b9-cd1bf8f235be")
                IIterable<ABI::Windows::UI::Input::RadialControllerMenuItem* > : IIterable_impl<ABI::Windows::Foundation::Internal::AggregateType<ABI::Windows::UI::Input::RadialControllerMenuItem*, ABI::Windows::UI::Input::IRadialControllerMenuItem* > >
                {
                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem, 0x1aa752b3, 0xdc11, 0x5bce, 0xb2,0xb9, 0xcd,0x1b,0xf8,0xf2,0x35,0xbe)
#endif
#else
typedef struct __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItemVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        TrustLevel *trustLevel);

    /*** IIterable<ABI::Windows::UI::Input::RadialControllerMenuItem* > methods ***/
    HRESULT (STDMETHODCALLTYPE *First)(
        __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem **value);

    END_INTERFACE
} __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItemVtbl;

interface __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem {
    CONST_VTBL __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItemVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IIterable<ABI::Windows::UI::Input::RadialControllerMenuItem* > methods ***/
#define __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_First(This,value) (This)->lpVtbl->First(This,value)
#else
/*** IUnknown methods ***/
static inline HRESULT __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_QueryInterface(__FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_AddRef(__FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_Release(__FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetIids(__FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetRuntimeClassName(__FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetTrustLevel(__FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IIterable<ABI::Windows::UI::Input::RadialControllerMenuItem* > methods ***/
static inline HRESULT __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_First(__FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,__FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem **value) {
    return This->lpVtbl->First(This,value);
}
#endif
#ifdef WIDL_using_Windows_Foundation_Collections
#define IID_IIterable_RadialControllerMenuItem IID___FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem
#define IIterable_RadialControllerMenuItemVtbl __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItemVtbl
#define IIterable_RadialControllerMenuItem __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem
#define IIterable_RadialControllerMenuItem_QueryInterface __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_QueryInterface
#define IIterable_RadialControllerMenuItem_AddRef __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_AddRef
#define IIterable_RadialControllerMenuItem_Release __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_Release
#define IIterable_RadialControllerMenuItem_GetIids __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetIids
#define IIterable_RadialControllerMenuItem_GetRuntimeClassName __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetRuntimeClassName
#define IIterable_RadialControllerMenuItem_GetTrustLevel __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetTrustLevel
#define IIterable_RadialControllerMenuItem_First __FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_First
#endif /* WIDL_using_Windows_Foundation_Collections */
#endif

#endif

#endif  /* ____FIIterable_1_Windows__CUI__CInput__CRadialControllerMenuItem_INTERFACE_DEFINED__ */

/*****************************************************************************
 * IIterable<ABI::Windows::UI::Input::RadialControllerSystemMenuItemKind > interface
 */
#ifndef ____FIIterable_1_RadialControllerSystemMenuItemKind_INTERFACE_DEFINED__
#define ____FIIterable_1_RadialControllerSystemMenuItemKind_INTERFACE_DEFINED__

DEFINE_GUID(IID___FIIterable_1_RadialControllerSystemMenuItemKind, 0x4516010f, 0xfd98, 0x5e1d, 0xbf,0x3f, 0xae,0xaf,0x79,0xf1,0xf3,0xda);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace Foundation {
            namespace Collections {
                template<>
                MIDL_INTERFACE("4516010f-fd98-5e1d-bf3f-aeaf79f1f3da")
                IIterable<ABI::Windows::UI::Input::RadialControllerSystemMenuItemKind > : IIterable_impl<ABI::Windows::UI::Input::RadialControllerSystemMenuItemKind >
                {
                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__FIIterable_1_RadialControllerSystemMenuItemKind, 0x4516010f, 0xfd98, 0x5e1d, 0xbf,0x3f, 0xae,0xaf,0x79,0xf1,0xf3,0xda)
#endif
#else
typedef struct __FIIterable_1_RadialControllerSystemMenuItemKindVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __FIIterable_1_RadialControllerSystemMenuItemKind *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __FIIterable_1_RadialControllerSystemMenuItemKind *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __FIIterable_1_RadialControllerSystemMenuItemKind *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __FIIterable_1_RadialControllerSystemMenuItemKind *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __FIIterable_1_RadialControllerSystemMenuItemKind *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __FIIterable_1_RadialControllerSystemMenuItemKind *This,
        TrustLevel *trustLevel);

    /*** IIterable<ABI::Windows::UI::Input::RadialControllerSystemMenuItemKind > methods ***/
    HRESULT (STDMETHODCALLTYPE *First)(
        __FIIterable_1_RadialControllerSystemMenuItemKind *This,
        __FIIterator_1_RadialControllerSystemMenuItemKind **value);

    END_INTERFACE
} __FIIterable_1_RadialControllerSystemMenuItemKindVtbl;

interface __FIIterable_1_RadialControllerSystemMenuItemKind {
    CONST_VTBL __FIIterable_1_RadialControllerSystemMenuItemKindVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __FIIterable_1_RadialControllerSystemMenuItemKind_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __FIIterable_1_RadialControllerSystemMenuItemKind_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __FIIterable_1_RadialControllerSystemMenuItemKind_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __FIIterable_1_RadialControllerSystemMenuItemKind_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __FIIterable_1_RadialControllerSystemMenuItemKind_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __FIIterable_1_RadialControllerSystemMenuItemKind_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IIterable<ABI::Windows::UI::Input::RadialControllerSystemMenuItemKind > methods ***/
#define __FIIterable_1_RadialControllerSystemMenuItemKind_First(This,value) (This)->lpVtbl->First(This,value)
#else
/*** IUnknown methods ***/
static inline HRESULT __FIIterable_1_RadialControllerSystemMenuItemKind_QueryInterface(__FIIterable_1_RadialControllerSystemMenuItemKind* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __FIIterable_1_RadialControllerSystemMenuItemKind_AddRef(__FIIterable_1_RadialControllerSystemMenuItemKind* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __FIIterable_1_RadialControllerSystemMenuItemKind_Release(__FIIterable_1_RadialControllerSystemMenuItemKind* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __FIIterable_1_RadialControllerSystemMenuItemKind_GetIids(__FIIterable_1_RadialControllerSystemMenuItemKind* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __FIIterable_1_RadialControllerSystemMenuItemKind_GetRuntimeClassName(__FIIterable_1_RadialControllerSystemMenuItemKind* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __FIIterable_1_RadialControllerSystemMenuItemKind_GetTrustLevel(__FIIterable_1_RadialControllerSystemMenuItemKind* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IIterable<ABI::Windows::UI::Input::RadialControllerSystemMenuItemKind > methods ***/
static inline HRESULT __FIIterable_1_RadialControllerSystemMenuItemKind_First(__FIIterable_1_RadialControllerSystemMenuItemKind* This,__FIIterator_1_RadialControllerSystemMenuItemKind **value) {
    return This->lpVtbl->First(This,value);
}
#endif
#ifdef WIDL_using_Windows_Foundation_Collections
#define IID_IIterable_RadialControllerSystemMenuItemKind IID___FIIterable_1_RadialControllerSystemMenuItemKind
#define IIterable_RadialControllerSystemMenuItemKindVtbl __FIIterable_1_RadialControllerSystemMenuItemKindVtbl
#define IIterable_RadialControllerSystemMenuItemKind __FIIterable_1_RadialControllerSystemMenuItemKind
#define IIterable_RadialControllerSystemMenuItemKind_QueryInterface __FIIterable_1_RadialControllerSystemMenuItemKind_QueryInterface
#define IIterable_RadialControllerSystemMenuItemKind_AddRef __FIIterable_1_RadialControllerSystemMenuItemKind_AddRef
#define IIterable_RadialControllerSystemMenuItemKind_Release __FIIterable_1_RadialControllerSystemMenuItemKind_Release
#define IIterable_RadialControllerSystemMenuItemKind_GetIids __FIIterable_1_RadialControllerSystemMenuItemKind_GetIids
#define IIterable_RadialControllerSystemMenuItemKind_GetRuntimeClassName __FIIterable_1_RadialControllerSystemMenuItemKind_GetRuntimeClassName
#define IIterable_RadialControllerSystemMenuItemKind_GetTrustLevel __FIIterable_1_RadialControllerSystemMenuItemKind_GetTrustLevel
#define IIterable_RadialControllerSystemMenuItemKind_First __FIIterable_1_RadialControllerSystemMenuItemKind_First
#endif /* WIDL_using_Windows_Foundation_Collections */
#endif

#endif

#endif  /* ____FIIterable_1_RadialControllerSystemMenuItemKind_INTERFACE_DEFINED__ */

/*****************************************************************************
 * IIterator<ABI::Windows::UI::Input::RadialControllerMenuItem* > interface
 */
#ifndef ____FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_INTERFACE_DEFINED__
#define ____FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_INTERFACE_DEFINED__

DEFINE_GUID(IID___FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem, 0x5a773e24, 0xd968, 0x535e, 0x96,0x9a, 0x76,0xce,0x36,0x02,0xa6,0x37);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace Foundation {
            namespace Collections {
                template<>
                MIDL_INTERFACE("5a773e24-d968-535e-969a-76ce3602a637")
                IIterator<ABI::Windows::UI::Input::RadialControllerMenuItem* > : IIterator_impl<ABI::Windows::Foundation::Internal::AggregateType<ABI::Windows::UI::Input::RadialControllerMenuItem*, ABI::Windows::UI::Input::IRadialControllerMenuItem* > >
                {
                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem, 0x5a773e24, 0xd968, 0x535e, 0x96,0x9a, 0x76,0xce,0x36,0x02,0xa6,0x37)
#endif
#else
typedef struct __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItemVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        TrustLevel *trustLevel);

    /*** IIterator<ABI::Windows::UI::Input::RadialControllerMenuItem* > methods ***/
    HRESULT (STDMETHODCALLTYPE *get_Current)(
        __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem **value);

    HRESULT (STDMETHODCALLTYPE *get_HasCurrent)(
        __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        boolean *value);

    HRESULT (STDMETHODCALLTYPE *MoveNext)(
        __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        boolean *value);

    HRESULT (STDMETHODCALLTYPE *GetMany)(
        __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        UINT32 items_size,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem **items,
        UINT32 *value);

    END_INTERFACE
} __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItemVtbl;

interface __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem {
    CONST_VTBL __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItemVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IIterator<ABI::Windows::UI::Input::RadialControllerMenuItem* > methods ***/
#define __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_get_Current(This,value) (This)->lpVtbl->get_Current(This,value)
#define __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_get_HasCurrent(This,value) (This)->lpVtbl->get_HasCurrent(This,value)
#define __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_MoveNext(This,value) (This)->lpVtbl->MoveNext(This,value)
#define __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetMany(This,items_size,items,value) (This)->lpVtbl->GetMany(This,items_size,items,value)
#else
/*** IUnknown methods ***/
static inline HRESULT __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_QueryInterface(__FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_AddRef(__FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_Release(__FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetIids(__FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetRuntimeClassName(__FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetTrustLevel(__FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IIterator<ABI::Windows::UI::Input::RadialControllerMenuItem* > methods ***/
static inline HRESULT __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_get_Current(__FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem **value) {
    return This->lpVtbl->get_Current(This,value);
}
static inline HRESULT __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_get_HasCurrent(__FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,boolean *value) {
    return This->lpVtbl->get_HasCurrent(This,value);
}
static inline HRESULT __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_MoveNext(__FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,boolean *value) {
    return This->lpVtbl->MoveNext(This,value);
}
static inline HRESULT __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetMany(__FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,UINT32 items_size,__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem **items,UINT32 *value) {
    return This->lpVtbl->GetMany(This,items_size,items,value);
}
#endif
#ifdef WIDL_using_Windows_Foundation_Collections
#define IID_IIterator_RadialControllerMenuItem IID___FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem
#define IIterator_RadialControllerMenuItemVtbl __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItemVtbl
#define IIterator_RadialControllerMenuItem __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem
#define IIterator_RadialControllerMenuItem_QueryInterface __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_QueryInterface
#define IIterator_RadialControllerMenuItem_AddRef __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_AddRef
#define IIterator_RadialControllerMenuItem_Release __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_Release
#define IIterator_RadialControllerMenuItem_GetIids __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetIids
#define IIterator_RadialControllerMenuItem_GetRuntimeClassName __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetRuntimeClassName
#define IIterator_RadialControllerMenuItem_GetTrustLevel __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetTrustLevel
#define IIterator_RadialControllerMenuItem_get_Current __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_get_Current
#define IIterator_RadialControllerMenuItem_get_HasCurrent __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_get_HasCurrent
#define IIterator_RadialControllerMenuItem_MoveNext __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_MoveNext
#define IIterator_RadialControllerMenuItem_GetMany __FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetMany
#endif /* WIDL_using_Windows_Foundation_Collections */
#endif

#endif

#endif  /* ____FIIterator_1_Windows__CUI__CInput__CRadialControllerMenuItem_INTERFACE_DEFINED__ */

/*****************************************************************************
 * IIterator<ABI::Windows::UI::Input::RadialControllerSystemMenuItemKind > interface
 */
#ifndef ____FIIterator_1_RadialControllerSystemMenuItemKind_INTERFACE_DEFINED__
#define ____FIIterator_1_RadialControllerSystemMenuItemKind_INTERFACE_DEFINED__

DEFINE_GUID(IID___FIIterator_1_RadialControllerSystemMenuItemKind, 0x3fbc1858, 0xa43e, 0x54dc, 0xb0,0xe2, 0x8b,0x09,0x8b,0xdd,0xac,0xf6);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace Foundation {
            namespace Collections {
                template<>
                MIDL_INTERFACE("3fbc1858-a43e-54dc-b0e2-8b098bddacf6")
                IIterator<ABI::Windows::UI::Input::RadialControllerSystemMenuItemKind > : IIterator_impl<ABI::Windows::UI::Input::RadialControllerSystemMenuItemKind >
                {
                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__FIIterator_1_RadialControllerSystemMenuItemKind, 0x3fbc1858, 0xa43e, 0x54dc, 0xb0,0xe2, 0x8b,0x09,0x8b,0xdd,0xac,0xf6)
#endif
#else
typedef struct __FIIterator_1_RadialControllerSystemMenuItemKindVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __FIIterator_1_RadialControllerSystemMenuItemKind *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __FIIterator_1_RadialControllerSystemMenuItemKind *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __FIIterator_1_RadialControllerSystemMenuItemKind *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __FIIterator_1_RadialControllerSystemMenuItemKind *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __FIIterator_1_RadialControllerSystemMenuItemKind *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __FIIterator_1_RadialControllerSystemMenuItemKind *This,
        TrustLevel *trustLevel);

    /*** IIterator<ABI::Windows::UI::Input::RadialControllerSystemMenuItemKind > methods ***/
    HRESULT (STDMETHODCALLTYPE *get_Current)(
        __FIIterator_1_RadialControllerSystemMenuItemKind *This,
        __x_ABI_CWindows_CUI_CInput_CRadialControllerSystemMenuItemKind *value);

    HRESULT (STDMETHODCALLTYPE *get_HasCurrent)(
        __FIIterator_1_RadialControllerSystemMenuItemKind *This,
        boolean *value);

    HRESULT (STDMETHODCALLTYPE *MoveNext)(
        __FIIterator_1_RadialControllerSystemMenuItemKind *This,
        boolean *value);

    HRESULT (STDMETHODCALLTYPE *GetMany)(
        __FIIterator_1_RadialControllerSystemMenuItemKind *This,
        UINT32 items_size,
        __x_ABI_CWindows_CUI_CInput_CRadialControllerSystemMenuItemKind *items,
        UINT32 *value);

    END_INTERFACE
} __FIIterator_1_RadialControllerSystemMenuItemKindVtbl;

interface __FIIterator_1_RadialControllerSystemMenuItemKind {
    CONST_VTBL __FIIterator_1_RadialControllerSystemMenuItemKindVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __FIIterator_1_RadialControllerSystemMenuItemKind_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __FIIterator_1_RadialControllerSystemMenuItemKind_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __FIIterator_1_RadialControllerSystemMenuItemKind_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __FIIterator_1_RadialControllerSystemMenuItemKind_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __FIIterator_1_RadialControllerSystemMenuItemKind_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __FIIterator_1_RadialControllerSystemMenuItemKind_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IIterator<ABI::Windows::UI::Input::RadialControllerSystemMenuItemKind > methods ***/
#define __FIIterator_1_RadialControllerSystemMenuItemKind_get_Current(This,value) (This)->lpVtbl->get_Current(This,value)
#define __FIIterator_1_RadialControllerSystemMenuItemKind_get_HasCurrent(This,value) (This)->lpVtbl->get_HasCurrent(This,value)
#define __FIIterator_1_RadialControllerSystemMenuItemKind_MoveNext(This,value) (This)->lpVtbl->MoveNext(This,value)
#define __FIIterator_1_RadialControllerSystemMenuItemKind_GetMany(This,items_size,items,value) (This)->lpVtbl->GetMany(This,items_size,items,value)
#else
/*** IUnknown methods ***/
static inline HRESULT __FIIterator_1_RadialControllerSystemMenuItemKind_QueryInterface(__FIIterator_1_RadialControllerSystemMenuItemKind* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __FIIterator_1_RadialControllerSystemMenuItemKind_AddRef(__FIIterator_1_RadialControllerSystemMenuItemKind* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __FIIterator_1_RadialControllerSystemMenuItemKind_Release(__FIIterator_1_RadialControllerSystemMenuItemKind* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __FIIterator_1_RadialControllerSystemMenuItemKind_GetIids(__FIIterator_1_RadialControllerSystemMenuItemKind* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __FIIterator_1_RadialControllerSystemMenuItemKind_GetRuntimeClassName(__FIIterator_1_RadialControllerSystemMenuItemKind* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __FIIterator_1_RadialControllerSystemMenuItemKind_GetTrustLevel(__FIIterator_1_RadialControllerSystemMenuItemKind* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IIterator<ABI::Windows::UI::Input::RadialControllerSystemMenuItemKind > methods ***/
static inline HRESULT __FIIterator_1_RadialControllerSystemMenuItemKind_get_Current(__FIIterator_1_RadialControllerSystemMenuItemKind* This,__x_ABI_CWindows_CUI_CInput_CRadialControllerSystemMenuItemKind *value) {
    return This->lpVtbl->get_Current(This,value);
}
static inline HRESULT __FIIterator_1_RadialControllerSystemMenuItemKind_get_HasCurrent(__FIIterator_1_RadialControllerSystemMenuItemKind* This,boolean *value) {
    return This->lpVtbl->get_HasCurrent(This,value);
}
static inline HRESULT __FIIterator_1_RadialControllerSystemMenuItemKind_MoveNext(__FIIterator_1_RadialControllerSystemMenuItemKind* This,boolean *value) {
    return This->lpVtbl->MoveNext(This,value);
}
static inline HRESULT __FIIterator_1_RadialControllerSystemMenuItemKind_GetMany(__FIIterator_1_RadialControllerSystemMenuItemKind* This,UINT32 items_size,__x_ABI_CWindows_CUI_CInput_CRadialControllerSystemMenuItemKind *items,UINT32 *value) {
    return This->lpVtbl->GetMany(This,items_size,items,value);
}
#endif
#ifdef WIDL_using_Windows_Foundation_Collections
#define IID_IIterator_RadialControllerSystemMenuItemKind IID___FIIterator_1_RadialControllerSystemMenuItemKind
#define IIterator_RadialControllerSystemMenuItemKindVtbl __FIIterator_1_RadialControllerSystemMenuItemKindVtbl
#define IIterator_RadialControllerSystemMenuItemKind __FIIterator_1_RadialControllerSystemMenuItemKind
#define IIterator_RadialControllerSystemMenuItemKind_QueryInterface __FIIterator_1_RadialControllerSystemMenuItemKind_QueryInterface
#define IIterator_RadialControllerSystemMenuItemKind_AddRef __FIIterator_1_RadialControllerSystemMenuItemKind_AddRef
#define IIterator_RadialControllerSystemMenuItemKind_Release __FIIterator_1_RadialControllerSystemMenuItemKind_Release
#define IIterator_RadialControllerSystemMenuItemKind_GetIids __FIIterator_1_RadialControllerSystemMenuItemKind_GetIids
#define IIterator_RadialControllerSystemMenuItemKind_GetRuntimeClassName __FIIterator_1_RadialControllerSystemMenuItemKind_GetRuntimeClassName
#define IIterator_RadialControllerSystemMenuItemKind_GetTrustLevel __FIIterator_1_RadialControllerSystemMenuItemKind_GetTrustLevel
#define IIterator_RadialControllerSystemMenuItemKind_get_Current __FIIterator_1_RadialControllerSystemMenuItemKind_get_Current
#define IIterator_RadialControllerSystemMenuItemKind_get_HasCurrent __FIIterator_1_RadialControllerSystemMenuItemKind_get_HasCurrent
#define IIterator_RadialControllerSystemMenuItemKind_MoveNext __FIIterator_1_RadialControllerSystemMenuItemKind_MoveNext
#define IIterator_RadialControllerSystemMenuItemKind_GetMany __FIIterator_1_RadialControllerSystemMenuItemKind_GetMany
#endif /* WIDL_using_Windows_Foundation_Collections */
#endif

#endif

#endif  /* ____FIIterator_1_RadialControllerSystemMenuItemKind_INTERFACE_DEFINED__ */

/*****************************************************************************
 * IVectorView<ABI::Windows::UI::Input::PointerPoint* > interface
 */
#ifndef ____FIVectorView_1_Windows__CUI__CInput__CPointerPoint_INTERFACE_DEFINED__
#define ____FIVectorView_1_Windows__CUI__CInput__CPointerPoint_INTERFACE_DEFINED__

DEFINE_GUID(IID___FIVectorView_1_Windows__CUI__CInput__CPointerPoint, 0xf0f57411, 0x7786, 0x5174, 0x87,0x52, 0x4c,0x5e,0x83,0x4b,0x6d,0xa2);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace Foundation {
            namespace Collections {
                template<>
                MIDL_INTERFACE("f0f57411-7786-5174-8752-4c5e834b6da2")
                IVectorView<ABI::Windows::UI::Input::PointerPoint* > : IVectorView_impl<ABI::Windows::Foundation::Internal::AggregateType<ABI::Windows::UI::Input::PointerPoint*, ABI::Windows::UI::Input::IPointerPoint* > >
                {
                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__FIVectorView_1_Windows__CUI__CInput__CPointerPoint, 0xf0f57411, 0x7786, 0x5174, 0x87,0x52, 0x4c,0x5e,0x83,0x4b,0x6d,0xa2)
#endif
#else
typedef struct __FIVectorView_1_Windows__CUI__CInput__CPointerPointVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __FIVectorView_1_Windows__CUI__CInput__CPointerPoint *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __FIVectorView_1_Windows__CUI__CInput__CPointerPoint *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __FIVectorView_1_Windows__CUI__CInput__CPointerPoint *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __FIVectorView_1_Windows__CUI__CInput__CPointerPoint *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __FIVectorView_1_Windows__CUI__CInput__CPointerPoint *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __FIVectorView_1_Windows__CUI__CInput__CPointerPoint *This,
        TrustLevel *trustLevel);

    /*** IVectorView<ABI::Windows::UI::Input::PointerPoint* > methods ***/
    HRESULT (STDMETHODCALLTYPE *GetAt)(
        __FIVectorView_1_Windows__CUI__CInput__CPointerPoint *This,
        UINT32 index,
        __x_ABI_CWindows_CUI_CInput_CIPointerPoint **value);

    HRESULT (STDMETHODCALLTYPE *get_Size)(
        __FIVectorView_1_Windows__CUI__CInput__CPointerPoint *This,
        UINT32 *value);

    HRESULT (STDMETHODCALLTYPE *IndexOf)(
        __FIVectorView_1_Windows__CUI__CInput__CPointerPoint *This,
        __x_ABI_CWindows_CUI_CInput_CIPointerPoint *element,
        UINT32 *index,
        BOOLEAN *value);

    HRESULT (STDMETHODCALLTYPE *GetMany)(
        __FIVectorView_1_Windows__CUI__CInput__CPointerPoint *This,
        UINT32 start_index,
        UINT32 items_size,
        __x_ABI_CWindows_CUI_CInput_CIPointerPoint **items,
        UINT32 *value);

    END_INTERFACE
} __FIVectorView_1_Windows__CUI__CInput__CPointerPointVtbl;

interface __FIVectorView_1_Windows__CUI__CInput__CPointerPoint {
    CONST_VTBL __FIVectorView_1_Windows__CUI__CInput__CPointerPointVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IVectorView<ABI::Windows::UI::Input::PointerPoint* > methods ***/
#define __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_GetAt(This,index,value) (This)->lpVtbl->GetAt(This,index,value)
#define __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_get_Size(This,value) (This)->lpVtbl->get_Size(This,value)
#define __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_IndexOf(This,element,index,value) (This)->lpVtbl->IndexOf(This,element,index,value)
#define __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_GetMany(This,start_index,items_size,items,value) (This)->lpVtbl->GetMany(This,start_index,items_size,items,value)
#else
/*** IUnknown methods ***/
static inline HRESULT __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_QueryInterface(__FIVectorView_1_Windows__CUI__CInput__CPointerPoint* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_AddRef(__FIVectorView_1_Windows__CUI__CInput__CPointerPoint* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_Release(__FIVectorView_1_Windows__CUI__CInput__CPointerPoint* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_GetIids(__FIVectorView_1_Windows__CUI__CInput__CPointerPoint* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_GetRuntimeClassName(__FIVectorView_1_Windows__CUI__CInput__CPointerPoint* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_GetTrustLevel(__FIVectorView_1_Windows__CUI__CInput__CPointerPoint* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IVectorView<ABI::Windows::UI::Input::PointerPoint* > methods ***/
static inline HRESULT __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_GetAt(__FIVectorView_1_Windows__CUI__CInput__CPointerPoint* This,UINT32 index,__x_ABI_CWindows_CUI_CInput_CIPointerPoint **value) {
    return This->lpVtbl->GetAt(This,index,value);
}
static inline HRESULT __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_get_Size(__FIVectorView_1_Windows__CUI__CInput__CPointerPoint* This,UINT32 *value) {
    return This->lpVtbl->get_Size(This,value);
}
static inline HRESULT __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_IndexOf(__FIVectorView_1_Windows__CUI__CInput__CPointerPoint* This,__x_ABI_CWindows_CUI_CInput_CIPointerPoint *element,UINT32 *index,BOOLEAN *value) {
    return This->lpVtbl->IndexOf(This,element,index,value);
}
static inline HRESULT __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_GetMany(__FIVectorView_1_Windows__CUI__CInput__CPointerPoint* This,UINT32 start_index,UINT32 items_size,__x_ABI_CWindows_CUI_CInput_CIPointerPoint **items,UINT32 *value) {
    return This->lpVtbl->GetMany(This,start_index,items_size,items,value);
}
#endif
#ifdef WIDL_using_Windows_Foundation_Collections
#define IID_IVectorView_PointerPoint IID___FIVectorView_1_Windows__CUI__CInput__CPointerPoint
#define IVectorView_PointerPointVtbl __FIVectorView_1_Windows__CUI__CInput__CPointerPointVtbl
#define IVectorView_PointerPoint __FIVectorView_1_Windows__CUI__CInput__CPointerPoint
#define IVectorView_PointerPoint_QueryInterface __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_QueryInterface
#define IVectorView_PointerPoint_AddRef __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_AddRef
#define IVectorView_PointerPoint_Release __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_Release
#define IVectorView_PointerPoint_GetIids __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_GetIids
#define IVectorView_PointerPoint_GetRuntimeClassName __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_GetRuntimeClassName
#define IVectorView_PointerPoint_GetTrustLevel __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_GetTrustLevel
#define IVectorView_PointerPoint_GetAt __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_GetAt
#define IVectorView_PointerPoint_get_Size __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_get_Size
#define IVectorView_PointerPoint_IndexOf __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_IndexOf
#define IVectorView_PointerPoint_GetMany __FIVectorView_1_Windows__CUI__CInput__CPointerPoint_GetMany
#endif /* WIDL_using_Windows_Foundation_Collections */
#endif

#endif

#endif  /* ____FIVectorView_1_Windows__CUI__CInput__CPointerPoint_INTERFACE_DEFINED__ */

/*****************************************************************************
 * IVectorView<ABI::Windows::UI::Input::RadialControllerMenuItem* > interface
 */
#ifndef ____FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_INTERFACE_DEFINED__
#define ____FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_INTERFACE_DEFINED__

DEFINE_GUID(IID___FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem, 0xb91a7342, 0x3fcb, 0x512b, 0xae,0xf1, 0xfd,0xa4,0x71,0x2e,0x58,0x17);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace Foundation {
            namespace Collections {
                template<>
                MIDL_INTERFACE("b91a7342-3fcb-512b-aef1-fda4712e5817")
                IVectorView<ABI::Windows::UI::Input::RadialControllerMenuItem* > : IVectorView_impl<ABI::Windows::Foundation::Internal::AggregateType<ABI::Windows::UI::Input::RadialControllerMenuItem*, ABI::Windows::UI::Input::IRadialControllerMenuItem* > >
                {
                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem, 0xb91a7342, 0x3fcb, 0x512b, 0xae,0xf1, 0xfd,0xa4,0x71,0x2e,0x58,0x17)
#endif
#else
typedef struct __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItemVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        TrustLevel *trustLevel);

    /*** IVectorView<ABI::Windows::UI::Input::RadialControllerMenuItem* > methods ***/
    HRESULT (STDMETHODCALLTYPE *GetAt)(
        __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        UINT32 index,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem **value);

    HRESULT (STDMETHODCALLTYPE *get_Size)(
        __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        UINT32 *value);

    HRESULT (STDMETHODCALLTYPE *IndexOf)(
        __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem *element,
        UINT32 *index,
        BOOLEAN *value);

    HRESULT (STDMETHODCALLTYPE *GetMany)(
        __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        UINT32 start_index,
        UINT32 items_size,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem **items,
        UINT32 *value);

    END_INTERFACE
} __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItemVtbl;

interface __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem {
    CONST_VTBL __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItemVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IVectorView<ABI::Windows::UI::Input::RadialControllerMenuItem* > methods ***/
#define __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetAt(This,index,value) (This)->lpVtbl->GetAt(This,index,value)
#define __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_get_Size(This,value) (This)->lpVtbl->get_Size(This,value)
#define __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_IndexOf(This,element,index,value) (This)->lpVtbl->IndexOf(This,element,index,value)
#define __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetMany(This,start_index,items_size,items,value) (This)->lpVtbl->GetMany(This,start_index,items_size,items,value)
#else
/*** IUnknown methods ***/
static inline HRESULT __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_QueryInterface(__FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_AddRef(__FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_Release(__FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetIids(__FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetRuntimeClassName(__FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetTrustLevel(__FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IVectorView<ABI::Windows::UI::Input::RadialControllerMenuItem* > methods ***/
static inline HRESULT __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetAt(__FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,UINT32 index,__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem **value) {
    return This->lpVtbl->GetAt(This,index,value);
}
static inline HRESULT __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_get_Size(__FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,UINT32 *value) {
    return This->lpVtbl->get_Size(This,value);
}
static inline HRESULT __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_IndexOf(__FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem *element,UINT32 *index,BOOLEAN *value) {
    return This->lpVtbl->IndexOf(This,element,index,value);
}
static inline HRESULT __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetMany(__FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,UINT32 start_index,UINT32 items_size,__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem **items,UINT32 *value) {
    return This->lpVtbl->GetMany(This,start_index,items_size,items,value);
}
#endif
#ifdef WIDL_using_Windows_Foundation_Collections
#define IID_IVectorView_RadialControllerMenuItem IID___FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem
#define IVectorView_RadialControllerMenuItemVtbl __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItemVtbl
#define IVectorView_RadialControllerMenuItem __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem
#define IVectorView_RadialControllerMenuItem_QueryInterface __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_QueryInterface
#define IVectorView_RadialControllerMenuItem_AddRef __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_AddRef
#define IVectorView_RadialControllerMenuItem_Release __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_Release
#define IVectorView_RadialControllerMenuItem_GetIids __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetIids
#define IVectorView_RadialControllerMenuItem_GetRuntimeClassName __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetRuntimeClassName
#define IVectorView_RadialControllerMenuItem_GetTrustLevel __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetTrustLevel
#define IVectorView_RadialControllerMenuItem_GetAt __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetAt
#define IVectorView_RadialControllerMenuItem_get_Size __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_get_Size
#define IVectorView_RadialControllerMenuItem_IndexOf __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_IndexOf
#define IVectorView_RadialControllerMenuItem_GetMany __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetMany
#endif /* WIDL_using_Windows_Foundation_Collections */
#endif

#endif

#endif  /* ____FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem_INTERFACE_DEFINED__ */

/*****************************************************************************
 * IVector<ABI::Windows::UI::Input::PointerPoint* > interface
 */
#ifndef ____FIVector_1_Windows__CUI__CInput__CPointerPoint_INTERFACE_DEFINED__
#define ____FIVector_1_Windows__CUI__CInput__CPointerPoint_INTERFACE_DEFINED__

DEFINE_GUID(IID___FIVector_1_Windows__CUI__CInput__CPointerPoint, 0xdfa655cf, 0xfde7, 0x5048, 0xb4,0xbf, 0xc9,0x09,0x23,0x1b,0x7e,0xdb);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace Foundation {
            namespace Collections {
                template<>
                MIDL_INTERFACE("dfa655cf-fde7-5048-b4bf-c909231b7edb")
                IVector<ABI::Windows::UI::Input::PointerPoint* > : IVector_impl<ABI::Windows::Foundation::Internal::AggregateType<ABI::Windows::UI::Input::PointerPoint*, ABI::Windows::UI::Input::IPointerPoint* > >
                {
                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__FIVector_1_Windows__CUI__CInput__CPointerPoint, 0xdfa655cf, 0xfde7, 0x5048, 0xb4,0xbf, 0xc9,0x09,0x23,0x1b,0x7e,0xdb)
#endif
#else
typedef struct __FIVector_1_Windows__CUI__CInput__CPointerPointVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __FIVector_1_Windows__CUI__CInput__CPointerPoint *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __FIVector_1_Windows__CUI__CInput__CPointerPoint *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __FIVector_1_Windows__CUI__CInput__CPointerPoint *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __FIVector_1_Windows__CUI__CInput__CPointerPoint *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __FIVector_1_Windows__CUI__CInput__CPointerPoint *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __FIVector_1_Windows__CUI__CInput__CPointerPoint *This,
        TrustLevel *trustLevel);

    /*** IVector<ABI::Windows::UI::Input::PointerPoint* > methods ***/
    HRESULT (STDMETHODCALLTYPE *GetAt)(
        __FIVector_1_Windows__CUI__CInput__CPointerPoint *This,
        UINT32 index,
        __x_ABI_CWindows_CUI_CInput_CIPointerPoint **value);

    HRESULT (STDMETHODCALLTYPE *get_Size)(
        __FIVector_1_Windows__CUI__CInput__CPointerPoint *This,
        UINT32 *value);

    HRESULT (STDMETHODCALLTYPE *GetView)(
        __FIVector_1_Windows__CUI__CInput__CPointerPoint *This,
        __FIVectorView_1_Windows__CUI__CInput__CPointerPoint **value);

    HRESULT (STDMETHODCALLTYPE *IndexOf)(
        __FIVector_1_Windows__CUI__CInput__CPointerPoint *This,
        __x_ABI_CWindows_CUI_CInput_CIPointerPoint *element,
        UINT32 *index,
        BOOLEAN *value);

    HRESULT (STDMETHODCALLTYPE *SetAt)(
        __FIVector_1_Windows__CUI__CInput__CPointerPoint *This,
        UINT32 index,
        __x_ABI_CWindows_CUI_CInput_CIPointerPoint *value);

    HRESULT (STDMETHODCALLTYPE *InsertAt)(
        __FIVector_1_Windows__CUI__CInput__CPointerPoint *This,
        UINT32 index,
        __x_ABI_CWindows_CUI_CInput_CIPointerPoint *value);

    HRESULT (STDMETHODCALLTYPE *RemoveAt)(
        __FIVector_1_Windows__CUI__CInput__CPointerPoint *This,
        UINT32 index);

    HRESULT (STDMETHODCALLTYPE *Append)(
        __FIVector_1_Windows__CUI__CInput__CPointerPoint *This,
        __x_ABI_CWindows_CUI_CInput_CIPointerPoint *value);

    HRESULT (STDMETHODCALLTYPE *RemoveAtEnd)(
        __FIVector_1_Windows__CUI__CInput__CPointerPoint *This);

    HRESULT (STDMETHODCALLTYPE *Clear)(
        __FIVector_1_Windows__CUI__CInput__CPointerPoint *This);

    HRESULT (STDMETHODCALLTYPE *GetMany)(
        __FIVector_1_Windows__CUI__CInput__CPointerPoint *This,
        UINT32 start_index,
        UINT32 items_size,
        __x_ABI_CWindows_CUI_CInput_CIPointerPoint **items,
        UINT32 *value);

    HRESULT (STDMETHODCALLTYPE *ReplaceAll)(
        __FIVector_1_Windows__CUI__CInput__CPointerPoint *This,
        UINT32 count,
        __x_ABI_CWindows_CUI_CInput_CIPointerPoint **items);

    END_INTERFACE
} __FIVector_1_Windows__CUI__CInput__CPointerPointVtbl;

interface __FIVector_1_Windows__CUI__CInput__CPointerPoint {
    CONST_VTBL __FIVector_1_Windows__CUI__CInput__CPointerPointVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __FIVector_1_Windows__CUI__CInput__CPointerPoint_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __FIVector_1_Windows__CUI__CInput__CPointerPoint_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __FIVector_1_Windows__CUI__CInput__CPointerPoint_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __FIVector_1_Windows__CUI__CInput__CPointerPoint_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __FIVector_1_Windows__CUI__CInput__CPointerPoint_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __FIVector_1_Windows__CUI__CInput__CPointerPoint_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IVector<ABI::Windows::UI::Input::PointerPoint* > methods ***/
#define __FIVector_1_Windows__CUI__CInput__CPointerPoint_GetAt(This,index,value) (This)->lpVtbl->GetAt(This,index,value)
#define __FIVector_1_Windows__CUI__CInput__CPointerPoint_get_Size(This,value) (This)->lpVtbl->get_Size(This,value)
#define __FIVector_1_Windows__CUI__CInput__CPointerPoint_GetView(This,value) (This)->lpVtbl->GetView(This,value)
#define __FIVector_1_Windows__CUI__CInput__CPointerPoint_IndexOf(This,element,index,value) (This)->lpVtbl->IndexOf(This,element,index,value)
#define __FIVector_1_Windows__CUI__CInput__CPointerPoint_SetAt(This,index,value) (This)->lpVtbl->SetAt(This,index,value)
#define __FIVector_1_Windows__CUI__CInput__CPointerPoint_InsertAt(This,index,value) (This)->lpVtbl->InsertAt(This,index,value)
#define __FIVector_1_Windows__CUI__CInput__CPointerPoint_RemoveAt(This,index) (This)->lpVtbl->RemoveAt(This,index)
#define __FIVector_1_Windows__CUI__CInput__CPointerPoint_Append(This,value) (This)->lpVtbl->Append(This,value)
#define __FIVector_1_Windows__CUI__CInput__CPointerPoint_RemoveAtEnd(This) (This)->lpVtbl->RemoveAtEnd(This)
#define __FIVector_1_Windows__CUI__CInput__CPointerPoint_Clear(This) (This)->lpVtbl->Clear(This)
#define __FIVector_1_Windows__CUI__CInput__CPointerPoint_GetMany(This,start_index,items_size,items,value) (This)->lpVtbl->GetMany(This,start_index,items_size,items,value)
#define __FIVector_1_Windows__CUI__CInput__CPointerPoint_ReplaceAll(This,count,items) (This)->lpVtbl->ReplaceAll(This,count,items)
#else
/*** IUnknown methods ***/
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CPointerPoint_QueryInterface(__FIVector_1_Windows__CUI__CInput__CPointerPoint* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __FIVector_1_Windows__CUI__CInput__CPointerPoint_AddRef(__FIVector_1_Windows__CUI__CInput__CPointerPoint* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __FIVector_1_Windows__CUI__CInput__CPointerPoint_Release(__FIVector_1_Windows__CUI__CInput__CPointerPoint* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CPointerPoint_GetIids(__FIVector_1_Windows__CUI__CInput__CPointerPoint* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CPointerPoint_GetRuntimeClassName(__FIVector_1_Windows__CUI__CInput__CPointerPoint* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CPointerPoint_GetTrustLevel(__FIVector_1_Windows__CUI__CInput__CPointerPoint* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IVector<ABI::Windows::UI::Input::PointerPoint* > methods ***/
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CPointerPoint_GetAt(__FIVector_1_Windows__CUI__CInput__CPointerPoint* This,UINT32 index,__x_ABI_CWindows_CUI_CInput_CIPointerPoint **value) {
    return This->lpVtbl->GetAt(This,index,value);
}
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CPointerPoint_get_Size(__FIVector_1_Windows__CUI__CInput__CPointerPoint* This,UINT32 *value) {
    return This->lpVtbl->get_Size(This,value);
}
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CPointerPoint_GetView(__FIVector_1_Windows__CUI__CInput__CPointerPoint* This,__FIVectorView_1_Windows__CUI__CInput__CPointerPoint **value) {
    return This->lpVtbl->GetView(This,value);
}
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CPointerPoint_IndexOf(__FIVector_1_Windows__CUI__CInput__CPointerPoint* This,__x_ABI_CWindows_CUI_CInput_CIPointerPoint *element,UINT32 *index,BOOLEAN *value) {
    return This->lpVtbl->IndexOf(This,element,index,value);
}
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CPointerPoint_SetAt(__FIVector_1_Windows__CUI__CInput__CPointerPoint* This,UINT32 index,__x_ABI_CWindows_CUI_CInput_CIPointerPoint *value) {
    return This->lpVtbl->SetAt(This,index,value);
}
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CPointerPoint_InsertAt(__FIVector_1_Windows__CUI__CInput__CPointerPoint* This,UINT32 index,__x_ABI_CWindows_CUI_CInput_CIPointerPoint *value) {
    return This->lpVtbl->InsertAt(This,index,value);
}
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CPointerPoint_RemoveAt(__FIVector_1_Windows__CUI__CInput__CPointerPoint* This,UINT32 index) {
    return This->lpVtbl->RemoveAt(This,index);
}
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CPointerPoint_Append(__FIVector_1_Windows__CUI__CInput__CPointerPoint* This,__x_ABI_CWindows_CUI_CInput_CIPointerPoint *value) {
    return This->lpVtbl->Append(This,value);
}
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CPointerPoint_RemoveAtEnd(__FIVector_1_Windows__CUI__CInput__CPointerPoint* This) {
    return This->lpVtbl->RemoveAtEnd(This);
}
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CPointerPoint_Clear(__FIVector_1_Windows__CUI__CInput__CPointerPoint* This) {
    return This->lpVtbl->Clear(This);
}
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CPointerPoint_GetMany(__FIVector_1_Windows__CUI__CInput__CPointerPoint* This,UINT32 start_index,UINT32 items_size,__x_ABI_CWindows_CUI_CInput_CIPointerPoint **items,UINT32 *value) {
    return This->lpVtbl->GetMany(This,start_index,items_size,items,value);
}
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CPointerPoint_ReplaceAll(__FIVector_1_Windows__CUI__CInput__CPointerPoint* This,UINT32 count,__x_ABI_CWindows_CUI_CInput_CIPointerPoint **items) {
    return This->lpVtbl->ReplaceAll(This,count,items);
}
#endif
#ifdef WIDL_using_Windows_Foundation_Collections
#define IID_IVector_PointerPoint IID___FIVector_1_Windows__CUI__CInput__CPointerPoint
#define IVector_PointerPointVtbl __FIVector_1_Windows__CUI__CInput__CPointerPointVtbl
#define IVector_PointerPoint __FIVector_1_Windows__CUI__CInput__CPointerPoint
#define IVector_PointerPoint_QueryInterface __FIVector_1_Windows__CUI__CInput__CPointerPoint_QueryInterface
#define IVector_PointerPoint_AddRef __FIVector_1_Windows__CUI__CInput__CPointerPoint_AddRef
#define IVector_PointerPoint_Release __FIVector_1_Windows__CUI__CInput__CPointerPoint_Release
#define IVector_PointerPoint_GetIids __FIVector_1_Windows__CUI__CInput__CPointerPoint_GetIids
#define IVector_PointerPoint_GetRuntimeClassName __FIVector_1_Windows__CUI__CInput__CPointerPoint_GetRuntimeClassName
#define IVector_PointerPoint_GetTrustLevel __FIVector_1_Windows__CUI__CInput__CPointerPoint_GetTrustLevel
#define IVector_PointerPoint_GetAt __FIVector_1_Windows__CUI__CInput__CPointerPoint_GetAt
#define IVector_PointerPoint_get_Size __FIVector_1_Windows__CUI__CInput__CPointerPoint_get_Size
#define IVector_PointerPoint_GetView __FIVector_1_Windows__CUI__CInput__CPointerPoint_GetView
#define IVector_PointerPoint_IndexOf __FIVector_1_Windows__CUI__CInput__CPointerPoint_IndexOf
#define IVector_PointerPoint_SetAt __FIVector_1_Windows__CUI__CInput__CPointerPoint_SetAt
#define IVector_PointerPoint_InsertAt __FIVector_1_Windows__CUI__CInput__CPointerPoint_InsertAt
#define IVector_PointerPoint_RemoveAt __FIVector_1_Windows__CUI__CInput__CPointerPoint_RemoveAt
#define IVector_PointerPoint_Append __FIVector_1_Windows__CUI__CInput__CPointerPoint_Append
#define IVector_PointerPoint_RemoveAtEnd __FIVector_1_Windows__CUI__CInput__CPointerPoint_RemoveAtEnd
#define IVector_PointerPoint_Clear __FIVector_1_Windows__CUI__CInput__CPointerPoint_Clear
#define IVector_PointerPoint_GetMany __FIVector_1_Windows__CUI__CInput__CPointerPoint_GetMany
#define IVector_PointerPoint_ReplaceAll __FIVector_1_Windows__CUI__CInput__CPointerPoint_ReplaceAll
#endif /* WIDL_using_Windows_Foundation_Collections */
#endif

#endif

#endif  /* ____FIVector_1_Windows__CUI__CInput__CPointerPoint_INTERFACE_DEFINED__ */

/*****************************************************************************
 * IVector<ABI::Windows::UI::Input::RadialControllerMenuItem* > interface
 */
#ifndef ____FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_INTERFACE_DEFINED__
#define ____FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_INTERFACE_DEFINED__

DEFINE_GUID(IID___FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem, 0xbfde94e7, 0x70f8, 0x5cc0, 0x98,0xe2, 0x8c,0x0f,0x8c,0xe5,0x24,0xab);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace Foundation {
            namespace Collections {
                template<>
                MIDL_INTERFACE("bfde94e7-70f8-5cc0-98e2-8c0f8ce524ab")
                IVector<ABI::Windows::UI::Input::RadialControllerMenuItem* > : IVector_impl<ABI::Windows::Foundation::Internal::AggregateType<ABI::Windows::UI::Input::RadialControllerMenuItem*, ABI::Windows::UI::Input::IRadialControllerMenuItem* > >
                {
                };
            }
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem, 0xbfde94e7, 0x70f8, 0x5cc0, 0x98,0xe2, 0x8c,0x0f,0x8c,0xe5,0x24,0xab)
#endif
#else
typedef struct __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItemVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        TrustLevel *trustLevel);

    /*** IVector<ABI::Windows::UI::Input::RadialControllerMenuItem* > methods ***/
    HRESULT (STDMETHODCALLTYPE *GetAt)(
        __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        UINT32 index,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem **value);

    HRESULT (STDMETHODCALLTYPE *get_Size)(
        __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        UINT32 *value);

    HRESULT (STDMETHODCALLTYPE *GetView)(
        __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        __FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem **value);

    HRESULT (STDMETHODCALLTYPE *IndexOf)(
        __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem *element,
        UINT32 *index,
        BOOLEAN *value);

    HRESULT (STDMETHODCALLTYPE *SetAt)(
        __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        UINT32 index,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem *value);

    HRESULT (STDMETHODCALLTYPE *InsertAt)(
        __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        UINT32 index,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem *value);

    HRESULT (STDMETHODCALLTYPE *RemoveAt)(
        __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        UINT32 index);

    HRESULT (STDMETHODCALLTYPE *Append)(
        __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem *value);

    HRESULT (STDMETHODCALLTYPE *RemoveAtEnd)(
        __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem *This);

    HRESULT (STDMETHODCALLTYPE *Clear)(
        __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem *This);

    HRESULT (STDMETHODCALLTYPE *GetMany)(
        __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        UINT32 start_index,
        UINT32 items_size,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem **items,
        UINT32 *value);

    HRESULT (STDMETHODCALLTYPE *ReplaceAll)(
        __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem *This,
        UINT32 count,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem **items);

    END_INTERFACE
} __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItemVtbl;

interface __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem {
    CONST_VTBL __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItemVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IVector<ABI::Windows::UI::Input::RadialControllerMenuItem* > methods ***/
#define __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetAt(This,index,value) (This)->lpVtbl->GetAt(This,index,value)
#define __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_get_Size(This,value) (This)->lpVtbl->get_Size(This,value)
#define __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetView(This,value) (This)->lpVtbl->GetView(This,value)
#define __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_IndexOf(This,element,index,value) (This)->lpVtbl->IndexOf(This,element,index,value)
#define __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_SetAt(This,index,value) (This)->lpVtbl->SetAt(This,index,value)
#define __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_InsertAt(This,index,value) (This)->lpVtbl->InsertAt(This,index,value)
#define __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_RemoveAt(This,index) (This)->lpVtbl->RemoveAt(This,index)
#define __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_Append(This,value) (This)->lpVtbl->Append(This,value)
#define __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_RemoveAtEnd(This) (This)->lpVtbl->RemoveAtEnd(This)
#define __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_Clear(This) (This)->lpVtbl->Clear(This)
#define __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetMany(This,start_index,items_size,items,value) (This)->lpVtbl->GetMany(This,start_index,items_size,items,value)
#define __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_ReplaceAll(This,count,items) (This)->lpVtbl->ReplaceAll(This,count,items)
#else
/*** IUnknown methods ***/
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_QueryInterface(__FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_AddRef(__FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_Release(__FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetIids(__FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetRuntimeClassName(__FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetTrustLevel(__FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IVector<ABI::Windows::UI::Input::RadialControllerMenuItem* > methods ***/
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetAt(__FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,UINT32 index,__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem **value) {
    return This->lpVtbl->GetAt(This,index,value);
}
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_get_Size(__FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,UINT32 *value) {
    return This->lpVtbl->get_Size(This,value);
}
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetView(__FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,__FIVectorView_1_Windows__CUI__CInput__CRadialControllerMenuItem **value) {
    return This->lpVtbl->GetView(This,value);
}
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_IndexOf(__FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem *element,UINT32 *index,BOOLEAN *value) {
    return This->lpVtbl->IndexOf(This,element,index,value);
}
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_SetAt(__FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,UINT32 index,__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem *value) {
    return This->lpVtbl->SetAt(This,index,value);
}
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_InsertAt(__FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,UINT32 index,__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem *value) {
    return This->lpVtbl->InsertAt(This,index,value);
}
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_RemoveAt(__FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,UINT32 index) {
    return This->lpVtbl->RemoveAt(This,index);
}
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_Append(__FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem *value) {
    return This->lpVtbl->Append(This,value);
}
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_RemoveAtEnd(__FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem* This) {
    return This->lpVtbl->RemoveAtEnd(This);
}
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_Clear(__FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem* This) {
    return This->lpVtbl->Clear(This);
}
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetMany(__FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,UINT32 start_index,UINT32 items_size,__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem **items,UINT32 *value) {
    return This->lpVtbl->GetMany(This,start_index,items_size,items,value);
}
static inline HRESULT __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_ReplaceAll(__FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem* This,UINT32 count,__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem **items) {
    return This->lpVtbl->ReplaceAll(This,count,items);
}
#endif
#ifdef WIDL_using_Windows_Foundation_Collections
#define IID_IVector_RadialControllerMenuItem IID___FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem
#define IVector_RadialControllerMenuItemVtbl __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItemVtbl
#define IVector_RadialControllerMenuItem __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem
#define IVector_RadialControllerMenuItem_QueryInterface __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_QueryInterface
#define IVector_RadialControllerMenuItem_AddRef __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_AddRef
#define IVector_RadialControllerMenuItem_Release __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_Release
#define IVector_RadialControllerMenuItem_GetIids __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetIids
#define IVector_RadialControllerMenuItem_GetRuntimeClassName __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetRuntimeClassName
#define IVector_RadialControllerMenuItem_GetTrustLevel __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetTrustLevel
#define IVector_RadialControllerMenuItem_GetAt __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetAt
#define IVector_RadialControllerMenuItem_get_Size __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_get_Size
#define IVector_RadialControllerMenuItem_GetView __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetView
#define IVector_RadialControllerMenuItem_IndexOf __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_IndexOf
#define IVector_RadialControllerMenuItem_SetAt __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_SetAt
#define IVector_RadialControllerMenuItem_InsertAt __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_InsertAt
#define IVector_RadialControllerMenuItem_RemoveAt __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_RemoveAt
#define IVector_RadialControllerMenuItem_Append __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_Append
#define IVector_RadialControllerMenuItem_RemoveAtEnd __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_RemoveAtEnd
#define IVector_RadialControllerMenuItem_Clear __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_Clear
#define IVector_RadialControllerMenuItem_GetMany __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_GetMany
#define IVector_RadialControllerMenuItem_ReplaceAll __FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_ReplaceAll
#endif /* WIDL_using_Windows_Foundation_Collections */
#endif

#endif

#endif  /* ____FIVector_1_Windows__CUI__CInput__CRadialControllerMenuItem_INTERFACE_DEFINED__ */

/*****************************************************************************
 * ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,IInspectable* > interface
 */
#ifndef ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable_INTERFACE_DEFINED__
#define ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable_INTERFACE_DEFINED__

DEFINE_GUID(IID___FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable, 0x5e0f93b1, 0xc2f2, 0x5351, 0x82,0xaa, 0x6c,0xf5,0xf4,0xc2,0xd0,0x68);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace Foundation {
            template<>
            MIDL_INTERFACE("5e0f93b1-c2f2-5351-82aa-6cf5f4c2d068")
            ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,IInspectable* > : ITypedEventHandler_impl<ABI::Windows::Foundation::Internal::AggregateType<ABI::Windows::UI::Input::RadialController*, ABI::Windows::UI::Input::IRadialController* >, IInspectable* >
            {
            };
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable, 0x5e0f93b1, 0xc2f2, 0x5351, 0x82,0xaa, 0x6c,0xf5,0xf4,0xc2,0xd0,0x68)
#endif
#else
typedef struct __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectableVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable *This);

    /*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,IInspectable* > methods ***/
    HRESULT (STDMETHODCALLTYPE *Invoke)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialController *sender,
        IInspectable *args);

    END_INTERFACE
} __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectableVtbl;

interface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable {
    CONST_VTBL __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectableVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable_Release(This) (This)->lpVtbl->Release(This)
/*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,IInspectable* > methods ***/
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable_Invoke(This,sender,args) (This)->lpVtbl->Invoke(This,sender,args)
#else
/*** IUnknown methods ***/
static inline HRESULT __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable_QueryInterface(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable_AddRef(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable_Release(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable* This) {
    return This->lpVtbl->Release(This);
}
/*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,IInspectable* > methods ***/
static inline HRESULT __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable_Invoke(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable* This,__x_ABI_CWindows_CUI_CInput_CIRadialController *sender,IInspectable *args) {
    return This->lpVtbl->Invoke(This,sender,args);
}
#endif
#ifdef WIDL_using_Windows_Foundation
#define IID_ITypedEventHandler_RadialController_IInspectable IID___FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable
#define ITypedEventHandler_RadialController_IInspectableVtbl __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectableVtbl
#define ITypedEventHandler_RadialController_IInspectable __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable
#define ITypedEventHandler_RadialController_IInspectable_QueryInterface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable_QueryInterface
#define ITypedEventHandler_RadialController_IInspectable_AddRef __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable_AddRef
#define ITypedEventHandler_RadialController_IInspectable_Release __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable_Release
#define ITypedEventHandler_RadialController_IInspectable_Invoke __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable_Invoke
#endif /* WIDL_using_Windows_Foundation */
#endif

#endif

#endif  /* ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_IInspectable_INTERFACE_DEFINED__ */

/*****************************************************************************
 * ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonClickedEventArgs* > interface
 */
#ifndef ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs_INTERFACE_DEFINED__
#define ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs_INTERFACE_DEFINED__

DEFINE_GUID(IID___FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs, 0xd09d9fcc, 0xedb8, 0x56c0, 0x85,0x6d, 0x70,0xe4,0x77,0xa9,0xdd,0xf3);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace Foundation {
            template<>
            MIDL_INTERFACE("d09d9fcc-edb8-56c0-856d-70e477a9ddf3")
            ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonClickedEventArgs* > : ITypedEventHandler_impl<ABI::Windows::Foundation::Internal::AggregateType<ABI::Windows::UI::Input::RadialController*, ABI::Windows::UI::Input::IRadialController* >, ABI::Windows::Foundation::Internal::AggregateType<ABI::Windows::UI::Input::RadialControllerButtonClickedEventArgs*, ABI::Windows::UI::Input::IRadialControllerButtonClickedEventArgs* > >
            {
            };
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs, 0xd09d9fcc, 0xedb8, 0x56c0, 0x85,0x6d, 0x70,0xe4,0x77,0xa9,0xdd,0xf3)
#endif
#else
typedef struct __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgsVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs *This);

    /*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonClickedEventArgs* > methods ***/
    HRESULT (STDMETHODCALLTYPE *Invoke)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialController *sender,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs *args);

    END_INTERFACE
} __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgsVtbl;

interface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs {
    CONST_VTBL __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgsVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs_Release(This) (This)->lpVtbl->Release(This)
/*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonClickedEventArgs* > methods ***/
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs_Invoke(This,sender,args) (This)->lpVtbl->Invoke(This,sender,args)
#else
/*** IUnknown methods ***/
static inline HRESULT __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs_QueryInterface(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs_AddRef(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs_Release(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs* This) {
    return This->lpVtbl->Release(This);
}
/*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonClickedEventArgs* > methods ***/
static inline HRESULT __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs_Invoke(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs* This,__x_ABI_CWindows_CUI_CInput_CIRadialController *sender,__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonClickedEventArgs *args) {
    return This->lpVtbl->Invoke(This,sender,args);
}
#endif
#ifdef WIDL_using_Windows_Foundation
#define IID_ITypedEventHandler_RadialController_RadialControllerButtonClickedEventArgs IID___FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs
#define ITypedEventHandler_RadialController_RadialControllerButtonClickedEventArgsVtbl __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgsVtbl
#define ITypedEventHandler_RadialController_RadialControllerButtonClickedEventArgs __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs
#define ITypedEventHandler_RadialController_RadialControllerButtonClickedEventArgs_QueryInterface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs_QueryInterface
#define ITypedEventHandler_RadialController_RadialControllerButtonClickedEventArgs_AddRef __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs_AddRef
#define ITypedEventHandler_RadialController_RadialControllerButtonClickedEventArgs_Release __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs_Release
#define ITypedEventHandler_RadialController_RadialControllerButtonClickedEventArgs_Invoke __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs_Invoke
#endif /* WIDL_using_Windows_Foundation */
#endif

#endif

#endif  /* ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonClickedEventArgs_INTERFACE_DEFINED__ */

/*****************************************************************************
 * ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonHoldingEventArgs* > interface
 */
#ifndef ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs_INTERFACE_DEFINED__
#define ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs_INTERFACE_DEFINED__

DEFINE_GUID(IID___FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs, 0x4c44f2ff, 0x3a4a, 0x51ba, 0xa0,0x1f, 0x9f,0x20,0x02,0x47,0x1f,0x59);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace Foundation {
            template<>
            MIDL_INTERFACE("4c44f2ff-3a4a-51ba-a01f-9f2002471f59")
            ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonHoldingEventArgs* > : ITypedEventHandler_impl<ABI::Windows::Foundation::Internal::AggregateType<ABI::Windows::UI::Input::RadialController*, ABI::Windows::UI::Input::IRadialController* >, ABI::Windows::Foundation::Internal::AggregateType<ABI::Windows::UI::Input::RadialControllerButtonHoldingEventArgs*, ABI::Windows::UI::Input::IRadialControllerButtonHoldingEventArgs* > >
            {
            };
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs, 0x4c44f2ff, 0x3a4a, 0x51ba, 0xa0,0x1f, 0x9f,0x20,0x02,0x47,0x1f,0x59)
#endif
#else
typedef struct __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgsVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs *This);

    /*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonHoldingEventArgs* > methods ***/
    HRESULT (STDMETHODCALLTYPE *Invoke)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialController *sender,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs *args);

    END_INTERFACE
} __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgsVtbl;

interface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs {
    CONST_VTBL __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgsVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs_Release(This) (This)->lpVtbl->Release(This)
/*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonHoldingEventArgs* > methods ***/
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs_Invoke(This,sender,args) (This)->lpVtbl->Invoke(This,sender,args)
#else
/*** IUnknown methods ***/
static inline HRESULT __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs_QueryInterface(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs_AddRef(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs_Release(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs* This) {
    return This->lpVtbl->Release(This);
}
/*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonHoldingEventArgs* > methods ***/
static inline HRESULT __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs_Invoke(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs* This,__x_ABI_CWindows_CUI_CInput_CIRadialController *sender,__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonHoldingEventArgs *args) {
    return This->lpVtbl->Invoke(This,sender,args);
}
#endif
#ifdef WIDL_using_Windows_Foundation
#define IID_ITypedEventHandler_RadialController_RadialControllerButtonHoldingEventArgs IID___FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs
#define ITypedEventHandler_RadialController_RadialControllerButtonHoldingEventArgsVtbl __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgsVtbl
#define ITypedEventHandler_RadialController_RadialControllerButtonHoldingEventArgs __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs
#define ITypedEventHandler_RadialController_RadialControllerButtonHoldingEventArgs_QueryInterface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs_QueryInterface
#define ITypedEventHandler_RadialController_RadialControllerButtonHoldingEventArgs_AddRef __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs_AddRef
#define ITypedEventHandler_RadialController_RadialControllerButtonHoldingEventArgs_Release __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs_Release
#define ITypedEventHandler_RadialController_RadialControllerButtonHoldingEventArgs_Invoke __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs_Invoke
#endif /* WIDL_using_Windows_Foundation */
#endif

#endif

#endif  /* ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonHoldingEventArgs_INTERFACE_DEFINED__ */

/*****************************************************************************
 * ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonPressedEventArgs* > interface
 */
#ifndef ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs_INTERFACE_DEFINED__
#define ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs_INTERFACE_DEFINED__

DEFINE_GUID(IID___FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs, 0x660bee4a, 0x4fed, 0x5a62, 0xaa,0x5d, 0x81,0x13,0xb4,0x77,0xbc,0x69);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace Foundation {
            template<>
            MIDL_INTERFACE("660bee4a-4fed-5a62-aa5d-8113b477bc69")
            ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonPressedEventArgs* > : ITypedEventHandler_impl<ABI::Windows::Foundation::Internal::AggregateType<ABI::Windows::UI::Input::RadialController*, ABI::Windows::UI::Input::IRadialController* >, ABI::Windows::Foundation::Internal::AggregateType<ABI::Windows::UI::Input::RadialControllerButtonPressedEventArgs*, ABI::Windows::UI::Input::IRadialControllerButtonPressedEventArgs* > >
            {
            };
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs, 0x660bee4a, 0x4fed, 0x5a62, 0xaa,0x5d, 0x81,0x13,0xb4,0x77,0xbc,0x69)
#endif
#else
typedef struct __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgsVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs *This);

    /*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonPressedEventArgs* > methods ***/
    HRESULT (STDMETHODCALLTYPE *Invoke)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialController *sender,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs *args);

    END_INTERFACE
} __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgsVtbl;

interface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs {
    CONST_VTBL __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgsVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs_Release(This) (This)->lpVtbl->Release(This)
/*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonPressedEventArgs* > methods ***/
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs_Invoke(This,sender,args) (This)->lpVtbl->Invoke(This,sender,args)
#else
/*** IUnknown methods ***/
static inline HRESULT __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs_QueryInterface(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs_AddRef(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs_Release(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs* This) {
    return This->lpVtbl->Release(This);
}
/*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonPressedEventArgs* > methods ***/
static inline HRESULT __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs_Invoke(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs* This,__x_ABI_CWindows_CUI_CInput_CIRadialController *sender,__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonPressedEventArgs *args) {
    return This->lpVtbl->Invoke(This,sender,args);
}
#endif
#ifdef WIDL_using_Windows_Foundation
#define IID_ITypedEventHandler_RadialController_RadialControllerButtonPressedEventArgs IID___FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs
#define ITypedEventHandler_RadialController_RadialControllerButtonPressedEventArgsVtbl __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgsVtbl
#define ITypedEventHandler_RadialController_RadialControllerButtonPressedEventArgs __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs
#define ITypedEventHandler_RadialController_RadialControllerButtonPressedEventArgs_QueryInterface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs_QueryInterface
#define ITypedEventHandler_RadialController_RadialControllerButtonPressedEventArgs_AddRef __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs_AddRef
#define ITypedEventHandler_RadialController_RadialControllerButtonPressedEventArgs_Release __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs_Release
#define ITypedEventHandler_RadialController_RadialControllerButtonPressedEventArgs_Invoke __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs_Invoke
#endif /* WIDL_using_Windows_Foundation */
#endif

#endif

#endif  /* ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonPressedEventArgs_INTERFACE_DEFINED__ */

/*****************************************************************************
 * ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonReleasedEventArgs* > interface
 */
#ifndef ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs_INTERFACE_DEFINED__
#define ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs_INTERFACE_DEFINED__

DEFINE_GUID(IID___FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs, 0xc22ff62c, 0xc642, 0x5d50, 0x93,0x40, 0xfe,0x16,0x31,0x22,0x72,0x0c);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace Foundation {
            template<>
            MIDL_INTERFACE("c22ff62c-c642-5d50-9340-fe163122720c")
            ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonReleasedEventArgs* > : ITypedEventHandler_impl<ABI::Windows::Foundation::Internal::AggregateType<ABI::Windows::UI::Input::RadialController*, ABI::Windows::UI::Input::IRadialController* >, ABI::Windows::Foundation::Internal::AggregateType<ABI::Windows::UI::Input::RadialControllerButtonReleasedEventArgs*, ABI::Windows::UI::Input::IRadialControllerButtonReleasedEventArgs* > >
            {
            };
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs, 0xc22ff62c, 0xc642, 0x5d50, 0x93,0x40, 0xfe,0x16,0x31,0x22,0x72,0x0c)
#endif
#else
typedef struct __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgsVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs *This);

    /*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonReleasedEventArgs* > methods ***/
    HRESULT (STDMETHODCALLTYPE *Invoke)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialController *sender,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs *args);

    END_INTERFACE
} __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgsVtbl;

interface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs {
    CONST_VTBL __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgsVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs_Release(This) (This)->lpVtbl->Release(This)
/*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonReleasedEventArgs* > methods ***/
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs_Invoke(This,sender,args) (This)->lpVtbl->Invoke(This,sender,args)
#else
/*** IUnknown methods ***/
static inline HRESULT __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs_QueryInterface(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs_AddRef(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs_Release(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs* This) {
    return This->lpVtbl->Release(This);
}
/*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerButtonReleasedEventArgs* > methods ***/
static inline HRESULT __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs_Invoke(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs* This,__x_ABI_CWindows_CUI_CInput_CIRadialController *sender,__x_ABI_CWindows_CUI_CInput_CIRadialControllerButtonReleasedEventArgs *args) {
    return This->lpVtbl->Invoke(This,sender,args);
}
#endif
#ifdef WIDL_using_Windows_Foundation
#define IID_ITypedEventHandler_RadialController_RadialControllerButtonReleasedEventArgs IID___FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs
#define ITypedEventHandler_RadialController_RadialControllerButtonReleasedEventArgsVtbl __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgsVtbl
#define ITypedEventHandler_RadialController_RadialControllerButtonReleasedEventArgs __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs
#define ITypedEventHandler_RadialController_RadialControllerButtonReleasedEventArgs_QueryInterface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs_QueryInterface
#define ITypedEventHandler_RadialController_RadialControllerButtonReleasedEventArgs_AddRef __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs_AddRef
#define ITypedEventHandler_RadialController_RadialControllerButtonReleasedEventArgs_Release __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs_Release
#define ITypedEventHandler_RadialController_RadialControllerButtonReleasedEventArgs_Invoke __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs_Invoke
#endif /* WIDL_using_Windows_Foundation */
#endif

#endif

#endif  /* ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerButtonReleasedEventArgs_INTERFACE_DEFINED__ */

/*****************************************************************************
 * ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerControlAcquiredEventArgs* > interface
 */
#ifndef ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs_INTERFACE_DEFINED__
#define ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs_INTERFACE_DEFINED__

DEFINE_GUID(IID___FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs, 0x4ec5f3fd, 0xb217, 0x5452, 0xa2,0xbd, 0x97,0x25,0xce,0x9f,0x66,0x75);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace Foundation {
            template<>
            MIDL_INTERFACE("4ec5f3fd-b217-5452-a2bd-9725ce9f6675")
            ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerControlAcquiredEventArgs* > : ITypedEventHandler_impl<ABI::Windows::Foundation::Internal::AggregateType<ABI::Windows::UI::Input::RadialController*, ABI::Windows::UI::Input::IRadialController* >, ABI::Windows::Foundation::Internal::AggregateType<ABI::Windows::UI::Input::RadialControllerControlAcquiredEventArgs*, ABI::Windows::UI::Input::IRadialControllerControlAcquiredEventArgs* > >
            {
            };
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs, 0x4ec5f3fd, 0xb217, 0x5452, 0xa2,0xbd, 0x97,0x25,0xce,0x9f,0x66,0x75)
#endif
#else
typedef struct __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgsVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs *This);

    /*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerControlAcquiredEventArgs* > methods ***/
    HRESULT (STDMETHODCALLTYPE *Invoke)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialController *sender,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs *args);

    END_INTERFACE
} __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgsVtbl;

interface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs {
    CONST_VTBL __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgsVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs_Release(This) (This)->lpVtbl->Release(This)
/*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerControlAcquiredEventArgs* > methods ***/
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs_Invoke(This,sender,args) (This)->lpVtbl->Invoke(This,sender,args)
#else
/*** IUnknown methods ***/
static inline HRESULT __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs_QueryInterface(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs_AddRef(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs_Release(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs* This) {
    return This->lpVtbl->Release(This);
}
/*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerControlAcquiredEventArgs* > methods ***/
static inline HRESULT __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs_Invoke(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs* This,__x_ABI_CWindows_CUI_CInput_CIRadialController *sender,__x_ABI_CWindows_CUI_CInput_CIRadialControllerControlAcquiredEventArgs *args) {
    return This->lpVtbl->Invoke(This,sender,args);
}
#endif
#ifdef WIDL_using_Windows_Foundation
#define IID_ITypedEventHandler_RadialController_RadialControllerControlAcquiredEventArgs IID___FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs
#define ITypedEventHandler_RadialController_RadialControllerControlAcquiredEventArgsVtbl __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgsVtbl
#define ITypedEventHandler_RadialController_RadialControllerControlAcquiredEventArgs __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs
#define ITypedEventHandler_RadialController_RadialControllerControlAcquiredEventArgs_QueryInterface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs_QueryInterface
#define ITypedEventHandler_RadialController_RadialControllerControlAcquiredEventArgs_AddRef __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs_AddRef
#define ITypedEventHandler_RadialController_RadialControllerControlAcquiredEventArgs_Release __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs_Release
#define ITypedEventHandler_RadialController_RadialControllerControlAcquiredEventArgs_Invoke __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs_Invoke
#endif /* WIDL_using_Windows_Foundation */
#endif

#endif

#endif  /* ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerControlAcquiredEventArgs_INTERFACE_DEFINED__ */

/*****************************************************************************
 * ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerRotationChangedEventArgs* > interface
 */
#ifndef ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs_INTERFACE_DEFINED__
#define ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs_INTERFACE_DEFINED__

DEFINE_GUID(IID___FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs, 0x8fe73ac9, 0x8a36, 0x5152, 0x81,0x5d, 0x03,0x31,0x0e,0xe8,0xbf,0x85);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace Foundation {
            template<>
            MIDL_INTERFACE("8fe73ac9-8a36-5152-815d-03310ee8bf85")
            ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerRotationChangedEventArgs* > : ITypedEventHandler_impl<ABI::Windows::Foundation::Internal::AggregateType<ABI::Windows::UI::Input::RadialController*, ABI::Windows::UI::Input::IRadialController* >, ABI::Windows::Foundation::Internal::AggregateType<ABI::Windows::UI::Input::RadialControllerRotationChangedEventArgs*, ABI::Windows::UI::Input::IRadialControllerRotationChangedEventArgs* > >
            {
            };
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs, 0x8fe73ac9, 0x8a36, 0x5152, 0x81,0x5d, 0x03,0x31,0x0e,0xe8,0xbf,0x85)
#endif
#else
typedef struct __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgsVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs *This);

    /*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerRotationChangedEventArgs* > methods ***/
    HRESULT (STDMETHODCALLTYPE *Invoke)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialController *sender,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs *args);

    END_INTERFACE
} __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgsVtbl;

interface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs {
    CONST_VTBL __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgsVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs_Release(This) (This)->lpVtbl->Release(This)
/*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerRotationChangedEventArgs* > methods ***/
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs_Invoke(This,sender,args) (This)->lpVtbl->Invoke(This,sender,args)
#else
/*** IUnknown methods ***/
static inline HRESULT __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs_QueryInterface(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs_AddRef(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs_Release(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs* This) {
    return This->lpVtbl->Release(This);
}
/*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerRotationChangedEventArgs* > methods ***/
static inline HRESULT __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs_Invoke(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs* This,__x_ABI_CWindows_CUI_CInput_CIRadialController *sender,__x_ABI_CWindows_CUI_CInput_CIRadialControllerRotationChangedEventArgs *args) {
    return This->lpVtbl->Invoke(This,sender,args);
}
#endif
#ifdef WIDL_using_Windows_Foundation
#define IID_ITypedEventHandler_RadialController_RadialControllerRotationChangedEventArgs IID___FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs
#define ITypedEventHandler_RadialController_RadialControllerRotationChangedEventArgsVtbl __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgsVtbl
#define ITypedEventHandler_RadialController_RadialControllerRotationChangedEventArgs __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs
#define ITypedEventHandler_RadialController_RadialControllerRotationChangedEventArgs_QueryInterface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs_QueryInterface
#define ITypedEventHandler_RadialController_RadialControllerRotationChangedEventArgs_AddRef __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs_AddRef
#define ITypedEventHandler_RadialController_RadialControllerRotationChangedEventArgs_Release __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs_Release
#define ITypedEventHandler_RadialController_RadialControllerRotationChangedEventArgs_Invoke __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs_Invoke
#endif /* WIDL_using_Windows_Foundation */
#endif

#endif

#endif  /* ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerRotationChangedEventArgs_INTERFACE_DEFINED__ */

/*****************************************************************************
 * ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerScreenContactContinuedEventArgs* > interface
 */
#ifndef ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs_INTERFACE_DEFINED__
#define ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs_INTERFACE_DEFINED__

DEFINE_GUID(IID___FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs, 0x30579e67, 0xfb4f, 0x5d38, 0x83,0xb4, 0x9c,0xb6,0x10,0x09,0x0d,0xef);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace Foundation {
            template<>
            MIDL_INTERFACE("30579e67-fb4f-5d38-83b4-9cb610090def")
            ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerScreenContactContinuedEventArgs* > : ITypedEventHandler_impl<ABI::Windows::Foundation::Internal::AggregateType<ABI::Windows::UI::Input::RadialController*, ABI::Windows::UI::Input::IRadialController* >, ABI::Windows::Foundation::Internal::AggregateType<ABI::Windows::UI::Input::RadialControllerScreenContactContinuedEventArgs*, ABI::Windows::UI::Input::IRadialControllerScreenContactContinuedEventArgs* > >
            {
            };
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs, 0x30579e67, 0xfb4f, 0x5d38, 0x83,0xb4, 0x9c,0xb6,0x10,0x09,0x0d,0xef)
#endif
#else
typedef struct __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgsVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs *This);

    /*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerScreenContactContinuedEventArgs* > methods ***/
    HRESULT (STDMETHODCALLTYPE *Invoke)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialController *sender,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs *args);

    END_INTERFACE
} __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgsVtbl;

interface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs {
    CONST_VTBL __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgsVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs_Release(This) (This)->lpVtbl->Release(This)
/*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerScreenContactContinuedEventArgs* > methods ***/
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs_Invoke(This,sender,args) (This)->lpVtbl->Invoke(This,sender,args)
#else
/*** IUnknown methods ***/
static inline HRESULT __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs_QueryInterface(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs_AddRef(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs_Release(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs* This) {
    return This->lpVtbl->Release(This);
}
/*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerScreenContactContinuedEventArgs* > methods ***/
static inline HRESULT __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs_Invoke(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs* This,__x_ABI_CWindows_CUI_CInput_CIRadialController *sender,__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactContinuedEventArgs *args) {
    return This->lpVtbl->Invoke(This,sender,args);
}
#endif
#ifdef WIDL_using_Windows_Foundation
#define IID_ITypedEventHandler_RadialController_RadialControllerScreenContactContinuedEventArgs IID___FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs
#define ITypedEventHandler_RadialController_RadialControllerScreenContactContinuedEventArgsVtbl __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgsVtbl
#define ITypedEventHandler_RadialController_RadialControllerScreenContactContinuedEventArgs __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs
#define ITypedEventHandler_RadialController_RadialControllerScreenContactContinuedEventArgs_QueryInterface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs_QueryInterface
#define ITypedEventHandler_RadialController_RadialControllerScreenContactContinuedEventArgs_AddRef __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs_AddRef
#define ITypedEventHandler_RadialController_RadialControllerScreenContactContinuedEventArgs_Release __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs_Release
#define ITypedEventHandler_RadialController_RadialControllerScreenContactContinuedEventArgs_Invoke __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs_Invoke
#endif /* WIDL_using_Windows_Foundation */
#endif

#endif

#endif  /* ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactContinuedEventArgs_INTERFACE_DEFINED__ */

/*****************************************************************************
 * ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerScreenContactStartedEventArgs* > interface
 */
#ifndef ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs_INTERFACE_DEFINED__
#define ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs_INTERFACE_DEFINED__

DEFINE_GUID(IID___FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs, 0x1f2d584e, 0x3ad8, 0x5049, 0xb4,0x51, 0x3a,0x44,0xa1,0x02,0xfa,0x82);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace Foundation {
            template<>
            MIDL_INTERFACE("1f2d584e-3ad8-5049-b451-3a44a102fa82")
            ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerScreenContactStartedEventArgs* > : ITypedEventHandler_impl<ABI::Windows::Foundation::Internal::AggregateType<ABI::Windows::UI::Input::RadialController*, ABI::Windows::UI::Input::IRadialController* >, ABI::Windows::Foundation::Internal::AggregateType<ABI::Windows::UI::Input::RadialControllerScreenContactStartedEventArgs*, ABI::Windows::UI::Input::IRadialControllerScreenContactStartedEventArgs* > >
            {
            };
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs, 0x1f2d584e, 0x3ad8, 0x5049, 0xb4,0x51, 0x3a,0x44,0xa1,0x02,0xfa,0x82)
#endif
#else
typedef struct __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgsVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs *This);

    /*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerScreenContactStartedEventArgs* > methods ***/
    HRESULT (STDMETHODCALLTYPE *Invoke)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialController *sender,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs *args);

    END_INTERFACE
} __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgsVtbl;

interface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs {
    CONST_VTBL __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgsVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs_Release(This) (This)->lpVtbl->Release(This)
/*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerScreenContactStartedEventArgs* > methods ***/
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs_Invoke(This,sender,args) (This)->lpVtbl->Invoke(This,sender,args)
#else
/*** IUnknown methods ***/
static inline HRESULT __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs_QueryInterface(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs_AddRef(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs_Release(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs* This) {
    return This->lpVtbl->Release(This);
}
/*** ITypedEventHandler<ABI::Windows::UI::Input::RadialController*,ABI::Windows::UI::Input::RadialControllerScreenContactStartedEventArgs* > methods ***/
static inline HRESULT __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs_Invoke(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs* This,__x_ABI_CWindows_CUI_CInput_CIRadialController *sender,__x_ABI_CWindows_CUI_CInput_CIRadialControllerScreenContactStartedEventArgs *args) {
    return This->lpVtbl->Invoke(This,sender,args);
}
#endif
#ifdef WIDL_using_Windows_Foundation
#define IID_ITypedEventHandler_RadialController_RadialControllerScreenContactStartedEventArgs IID___FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs
#define ITypedEventHandler_RadialController_RadialControllerScreenContactStartedEventArgsVtbl __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgsVtbl
#define ITypedEventHandler_RadialController_RadialControllerScreenContactStartedEventArgs __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs
#define ITypedEventHandler_RadialController_RadialControllerScreenContactStartedEventArgs_QueryInterface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs_QueryInterface
#define ITypedEventHandler_RadialController_RadialControllerScreenContactStartedEventArgs_AddRef __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs_AddRef
#define ITypedEventHandler_RadialController_RadialControllerScreenContactStartedEventArgs_Release __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs_Release
#define ITypedEventHandler_RadialController_RadialControllerScreenContactStartedEventArgs_Invoke __FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs_Invoke
#endif /* WIDL_using_Windows_Foundation */
#endif

#endif

#endif  /* ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialController_Windows__CUI__CInput__CRadialControllerScreenContactStartedEventArgs_INTERFACE_DEFINED__ */

/*****************************************************************************
 * ITypedEventHandler<ABI::Windows::UI::Input::RadialControllerMenuItem*,IInspectable* > interface
 */
#ifndef ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable_INTERFACE_DEFINED__
#define ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable_INTERFACE_DEFINED__

DEFINE_GUID(IID___FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable, 0x5c90d6fb, 0xe4f8, 0x5be2, 0x85,0x44, 0x9d,0xe3,0x3f,0x82,0xc4,0x1a);
#if defined(__cplusplus) && !defined(CINTERFACE)
} /* extern "C" */
namespace ABI {
    namespace Windows {
        namespace Foundation {
            template<>
            MIDL_INTERFACE("5c90d6fb-e4f8-5be2-8544-9de33f82c41a")
            ITypedEventHandler<ABI::Windows::UI::Input::RadialControllerMenuItem*,IInspectable* > : ITypedEventHandler_impl<ABI::Windows::Foundation::Internal::AggregateType<ABI::Windows::UI::Input::RadialControllerMenuItem*, ABI::Windows::UI::Input::IRadialControllerMenuItem* >, IInspectable* >
            {
            };
        }
    }
}
extern "C" {
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable, 0x5c90d6fb, 0xe4f8, 0x5be2, 0x85,0x44, 0x9d,0xe3,0x3f,0x82,0xc4,0x1a)
#endif
#else
typedef struct __FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectableVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable *This);

    /*** ITypedEventHandler<ABI::Windows::UI::Input::RadialControllerMenuItem*,IInspectable* > methods ***/
    HRESULT (STDMETHODCALLTYPE *Invoke)(
        __FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable *This,
        __x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem *sender,
        IInspectable *args);

    END_INTERFACE
} __FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectableVtbl;

interface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable {
    CONST_VTBL __FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectableVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable_AddRef(This) (This)->lpVtbl->AddRef(This)
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable_Release(This) (This)->lpVtbl->Release(This)
/*** ITypedEventHandler<ABI::Windows::UI::Input::RadialControllerMenuItem*,IInspectable* > methods ***/
#define __FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable_Invoke(This,sender,args) (This)->lpVtbl->Invoke(This,sender,args)
#else
/*** IUnknown methods ***/
static inline HRESULT __FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable_QueryInterface(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG __FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable_AddRef(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG __FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable_Release(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable* This) {
    return This->lpVtbl->Release(This);
}
/*** ITypedEventHandler<ABI::Windows::UI::Input::RadialControllerMenuItem*,IInspectable* > methods ***/
static inline HRESULT __FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable_Invoke(__FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable* This,__x_ABI_CWindows_CUI_CInput_CIRadialControllerMenuItem *sender,IInspectable *args) {
    return This->lpVtbl->Invoke(This,sender,args);
}
#endif
#ifdef WIDL_using_Windows_Foundation
#define IID_ITypedEventHandler_RadialControllerMenuItem_IInspectable IID___FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable
#define ITypedEventHandler_RadialControllerMenuItem_IInspectableVtbl __FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectableVtbl
#define ITypedEventHandler_RadialControllerMenuItem_IInspectable __FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable
#define ITypedEventHandler_RadialControllerMenuItem_IInspectable_QueryInterface __FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable_QueryInterface
#define ITypedEventHandler_RadialControllerMenuItem_IInspectable_AddRef __FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable_AddRef
#define ITypedEventHandler_RadialControllerMenuItem_IInspectable_Release __FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable_Release
#define ITypedEventHandler_RadialControllerMenuItem_IInspectable_Invoke __FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable_Invoke
#endif /* WIDL_using_Windows_Foundation */
#endif

#endif

#endif  /* ____FITypedEventHandler_2_Windows__CUI__CInput__CRadialControllerMenuItem_IInspectable_INTERFACE_DEFINED__ */

/* Begin additional prototypes for all interfaces */

ULONG           __RPC_USER HSTRING_UserSize     (ULONG *, ULONG, HSTRING *);
unsigned char * __RPC_USER HSTRING_UserMarshal  (ULONG *, unsigned char *, HSTRING *);
unsigned char * __RPC_USER HSTRING_UserUnmarshal(ULONG *, unsigned char *, HSTRING *);
void            __RPC_USER HSTRING_UserFree     (ULONG *, HSTRING *);

/* End additional prototypes */

#ifdef __cplusplus
}
#endif

#endif /* __windows_ui_input_h__ */
